@@ -35,6 +35,6 @@ public interface AlertChannel {
     AlertResult process(AlertInfo info);
 
     default @NonNull AlertResult closeAlert(AlertInfo info) {
-        return new AlertResult("true", "no need to close alert");
+        return new AlertResult(true, "no need to close alert");
     }
 }
