@@ -33,15 +33,19 @@ import lombok.NoArgsConstructor;
 @NoArgsConstructor
 public class AlertResult {
 
-    /**
-     * todo: use enum
-     * false or true
-     */
-    private String status;
+    private boolean success;
 
     /**
      * alert result message, each plugin can have its own message
      */
     private String message;
 
+    public static AlertResult success() {
+        return new AlertResult(true, null);
+    }
+
+    public static AlertResult fail(String message) {
+        return new AlertResult(false, message);
+    }
+
 }
