@@ -23,6 +23,7 @@ import org.apache.dolphinscheduler.common.utils.JSONUtils;
 
 import org.apache.commons.lang3.StringUtils;
 import org.apache.http.HttpEntity;
+import org.apache.http.client.config.RequestConfig;
 import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.methods.HttpPost;
@@ -32,13 +33,13 @@ import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.HttpClients;
 import org.apache.http.util.EntityUtils;
 
-import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.net.MalformedURLException;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URL;
 import java.net.URLEncoder;
+import java.nio.charset.StandardCharsets;
 import java.util.HashMap;
 import java.util.Map;
 
@@ -58,11 +59,11 @@ public final class HttpSender {
      * request type get
      */
     private static final String REQUEST_TYPE_GET = "GET";
-    private static final String DEFAULT_CHARSET = "utf-8";
     private final String headerParams;
     private final String bodyParams;
     private final String contentField;
     private final String requestType;
+    private final int timeout;
     private String url;
     private HttpRequestBase httpRequest;
 
@@ -73,6 +74,9 @@ public final class HttpSender {
         bodyParams = paramsMap.get(HttpAlertConstants.NAME_BODY_PARAMS);
         contentField = paramsMap.get(HttpAlertConstants.NAME_CONTENT_FIELD);
         requestType = paramsMap.get(HttpAlertConstants.NAME_REQUEST_TYPE);
+        timeout = StringUtils.isNotBlank(paramsMap.get(HttpAlertConstants.NAME_TIMEOUT))
+                ? Integer.parseInt(paramsMap.get(HttpAlertConstants.NAME_TIMEOUT))
+                : HttpAlertConstants.DEFAULT_TIMEOUT;
     }
 
     public AlertResult send(String msg) {
@@ -88,30 +92,39 @@ public final class HttpSender {
         }
 
         if (httpRequest == null) {
-            alertResult.setStatus("false");
+            alertResult.setSuccess(false);
             alertResult.setMessage("Request types are not supported");
             return alertResult;
         }
 
         try {
             String resp = this.getResponseString(httpRequest);
-            alertResult.setStatus("true");
+            alertResult.setSuccess(true);
             alertResult.setMessage(resp);
         } catch (Exception e) {
             log.error("send http alert msg  exception : {}", e.getMessage());
-            alertResult.setStatus("false");
-            alertResult.setMessage("send http request  alert fail.");
+            alertResult.setSuccess(false);
+            alertResult.setMessage(
+                    String.format("Send http request alert failed: %s", e.getMessage()));
         }
 
         return alertResult;
     }
 
-    public String getResponseString(HttpRequestBase httpRequest) throws IOException {
-        CloseableHttpClient httpClient =
-                HttpClients.custom().setRetryHandler(HttpServiceRetryStrategy.retryStrategy).build();
+    public String getResponseString(HttpRequestBase httpRequest) throws Exception {
+
+        RequestConfig requestConfig = RequestConfig.custom()
+                .setConnectTimeout(timeout * 1000)
+                .setConnectionRequestTimeout(timeout * 1000)
+                .setSocketTimeout(timeout * 1000)
+                .build();
+        CloseableHttpClient httpClient = HttpClients.custom()
+                .setDefaultRequestConfig(requestConfig)
+                .setRetryHandler(HttpServiceRetryStrategy.retryStrategy).build();
+
         CloseableHttpResponse response = httpClient.execute(httpRequest);
         HttpEntity entity = response.getEntity();
-        return EntityUtils.toString(entity, DEFAULT_CHARSET);
+        return EntityUtils.toString(entity, StandardCharsets.UTF_8);
     }
 
     private void createHttpRequest(String msg) throws MalformedURLException, URISyntaxException {
@@ -144,7 +157,8 @@ public final class HttpSender {
                 type = URL_SPLICE_CHAR;
             }
             try {
-                url = String.format("%s%s%s=%s", url, type, contentField, URLEncoder.encode(msg, DEFAULT_CHARSET));
+                url = String.format("%s%s%s=%s", url, type, contentField,
+                        URLEncoder.encode(msg, StandardCharsets.UTF_8.name()));
             } catch (UnsupportedEncodingException e) {
                 throw new RuntimeException(e);
             }
@@ -177,7 +191,7 @@ public final class HttpSender {
             }
             // set msg content field
             objectNode.put(contentField, msg);
-            StringEntity entity = new StringEntity(JSONUtils.toJsonString(objectNode), DEFAULT_CHARSET);
+            StringEntity entity = new StringEntity(JSONUtils.toJsonString(objectNode), StandardCharsets.UTF_8);
             ((HttpPost) httpRequest).setEntity(entity);
         } catch (Exception e) {
             log.error("send http alert msg  exception : {}", e.getMessage());
