@@ -26,12 +26,16 @@ import static org.apache.dolphinscheduler.api.enums.Status.QUERY_RULE_LIST_PAGIN
 import org.apache.dolphinscheduler.api.exceptions.ApiException;
 import org.apache.dolphinscheduler.api.service.DqExecuteResultService;
 import org.apache.dolphinscheduler.api.service.DqRuleService;
+import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.common.constants.Constants;
+import org.apache.dolphinscheduler.dao.entity.DqExecuteResult;
+import org.apache.dolphinscheduler.dao.entity.DqRule;
 import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.dolphinscheduler.plugin.task.api.utils.ParameterUtils;
+import org.apache.dolphinscheduler.spi.params.base.ParamsOptions;
 
-import java.util.Map;
+import java.util.List;
 
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.http.HttpStatus;
@@ -74,9 +78,9 @@ public class DataQualityController extends BaseController {
     @GetMapping(value = "/getRuleFormCreateJson")
     @ResponseStatus(HttpStatus.OK)
     @ApiException(GET_RULE_FORM_CREATE_JSON_ERROR)
-    public Result getRuleFormCreateJsonById(@RequestParam(value = "ruleId") int ruleId) {
-        Map<String, Object> result = dqRuleService.getRuleFormCreateJsonById(ruleId);
-        return returnDataList(result);
+    public Result<String> getRuleFormCreateJsonById(@RequestParam(value = "ruleId") int ruleId) {
+        String ruleFormCreateJsonById = dqRuleService.getRuleFormCreateJsonById(ruleId);
+        return Result.success(ruleFormCreateJsonById);
     }
 
     /**
@@ -100,33 +104,33 @@ public class DataQualityController extends BaseController {
     @GetMapping(value = "/rule/page")
     @ResponseStatus(HttpStatus.OK)
     @ApiException(QUERY_RULE_LIST_PAGING_ERROR)
-    public Result queryRuleListPaging(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
-                                      @RequestParam(value = "searchVal", required = false) String searchVal,
-                                      @RequestParam(value = "ruleType", required = false) Integer ruleType,
-                                      @RequestParam(value = "startDate", required = false) String startTime,
-                                      @RequestParam(value = "endDate", required = false) String endTime,
-                                      @RequestParam("pageNo") Integer pageNo,
-                                      @RequestParam("pageSize") Integer pageSize) {
-        Result result = checkPageParams(pageNo, pageSize);
-        if (!result.checkResult()) {
-            return result;
-        }
+    public Result<PageInfo<DqRule>> queryRuleListPaging(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
+                                                        @RequestParam(value = "searchVal", required = false) String searchVal,
+                                                        @RequestParam(value = "ruleType", required = false) Integer ruleType,
+                                                        @RequestParam(value = "startDate", required = false) String startTime,
+                                                        @RequestParam(value = "endDate", required = false) String endTime,
+                                                        @RequestParam("pageNo") Integer pageNo,
+                                                        @RequestParam("pageSize") Integer pageSize) {
+        checkPageParams(pageNo, pageSize);
         searchVal = ParameterUtils.handleEscapes(searchVal);
 
-        return dqRuleService.queryRuleListPaging(loginUser, searchVal, ruleType, startTime, endTime, pageNo, pageSize);
+        PageInfo<DqRule> dqRulePageInfo =
+                dqRuleService.queryRuleListPaging(loginUser, searchVal, ruleType, startTime, endTime, pageNo, pageSize);
+        return Result.success(dqRulePageInfo);
     }
 
     /**
      * query all rule list
+     *
      * @return rule list
      */
     @Operation(summary = "queryRuleList", description = "QUERY_RULE_LIST_NOTES")
     @GetMapping(value = "/ruleList")
     @ResponseStatus(HttpStatus.OK)
     @ApiException(QUERY_RULE_LIST_ERROR)
-    public Result queryRuleList() {
-        Map<String, Object> result = dqRuleService.queryAllRuleList();
-        return returnDataList(result);
+    public Result<List<DqRule>> queryRuleList() {
+        List<DqRule> dqRules = dqRuleService.queryAllRuleList();
+        return Result.success(dqRules);
     }
 
     /**
@@ -155,23 +159,21 @@ public class DataQualityController extends BaseController {
     @GetMapping(value = "/result/page")
     @ResponseStatus(HttpStatus.OK)
     @ApiException(QUERY_EXECUTE_RESULT_LIST_PAGING_ERROR)
-    public Result queryExecuteResultListPaging(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
-                                               @RequestParam(value = "searchVal", required = false) String searchVal,
-                                               @RequestParam(value = "ruleType", required = false) Integer ruleType,
-                                               @RequestParam(value = "state", required = false) Integer state,
-                                               @RequestParam(value = "startDate", required = false) String startTime,
-                                               @RequestParam(value = "endDate", required = false) String endTime,
-                                               @RequestParam("pageNo") Integer pageNo,
-                                               @RequestParam("pageSize") Integer pageSize) {
+    public Result<PageInfo<DqExecuteResult>> queryExecuteResultListPaging(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
+                                                                          @RequestParam(value = "searchVal", required = false) String searchVal,
+                                                                          @RequestParam(value = "ruleType", required = false) Integer ruleType,
+                                                                          @RequestParam(value = "state", required = false) Integer state,
+                                                                          @RequestParam(value = "startDate", required = false) String startTime,
+                                                                          @RequestParam(value = "endDate", required = false) String endTime,
+                                                                          @RequestParam("pageNo") Integer pageNo,
+                                                                          @RequestParam("pageSize") Integer pageSize) {
 
-        Result result = checkPageParams(pageNo, pageSize);
-        if (!result.checkResult()) {
-            return result;
-        }
+        checkPageParams(pageNo, pageSize);
         searchVal = ParameterUtils.handleEscapes(searchVal);
 
-        return dqExecuteResultService.queryResultListPaging(loginUser, searchVal, state, ruleType, startTime, endTime,
-                pageNo, pageSize);
+        PageInfo<DqExecuteResult> dqExecuteResultPageInfo = dqExecuteResultService.queryResultListPaging(loginUser,
+                searchVal, state, ruleType, startTime, endTime, pageNo, pageSize);
+        return Result.success(dqExecuteResultPageInfo);
     }
 
     /**
@@ -186,8 +188,8 @@ public class DataQualityController extends BaseController {
     @GetMapping(value = "/getDatasourceOptionsById")
     @ResponseStatus(HttpStatus.OK)
     @ApiException(GET_DATASOURCE_OPTIONS_ERROR)
-    public Result getDatasourceOptionsById(@RequestParam(value = "datasourceId") int datasourceId) {
-        Map<String, Object> result = dqRuleService.getDatasourceOptionsById(datasourceId);
-        return returnDataList(result);
+    public Result<List<ParamsOptions>> getDatasourceOptionsById(@RequestParam(value = "datasourceId") int datasourceId) {
+        List<ParamsOptions> paramsOptions = dqRuleService.getDatasourceOptionsById(datasourceId);
+        return Result.success(paramsOptions);
     }
 }
