@@ -18,17 +18,12 @@
 package org.apache.dolphinscheduler.api.security.impl.pwd;
 
 import org.apache.dolphinscheduler.api.security.impl.AbstractAuthenticator;
-import org.apache.dolphinscheduler.api.service.UsersService;
 import org.apache.dolphinscheduler.dao.entity.User;
 
-import org.springframework.beans.factory.annotation.Autowired;
-
 public class PasswordAuthenticator extends AbstractAuthenticator {
-    @Autowired
-    private UsersService userService;
 
     @Override
-    public User login(String userId, String password, String extra) {
+    public User login(String userId, String password) {
         return userService.queryUser(userId, password);
     }
 }
