@@ -24,17 +24,23 @@ import org.apache.dolphinscheduler.api.dto.DefineUserDto;
 import org.apache.dolphinscheduler.api.dto.TaskCountDto;
 import org.apache.dolphinscheduler.api.dto.project.StatisticsStateRequest;
 import org.apache.dolphinscheduler.api.enums.Status;
+import org.apache.dolphinscheduler.api.exceptions.ServiceException;
 import org.apache.dolphinscheduler.api.service.DataAnalysisService;
 import org.apache.dolphinscheduler.api.service.ProjectService;
+import org.apache.dolphinscheduler.api.utils.PageInfo;
+import org.apache.dolphinscheduler.api.vo.TaskInstanceCountVO;
+import org.apache.dolphinscheduler.api.vo.WorkflowDefinitionCountVO;
+import org.apache.dolphinscheduler.api.vo.WorkflowInstanceCountVO;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.CommandType;
 import org.apache.dolphinscheduler.common.enums.UserType;
 import org.apache.dolphinscheduler.common.utils.DateUtils;
-import org.apache.dolphinscheduler.common.utils.TriFunction;
+import org.apache.dolphinscheduler.dao.entity.Command;
 import org.apache.dolphinscheduler.dao.entity.CommandCount;
-import org.apache.dolphinscheduler.dao.entity.DefinitionGroupByUser;
+import org.apache.dolphinscheduler.dao.entity.ErrorCommand;
 import org.apache.dolphinscheduler.dao.entity.ExecuteStatusCount;
+import org.apache.dolphinscheduler.dao.entity.ProcessDefinition;
 import org.apache.dolphinscheduler.dao.entity.Project;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.User;
@@ -42,14 +48,16 @@ import org.apache.dolphinscheduler.dao.mapper.CommandMapper;
 import org.apache.dolphinscheduler.dao.mapper.ErrorCommandMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProcessDefinitionMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProcessInstanceMapper;
-import org.apache.dolphinscheduler.dao.mapper.ProcessTaskRelationMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProjectMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskDefinitionMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskInstanceMapper;
+import org.apache.dolphinscheduler.dao.model.TaskInstanceStatusCountDto;
+import org.apache.dolphinscheduler.dao.model.WorkflowDefinitionCountDto;
+import org.apache.dolphinscheduler.dao.model.WorkflowInstanceStatusCountDto;
 import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.lang3.tuple.Pair;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -58,7 +66,6 @@ import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
 import java.util.stream.Collectors;
@@ -68,6 +75,10 @@ import lombok.extern.slf4j.Slf4j;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
 
+import com.baomidou.mybatisplus.core.metadata.IPage;
+import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
+import com.google.common.collect.Lists;
+
 /**
  * data analysis service impl
  */
@@ -99,182 +110,94 @@ public class DataAnalysisServiceImpl extends BaseServiceImpl implements DataAnal
     @Autowired
     private TaskDefinitionMapper taskDefinitionMapper;
 
-    @Autowired
-    private ProcessTaskRelationMapper relationMapper;
-    /**
-     * statistical task instance status data
-     *
-     * @param loginUser   login user
-     * @param projectCode project code
-     * @param startDate   start date
-     * @param endDate     end date
-     * @return task state count data
-     */
     @Override
-    public Map<String, Object> countTaskStateByProject(User loginUser, long projectCode, String startDate,
-                                                       String endDate) {
-
-        return countStateByProject(
-                loginUser,
-                projectCode,
-                startDate,
-                endDate,
-                this::countTaskInstanceAllStatesByProjectCodes);
-    }
-
-    /**
-     * statistical process instance status data
-     *
-     * @param loginUser   login user
-     * @param projectCode project code
-     * @param startDate   start date
-     * @param endDate     end date
-     * @return process instance state count data
-     */
-    @Override
-    public Map<String, Object> countProcessInstanceStateByProject(User loginUser, long projectCode, String startDate,
+    public TaskInstanceCountVO getTaskInstanceStateCountByProject(User loginUser,
+                                                                  Long projectCode,
+                                                                  String startDate,
                                                                   String endDate) {
-        Map<String, Object> result = this.countStateByProject(
-                loginUser,
-                projectCode,
-                startDate,
-                endDate,
-                (start, end, projectCodes) -> this.processInstanceMapper.countInstanceStateByProjectCodes(start, end,
-                        projectCodes));
-
-        // process state count needs to remove state of forced success
-        if (result.containsKey(Constants.STATUS) && result.get(Constants.STATUS).equals(Status.SUCCESS)) {
-            ((TaskCountDto) result.get(Constants.DATA_LIST))
-                    .removeStateFromCountList(TaskExecutionStatus.FORCED_SUCCESS);
-        }
-        return result;
+        projectService.checkProjectAndAuthThrowException(loginUser, projectCode, PROJECT_OVERVIEW);
+        Date start = startDate == null ? null : transformDate(startDate);
+        Date end = endDate == null ? null : transformDate(endDate);
+        List<TaskInstanceStatusCountDto> taskInstanceStatusCounts =
+                taskInstanceMapper.countTaskInstanceStateByProjectCodes(start, end, Lists.newArrayList(projectCode));
+        return TaskInstanceCountVO.of(taskInstanceStatusCounts);
     }
 
-    /**
-     * Wrapper function of counting process instance state and task state
-     *
-     * @param loginUser   login user
-     * @param projectCode project code
-     * @param startDate   start date
-     * @param endDate     end date
-     */
-    private Map<String, Object> countStateByProject(User loginUser, long projectCode, String startDate, String endDate,
-                                                    TriFunction<Date, Date, Long[], List<ExecuteStatusCount>> instanceStateCounter) {
-        Map<String, Object> result = new HashMap<>();
-        if (projectCode != 0) {
-            Project project = projectMapper.queryByCode(projectCode);
-            result = projectService.checkProjectAndAuth(loginUser, project, projectCode, PROJECT_OVERVIEW);
-            if (result.get(Constants.STATUS) != Status.SUCCESS) {
-                return result;
-            }
-        }
-
-        Date start = null;
-        Date end = null;
-        if (!StringUtils.isEmpty(startDate) && !StringUtils.isEmpty(endDate)) {
-            start = DateUtils.stringToDate(startDate);
-            end = DateUtils.stringToDate(endDate);
-            if (Objects.isNull(start) || Objects.isNull(end)) {
-                log.warn("Parameter startDate or endDate is invalid.");
-                putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.START_END_DATE);
-                return result;
-            }
-        }
-        Pair<Set<Integer>, Map<String, Object>> projectIds = getProjectIds(loginUser, result);
-        if (projectIds.getRight() != null) {
-            return projectIds.getRight();
-        }
-        Long[] projectCodeArray =
-                projectCode == 0 ? getProjectCodesArrays(projectIds.getLeft()) : new Long[]{projectCode};
-        List<ExecuteStatusCount> processInstanceStateCounts = new ArrayList<>();
-
-        if (projectCodeArray.length != 0 || loginUser.getUserType() == UserType.ADMIN_USER) {
-            processInstanceStateCounts = instanceStateCounter.apply(start, end, projectCodeArray);
-        }
-
-        if (processInstanceStateCounts != null) {
-            TaskCountDto taskCountResult = new TaskCountDto(processInstanceStateCounts);
-            result.put(Constants.DATA_LIST, taskCountResult);
-            putMsg(result, Status.SUCCESS);
-        }
-        return result;
-    }
-
-    /**
-     * statistics the process definition quantities of a certain person
-     * <p>
-     * We only need projects which users have permission to see to determine whether the definition belongs to the user or not.
-     *
-     * @param loginUser   login user
-     * @param projectCode project code
-     * @return definition count data
-     */
     @Override
-    public Map<String, Object> countDefinitionByUser(User loginUser, long projectCode) {
-        Map<String, Object> result = new HashMap<>();
-        if (projectCode != 0) {
-            Project project = projectMapper.queryByCode(projectCode);
-            result = projectService.checkProjectAndAuth(loginUser, project, projectCode, PROJECT_OVERVIEW);
-            if (result.get(Constants.STATUS) != Status.SUCCESS) {
-                return result;
-            }
+    public TaskInstanceCountVO getAllTaskInstanceStateCount(User loginUser,
+                                                            String startDate,
+                                                            String endDate) {
+        List<Long> projectCodes = projectService.getAuthorizedProjectCodes(loginUser);
+        if (CollectionUtils.isEmpty(projectCodes)) {
+            return TaskInstanceCountVO.empty();
         }
-
-        List<DefinitionGroupByUser> defineGroupByUsers = new ArrayList<>();
-        Pair<Set<Integer>, Map<String, Object>> projectIds = getProjectIds(loginUser, result);
-        if (projectIds.getRight() != null) {
-            List<DefinitionGroupByUser> emptyList = new ArrayList<>();
-            DefineUserDto dto = new DefineUserDto(emptyList);
-            result.put(Constants.DATA_LIST, dto);
-            putMsg(result, Status.SUCCESS);
-            return result;
-        }
-        Long[] projectCodeArray =
-                projectCode == 0 ? getProjectCodesArrays(projectIds.getLeft()) : new Long[]{projectCode};
-        if (projectCodeArray.length != 0 || loginUser.getUserType() == UserType.ADMIN_USER) {
-            defineGroupByUsers = processDefinitionMapper.countDefinitionByProjectCodes(projectCodeArray);
-        }
-
-        DefineUserDto dto = new DefineUserDto(defineGroupByUsers);
-        result.put(Constants.DATA_LIST, dto);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        Date start = startDate == null ? null : transformDate(startDate);
+        Date end = endDate == null ? null : transformDate(endDate);
+        List<TaskInstanceStatusCountDto> taskInstanceStatusCounts =
+                taskInstanceMapper.countTaskInstanceStateByProjectCodes(start, end, projectCodes);
+        return TaskInstanceCountVO.of(taskInstanceStatusCounts);
     }
 
-    /**
-     * statistical command status data
-     *
-     * @param loginUser login user
-     * @return command state count data
-     */
     @Override
-    public Map<String, Object> countCommandState(User loginUser) {
-        Map<String, Object> result = new HashMap<>();
+    public WorkflowInstanceCountVO getWorkflowInstanceStateCountByProject(User loginUser,
+                                                                          Long projectCode,
+                                                                          String startDate,
+                                                                          String endDate) {
+        projectService.checkProjectAndAuthThrowException(loginUser, projectCode, PROJECT_OVERVIEW);
+        Date start = startDate == null ? null : transformDate(startDate);
+        Date end = endDate == null ? null : transformDate(endDate);
+        List<WorkflowInstanceStatusCountDto> workflowInstanceStatusCountDtos = processInstanceMapper
+                .countWorkflowInstanceStateByProjectCodes(start, end, Lists.newArrayList(projectCode));
+        return WorkflowInstanceCountVO.of(workflowInstanceStatusCountDtos);
+    }
 
-        /**
-         * find all the task lists in the project under the user
-         * statistics based on task status execution, failure, completion, wait, total
-         */
-        Date start = null;
-        Date end = null;
-        Pair<Set<Integer>, Map<String, Object>> projectIds = getProjectIds(loginUser, result);
-        if (projectIds.getRight() != null) {
-            List<CommandStateCount> noData = Arrays.stream(CommandType.values())
-                    .map(commandType -> new CommandStateCount(0, 0, commandType)).collect(Collectors.toList());
-            result.put(Constants.DATA_LIST, noData);
-            putMsg(result, Status.SUCCESS);
-            return result;
+    @Override
+    public WorkflowInstanceCountVO getAllWorkflowInstanceStateCount(User loginUser,
+                                                                    String startDate,
+                                                                    String endDate) {
+        List<Long> projectCodes = projectService.getAuthorizedProjectCodes(loginUser);
+        if (CollectionUtils.isEmpty(projectCodes)) {
+            return WorkflowInstanceCountVO.empty();
         }
-        Long[] projectCodeArray = getProjectCodesArrays(projectIds.getLeft());
+        Date start = startDate == null ? null : transformDate(startDate);
+        Date end = endDate == null ? null : transformDate(endDate);
+
+        List<WorkflowInstanceStatusCountDto> workflowInstanceStatusCountDtos =
+                processInstanceMapper.countWorkflowInstanceStateByProjectCodes(start, end, projectCodes);
+        return WorkflowInstanceCountVO.of(workflowInstanceStatusCountDtos);
+    }
+
+    @Override
+    public WorkflowDefinitionCountVO getWorkflowDefinitionCountByProject(User loginUser, Long projectCode) {
+        projectService.checkProjectAndAuthThrowException(loginUser, projectCode, PROJECT_OVERVIEW);
+        List<WorkflowDefinitionCountDto> workflowDefinitionCounts =
+                processDefinitionMapper.countDefinitionByProjectCodes(Lists.newArrayList(projectCode));
+        return WorkflowDefinitionCountVO.of(workflowDefinitionCounts);
+    }
+
+    @Override
+    public WorkflowDefinitionCountVO getAllWorkflowDefinitionCount(User loginUser) {
+        List<Long> projectCodes = projectService.getAuthorizedProjectCodes(loginUser);
+        if (CollectionUtils.isEmpty(projectCodes)) {
+            return WorkflowDefinitionCountVO.empty();
+        }
+        return WorkflowDefinitionCountVO.of(processDefinitionMapper.countDefinitionByProjectCodes(projectCodes));
+    }
+
+    @Override
+    public List<CommandStateCount> countCommandState(User loginUser) {
+
+        List<Long> projectCodes = projectService.getAuthorizedProjectCodes(loginUser);
+
         // count normal command state
         Map<CommandType, Integer> normalCountCommandCounts =
-                commandMapper.countCommandState(start, end, projectCodeArray)
+                commandMapper.countCommandState(null, null, projectCodes)
                         .stream()
                         .collect(Collectors.toMap(CommandCount::getCommandType, CommandCount::getCount));
 
         // count error command state
         Map<CommandType, Integer> errorCommandCounts =
-                errorCommandMapper.countCommandState(start, end, projectCodeArray)
+                errorCommandMapper.countCommandState(null, null, projectCodes)
                         .stream()
                         .collect(Collectors.toMap(CommandCount::getCommandType, CommandCount::getCount));
 
@@ -284,30 +207,7 @@ public class DataAnalysisServiceImpl extends BaseServiceImpl implements DataAnal
                         normalCountCommandCounts.getOrDefault(commandType, 0),
                         commandType))
                 .collect(Collectors.toList());
-
-        result.put(Constants.DATA_LIST, list);
-        putMsg(result, Status.SUCCESS);
-        return result;
-    }
-
-    private Pair<Set<Integer>, Map<String, Object>> getProjectIds(User loginUser, Map<String, Object> result) {
-        Set<Integer> projectIds = resourcePermissionCheckService
-                .userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, loginUser.getId(), log);
-        if (projectIds.isEmpty()) {
-            List<ExecuteStatusCount> taskInstanceStateCounts = new ArrayList<>();
-            result.put(Constants.DATA_LIST, new TaskCountDto(taskInstanceStateCounts));
-            putMsg(result, Status.SUCCESS);
-            return Pair.of(null, result);
-        }
-        return Pair.of(projectIds, null);
-    }
-
-    private Long[] getProjectCodesArrays(Set<Integer> projectIds) {
-        List<Project> projects = projectMapper.selectBatchIds(projectIds);
-        List<Long> codeList = projects.stream().map(Project::getCode).collect(Collectors.toList());
-        Long[] projectCodeArray = new Long[codeList.size()];
-        codeList.toArray(projectCodeArray);
-        return projectCodeArray;
+        return list;
     }
 
     /**
@@ -316,85 +216,30 @@ public class DataAnalysisServiceImpl extends BaseServiceImpl implements DataAnal
      * @return queue state count data
      */
     @Override
-    public Map<String, Object> countQueueState(User loginUser) {
-        Map<String, Object> result = new HashMap<>();
+    public Map<String, Integer> countQueueState(User loginUser) {
 
         // TODO need to add detail data info
+        // todo: refactor this method, don't use Map
         Map<String, Integer> dataMap = new HashMap<>();
         dataMap.put("taskQueue", 0);
         dataMap.put("taskKill", 0);
-        result.put(Constants.DATA_LIST, dataMap);
-        putMsg(result, Status.SUCCESS);
-        return result;
-    }
-
-    @Override
-    public List<ExecuteStatusCount> countTaskInstanceAllStatesByProjectCodes(Date startTime, Date endTime,
-                                                                             Long[] projectCodes) {
-        Optional<List<ExecuteStatusCount>> startTimeStates = Optional.ofNullable(
-                this.taskInstanceMapper.countTaskInstanceStateByProjectCodes(startTime, endTime, projectCodes));
-
-        List<TaskExecutionStatus> allState = Arrays.stream(TaskExecutionStatus.values()).collect(Collectors.toList());
-        List<TaskExecutionStatus> needRecountState;
-        if (startTimeStates.isPresent() && startTimeStates.get().size() != 0) {
-            List<TaskExecutionStatus> instanceState =
-                    startTimeStates.get().stream().map(ExecuteStatusCount::getState).collect(Collectors.toList());
-            // value 0 state need to recount by submit time
-            needRecountState =
-                    allState.stream().filter(ele -> !instanceState.contains(ele)).collect(Collectors.toList());
-            if (needRecountState.size() == 0) {
-                return startTimeStates.get();
-            }
-        } else {
-            needRecountState = allState;
-        }
-
-        // use submit time to recount when 0
-        // if have any issues with this code, should change to specified states 0 8 9 17 not state count is 0
-        List<ExecuteStatusCount> recounts = this.taskInstanceMapper
-                .countTaskInstanceStateByProjectCodesAndStatesBySubmitTime(startTime, endTime, projectCodes,
-                        needRecountState);
-        startTimeStates.orElseGet(ArrayList::new).addAll(recounts);
-
-        return startTimeStates.orElse(null);
-    }
-    /**
-     * query all workflow count
-     *
-     * @param loginUser login user
-     * @return workflow count
-     */
-    @Override
-    public Map<String, Object> queryAllWorkflowCounts(User loginUser) {
-        Map<String, Object> result = new HashMap<>();
-        int count = 0;
-        Set<Integer> projectIds = resourcePermissionCheckService
-                .userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, loginUser.getId(), log);
-        if (!projectIds.isEmpty()) {
-            List<Project> projects = projectMapper.selectBatchIds(projectIds);
-            List<Long> projectCodes = projects.stream().map(project -> project.getCode()).collect(Collectors.toList());
-            count = projectMapper.queryAllWorkflowCounts(projectCodes);
-        }
-        result.put("data", "AllWorkflowCounts = " + count);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        return dataMap;
     }
 
     /**
      * query all workflow states count
-     * @param loginUser login user
+     *
+     * @param loginUser              login user
      * @param statisticsStateRequest statisticsStateRequest
      * @return workflow states count
      */
     @Override
-    public Map<String, Object> countWorkflowStates(User loginUser,
-                                                   StatisticsStateRequest statisticsStateRequest) {
-        Map<String, Object> result = new HashMap<>();
+    public TaskCountDto countWorkflowStates(User loginUser,
+                                            StatisticsStateRequest statisticsStateRequest) {
         Set<Integer> projectIds = resourcePermissionCheckService
                 .userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, loginUser.getId(), log);
         if (projectIds.isEmpty()) {
-            putMsg(result, Status.SUCCESS);
-            return result;
+            return new TaskCountDto(Collections.emptyList());
         }
 
         String projectName = statisticsStateRequest.getProjectName();
@@ -425,50 +270,42 @@ public class DataAnalysisServiceImpl extends BaseServiceImpl implements DataAnal
 
         List<ExecuteStatusCount> executeStatusCounts = processInstanceMapper.countInstanceStateV2(
                 startTime, endTime, projectCode, workflowCode, model, projectIds);
-        TaskCountDto taskCountResult = new TaskCountDto(executeStatusCounts);
-        result.put(Constants.DATA_LIST, taskCountResult);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        return new TaskCountDto(executeStatusCounts);
     }
 
     /**
      * query one workflow states count
-     * @param loginUser login user
+     *
+     * @param loginUser    login user
      * @param workflowCode workflowCode
      * @return workflow states count
      */
     @Override
-    public Map<String, Object> countOneWorkflowStates(User loginUser, Long workflowCode) {
-        Map<String, Object> result = new HashMap<>();
-        Project project = projectMapper.queryByCode(workflowCode);
-        boolean hasProjectAndWritePerm = projectService.hasProjectAndWritePerm(loginUser, project, result);
-        if (!hasProjectAndWritePerm) {
-            return result;
+    public TaskCountDto countOneWorkflowStates(User loginUser, Long workflowCode) {
+        ProcessDefinition processDefinition = processDefinitionMapper.queryByCode(workflowCode);
+        if (processDefinition == null) {
+            throw new ServiceException(Status.PROCESS_DEFINE_NOT_EXIST, workflowCode);
         }
-        List<ExecuteStatusCount> executeStatusCounts = processInstanceMapper.countInstanceStateV2(
-                null, null, null, workflowCode, Constants.QUERY_ALL_ON_WORKFLOW, null);
-        if (executeStatusCounts != null) {
-            TaskCountDto taskCountResult = new TaskCountDto(executeStatusCounts);
-            result.put(Constants.DATA_LIST, taskCountResult);
-            putMsg(result, Status.SUCCESS);
-        }
-        return result;
+        projectService.checkHasProjectWritePermissionThrowException(loginUser, processDefinition.getProjectCode());
+
+        List<ExecuteStatusCount> executeStatusCounts = processInstanceMapper.countInstanceStateV2(null, null, null,
+                workflowCode, Constants.QUERY_ALL_ON_WORKFLOW, null);
+        return new TaskCountDto(executeStatusCounts);
     }
 
     /**
      * query all task states count
-     * @param loginUser login user
+     *
+     * @param loginUser              login user
      * @param statisticsStateRequest statisticsStateRequest
      * @return tasks states count
      */
     @Override
-    public Map<String, Object> countTaskStates(User loginUser, StatisticsStateRequest statisticsStateRequest) {
-        Map<String, Object> result = new HashMap<>();
+    public TaskCountDto countTaskStates(User loginUser, StatisticsStateRequest statisticsStateRequest) {
         Set<Integer> projectIds = resourcePermissionCheckService
                 .userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, loginUser.getId(), log);
         if (projectIds.isEmpty()) {
-            putMsg(result, Status.SUCCESS);
-            return result;
+            return new TaskCountDto(Collections.emptyList());
         }
         String projectName = statisticsStateRequest.getProjectName();
         String workflowName = statisticsStateRequest.getWorkflowName();
@@ -508,10 +345,7 @@ public class DataAnalysisServiceImpl extends BaseServiceImpl implements DataAnal
                 taskInstanceMapper.countTaskInstanceStateByProjectIdsV2(startTime, endTime, projectIds));
         List<TaskExecutionStatus> needRecountState = setOptional(startTimeStates);
         if (needRecountState.size() == 0) {
-            TaskCountDto taskCountResult = new TaskCountDto(startTimeStates.get());
-            result.put(Constants.DATA_LIST, taskCountResult);
-            putMsg(result, Status.SUCCESS);
-            return result;
+            return new TaskCountDto(startTimeStates.get());
         }
         List<ExecuteStatusCount> recounts = this.taskInstanceMapper
                 .countTaskInstanceStateByProjectCodesAndStatesBySubmitTimeV2(startTime, endTime, projectCode,
@@ -519,37 +353,29 @@ public class DataAnalysisServiceImpl extends BaseServiceImpl implements DataAnal
                         needRecountState);
         startTimeStates.orElseGet(ArrayList::new).addAll(recounts);
         List<ExecuteStatusCount> executeStatusCounts = startTimeStates.orElse(null);
-        TaskCountDto taskCountResult = new TaskCountDto(executeStatusCounts);
-        result.put(Constants.DATA_LIST, taskCountResult);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        return new TaskCountDto(executeStatusCounts);
     }
 
     /**
      * query one task states count
+     *
      * @param loginUser login user
-     * @param taskCode taskCode
+     * @param taskCode  taskCode
      * @return tasks states count
      */
     @Override
-    public Map<String, Object> countOneTaskStates(User loginUser, Long taskCode) {
-        Map<String, Object> result = new HashMap<>();
+    public TaskCountDto countOneTaskStates(User loginUser, Long taskCode) {
         TaskDefinition taskDefinition = taskDefinitionMapper.queryByCode(taskCode);
         long projectCode = taskDefinition.getProjectCode();
         Project project = projectMapper.queryByCode(projectCode);
-        boolean hasProjectAndWritePerm = projectService.hasProjectAndWritePerm(loginUser, project, result);
-        if (!hasProjectAndWritePerm) {
-            return result;
-        }
+        projectService.checkHasProjectWritePermissionThrowException(loginUser, project);
+
         Set<Integer> projectId = Collections.singleton(project.getId());
         Optional<List<ExecuteStatusCount>> startTimeStates = Optional.ofNullable(
                 taskInstanceMapper.countTaskInstanceStateByProjectIdsV2(null, null, projectId));
         List<TaskExecutionStatus> needRecountState = setOptional(startTimeStates);
         if (needRecountState.size() == 0) {
-            TaskCountDto taskCountResult = new TaskCountDto(startTimeStates.get());
-            result.put(Constants.DATA_LIST, taskCountResult);
-            putMsg(result, Status.SUCCESS);
-            return result;
+            return new TaskCountDto(startTimeStates.get());
         }
         List<ExecuteStatusCount> recounts = this.taskInstanceMapper
                 .countTaskInstanceStateByProjectCodesAndStatesBySubmitTimeV2(null, null, projectCode, null, taskCode,
@@ -557,10 +383,67 @@ public class DataAnalysisServiceImpl extends BaseServiceImpl implements DataAnal
                         needRecountState);
         startTimeStates.orElseGet(ArrayList::new).addAll(recounts);
         List<ExecuteStatusCount> executeStatusCounts = startTimeStates.orElse(null);
-        TaskCountDto taskCountResult = new TaskCountDto(executeStatusCounts);
-        result.put(Constants.DATA_LIST, taskCountResult);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        return new TaskCountDto(executeStatusCounts);
+    }
+
+    @Override
+    public PageInfo<Command> listPendingCommands(User loginUser, Long projectCode, Integer pageNo, Integer pageSize) {
+        Page<Command> page = new Page<>(pageNo, pageSize);
+        if (loginUser.getUserType().equals(UserType.ADMIN_USER)) {
+            IPage<Command> commandIPage = commandMapper.queryCommandPage(page);
+            return PageInfo.of(commandIPage);
+        }
+
+        List<Long> workflowDefinitionCodes = getAuthDefinitionCodes(loginUser, projectCode);
+
+        if (workflowDefinitionCodes.isEmpty()) {
+            return PageInfo.of(pageNo, pageSize);
+        }
+
+        IPage<Command> commandIPage =
+                commandMapper.queryCommandPageByIds(page, new ArrayList<>(workflowDefinitionCodes));
+        return PageInfo.of(commandIPage);
+    }
+
+    @Override
+    public PageInfo<ErrorCommand> listErrorCommand(User loginUser, Long projectCode, Integer pageNo, Integer pageSize) {
+        Page<ErrorCommand> page = new Page<>(pageNo, pageSize);
+        if (loginUser.getUserType().equals(UserType.ADMIN_USER)) {
+            IPage<ErrorCommand> commandIPage = errorCommandMapper.queryErrorCommandPage(page);
+            return PageInfo.of(commandIPage);
+        }
+
+        List<Long> workflowDefinitionCodes = getAuthDefinitionCodes(loginUser, projectCode);
+
+        if (workflowDefinitionCodes.isEmpty()) {
+            return PageInfo.of(pageNo, pageSize);
+        }
+
+        IPage<ErrorCommand> commandIPage =
+                errorCommandMapper.queryErrorCommandPageByIds(page, new ArrayList<>(workflowDefinitionCodes));
+        return PageInfo.of(commandIPage);
+    }
+
+    private List<Long> getAuthDefinitionCodes(User loginUser, Long projectCode) {
+        Set<Integer> projectIds = resourcePermissionCheckService
+                .userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, loginUser.getId(), log);
+        if (CollectionUtils.isEmpty(projectIds)) {
+            return Collections.emptyList();
+        }
+        List<Long> projectCodes = projectMapper.selectBatchIds(projectIds)
+                .stream()
+                .map(Project::getCode)
+                .collect(Collectors.toList());
+
+        if (projectCode != null) {
+            if (!projectCodes.contains(projectCode)) {
+                return Collections.emptyList();
+            }
+
+            projectCodes = Collections.singletonList(projectCode);
+        }
+
+        return processDefinitionMapper.queryDefinitionCodeListByProjectCodes(projectCodes);
     }
 
     /**
@@ -568,48 +451,27 @@ public class DataAnalysisServiceImpl extends BaseServiceImpl implements DataAnal
      * <p>
      * We only need projects which users have permission to see to determine whether the definition belongs to the user or not.
      *
-     * @param loginUser   login user
-     * @param projectCode project code
+     * @param loginUser login user
      * @return definition count data
      */
     @Override
-    public Map<String, Object> countDefinitionByUserV2(User loginUser, Long projectCode, Integer userId,
-                                                       Integer releaseState) {
-        Map<String, Object> result = new HashMap<>();
-        if (null != projectCode) {
-            Project project = projectMapper.queryByCode(projectCode);
-            result = projectService.checkProjectAndAuth(loginUser, project, projectCode, PROJECT_OVERVIEW);
-            if (result.get(Constants.STATUS) != Status.SUCCESS) {
-                return result;
-            }
+    public DefineUserDto countDefinitionByUserV2(User loginUser,
+                                                 Integer userId,
+                                                 Integer releaseState) {
+        Set<Integer> projectIds = resourcePermissionCheckService
+                .userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, loginUser.getId(), log);
+        if (CollectionUtils.isEmpty(projectIds)) {
+            return new DefineUserDto(Collections.emptyList());
         }
+        List<Long> projectCodes = projectMapper.selectBatchIds(projectIds)
+                .stream()
+                .map(Project::getCode)
+                .collect(Collectors.toList());
 
-        List<DefinitionGroupByUser> defineGroupByUsers = new ArrayList<>();
-        Pair<Set<Integer>, Map<String, Object>> projectIds = getProjectIds(loginUser, result);
-        if (projectIds.getRight() != null) {
-            List<DefinitionGroupByUser> emptyList = new ArrayList<>();
-            DefineUserDto dto = new DefineUserDto(emptyList);
-            result.put(Constants.DATA_LIST, dto);
-            putMsg(result, Status.SUCCESS);
-            return result;
-        }
-        Long[] projectCodeArray =
-                projectCode == null ? getProjectCodesArrays(projectIds.getLeft()) : new Long[]{projectCode};
-        if (projectCodeArray.length != 0 || loginUser.getUserType() == UserType.ADMIN_USER) {
-            defineGroupByUsers =
-                    processDefinitionMapper.countDefinitionByProjectCodesV2(projectCodeArray, userId, releaseState);
-        }
+        List<WorkflowDefinitionCountDto> workflowDefinitionCountDtos =
+                processDefinitionMapper.countDefinitionByProjectCodesV2(projectCodes, userId, releaseState);
 
-        DefineUserDto dto = new DefineUserDto(defineGroupByUsers);
-        result.put(Constants.DATA_LIST, dto);
-        putMsg(result, Status.SUCCESS);
-        return result;
-    }
-
-    @Override
-    public Long getProjectCodeByName(String projectName) {
-        Project project = projectMapper.queryByName(projectName);
-        return project == null ? 0 : project.getCode();
+        return new DefineUserDto(workflowDefinitionCountDtos);
     }
 
     private List<TaskExecutionStatus> setOptional(Optional<List<ExecuteStatusCount>> startTimeStates) {
