@@ -39,7 +39,7 @@ import org.apache.dolphinscheduler.api.service.ProjectService;
 import org.apache.dolphinscheduler.api.service.TaskDefinitionService;
 import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.api.utils.Result;
-import org.apache.dolphinscheduler.api.vo.TaskDefinitionVo;
+import org.apache.dolphinscheduler.api.vo.TaskDefinitionVO;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.ConditionType;
@@ -51,6 +51,7 @@ import org.apache.dolphinscheduler.common.utils.CodeGenerateUtils;
 import org.apache.dolphinscheduler.common.utils.CodeGenerateUtils.CodeGenerateException;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.dao.entity.ProcessDefinition;
+import org.apache.dolphinscheduler.dao.entity.ProcessDefinitionLog;
 import org.apache.dolphinscheduler.dao.entity.ProcessTaskRelation;
 import org.apache.dolphinscheduler.dao.entity.ProcessTaskRelationLog;
 import org.apache.dolphinscheduler.dao.entity.Project;
@@ -58,6 +59,7 @@ import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinitionLog;
 import org.apache.dolphinscheduler.dao.entity.TaskMainInfo;
 import org.apache.dolphinscheduler.dao.entity.User;
+import org.apache.dolphinscheduler.dao.mapper.ProcessDefinitionLogMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProcessDefinitionMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProcessTaskRelationMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProjectMapper;
@@ -73,7 +75,6 @@ import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.collections4.MapUtils;
 import org.apache.commons.lang3.StringUtils;
 
-import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -103,8 +104,6 @@ import com.google.common.collect.Lists;
 @Slf4j
 public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDefinitionService {
 
-    private static final String RELEASESTATE = "releaseState";
-
     @Autowired
     private ProjectMapper projectMapper;
 
@@ -136,16 +135,16 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
     private ProcessService processService;
 
     @Autowired
-    private TaskPluginManager taskPluginManager;
+    private ProcessDefinitionService processDefinitionService;
 
     @Autowired
-    private ProcessDefinitionService processDefinitionService;
+    private ProcessDefinitionLogMapper processDefinitionLogMapper;
 
     /**
      * create task definition
      *
-     * @param loginUser login user
-     * @param projectCode project code
+     * @param loginUser          login user
+     * @param projectCode        project code
      * @param taskDefinitionJson task definition json
      */
     @Transactional
@@ -168,7 +167,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
             return result;
         }
         for (TaskDefinitionLog taskDefinitionLog : taskDefinitionLogs) {
-            if (!taskPluginManager.checkTaskParameters(ParametersNode.builder()
+            if (!TaskPluginManager.checkTaskParameters(ParametersNode.builder()
                     .taskType(taskDefinitionLog.getTaskType())
                     .taskParams(taskDefinitionLog.getTaskParams())
                     .dependence(taskDefinitionLog.getDependence())
@@ -209,7 +208,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
         Project project = projectMapper.queryByCode(taskDefinition.getProjectCode());
         projectService.checkProjectAndAuthThrowException(user, project, permissions);
 
-        if (!taskPluginManager.checkTaskParameters(ParametersNode.builder()
+        if (!TaskPluginManager.checkTaskParameters(ParametersNode.builder()
                 .taskType(taskDefinition.getTaskType())
                 .taskParams(taskDefinition.getTaskParams())
                 .dependence(taskDefinition.getDependence())
@@ -239,7 +238,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
     /**
      * Create resource task definition
      *
-     * @param loginUser login user
+     * @param loginUser         login user
      * @param taskCreateRequest task definition json
      * @return new TaskDefinition have created
      */
@@ -260,7 +259,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
 
         long taskDefinitionCode;
         try {
-            taskDefinitionCode = CodeGenerateUtils.getInstance().genCode();
+            taskDefinitionCode = CodeGenerateUtils.genCode();
         } catch (CodeGenerateException e) {
             throw new ServiceException(Status.INTERNAL_SERVER_ERROR_ARGS);
         }
@@ -283,11 +282,11 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
     /**
      * create single task definition that binds the workflow
      *
-     * @param loginUser login user
-     * @param projectCode project code
+     * @param loginUser             login user
+     * @param projectCode           project code
      * @param processDefinitionCode process definition code
      * @param taskDefinitionJsonObj task definition json object
-     * @param upstreamCodes upstream task codes, sep comma
+     * @param upstreamCodes         upstream task codes, sep comma
      * @return create result code
      */
     @Transactional
@@ -322,7 +321,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
             putMsg(result, Status.DATA_IS_NOT_VALID, taskDefinitionJsonObj);
             return result;
         }
-        if (!taskPluginManager.checkTaskParameters(ParametersNode.builder()
+        if (!TaskPluginManager.checkTaskParameters(ParametersNode.builder()
                 .taskType(taskDefinition.getTaskType())
                 .taskParams(taskDefinition.getTaskParams())
                 .dependence(taskDefinition.getDependence())
@@ -333,10 +332,10 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
         }
         long taskCode = taskDefinition.getCode();
         if (taskCode == 0) {
-            taskDefinition.setCode(CodeGenerateUtils.getInstance().genCode());
+            taskDefinition.setCode(CodeGenerateUtils.genCode());
         }
         List<ProcessTaskRelationLog> processTaskRelationLogList =
-                processTaskRelationMapper.queryByProcessCode(projectCode, processDefinitionCode)
+                processTaskRelationMapper.queryByProcessCode(processDefinitionCode)
                         .stream()
                         .map(ProcessTaskRelationLog::new)
                         .collect(Collectors.toList());
@@ -409,10 +408,10 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
     /**
      * query task definition
      *
-     * @param loginUser login user
+     * @param loginUser   login user
      * @param projectCode project code
      * @param processCode process code
-     * @param taskName task name
+     * @param taskName    task name
      */
     @Override
     public Map<String, Object> queryTaskDefinitionByName(User loginUser, long projectCode, long processCode,
@@ -470,12 +469,12 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
 
     /**
      * Delete resource task definition by code
-     *
+     * <p>
      * Only task release state offline and no downstream tasks can be deleted, will also remove the exists
      * task relation [upstreamTaskCode, taskCode]
      *
      * @param loginUser login user
-     * @param taskCode task code
+     * @param taskCode  task code
      */
     @Transactional
     @Override
@@ -499,8 +498,8 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
                     "Task definition has upstream tasks, start handle them after delete task, taskDefinitionCode:{}.",
                     taskCode);
             long processDefinitionCode = taskRelationList.get(0).getProcessDefinitionCode();
-            List<ProcessTaskRelation> processTaskRelations = processTaskRelationMapper
-                    .queryByProcessCode(taskDefinition.getProjectCode(), processDefinitionCode);
+            List<ProcessTaskRelation> processTaskRelations =
+                    processTaskRelationMapper.queryByProcessCode(processDefinitionCode);
             List<ProcessTaskRelation> relationList = processTaskRelations.stream()
                     .filter(r -> r.getPostTaskCode() != taskCode).collect(Collectors.toList());
             updateDag(loginUser, processDefinitionCode, relationList, Lists.newArrayList());
@@ -543,9 +542,9 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
     /**
      * update task definition
      *
-     * @param loginUser login user
-     * @param projectCode project code
-     * @param taskCode task code
+     * @param loginUser             login user
+     * @param projectCode           project code
+     * @param taskCode              task code
      * @param taskDefinitionJsonObj task definition json object
      */
     @Transactional
@@ -566,7 +565,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
                     taskCode);
             long processDefinitionCode = taskRelationList.get(0).getProcessDefinitionCode();
             List<ProcessTaskRelation> processTaskRelations =
-                    processTaskRelationMapper.queryByProcessCode(projectCode, processDefinitionCode);
+                    processTaskRelationMapper.queryByProcessCode(processDefinitionCode);
             updateDag(loginUser, processDefinitionCode, processTaskRelations,
                     Lists.newArrayList(taskDefinitionToUpdate));
         }
@@ -601,8 +600,8 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
     /**
      * update task definition
      *
-     * @param loginUser login user
-     * @param taskCode task code
+     * @param loginUser         login user
+     * @param taskCode          task code
      * @param taskUpdateRequest task definition json object
      * @return new TaskDefinition have updated
      */
@@ -616,13 +615,8 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
             throw new ServiceException(Status.TASK_DEFINITION_NOT_EXISTS, taskCode);
         }
 
-        TaskDefinition taskDefinitionUpdate;
-        try {
-            taskDefinitionUpdate = taskUpdateRequest.mergeIntoTaskDefinition(taskDefinitionOriginal);
-        } catch (InvocationTargetException | IllegalAccessException | InstantiationException
-                | NoSuchMethodException e) {
-            throw new ServiceException(Status.REQUEST_PARAMS_NOT_VALID_ERROR, taskUpdateRequest.toString());
-        }
+        TaskDefinition taskDefinitionUpdate = taskUpdateRequest.mergeIntoTaskDefinition(taskDefinitionOriginal);
+
         this.checkTaskDefinitionValid(loginUser, taskDefinitionUpdate, TASK_DEFINITION_UPDATE);
         this.TaskDefinitionUpdateValid(taskDefinitionOriginal, taskDefinitionUpdate);
 
@@ -640,8 +634,8 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
                     "Task definition has upstream tasks, start handle them after update task, taskDefinitionCode:{}.",
                     taskCode);
             long processDefinitionCode = taskRelationList.get(0).getProcessDefinitionCode();
-            List<ProcessTaskRelation> processTaskRelations = processTaskRelationMapper
-                    .queryByProcessCode(taskDefinitionUpdate.getProjectCode(), processDefinitionCode);
+            List<ProcessTaskRelation> processTaskRelations =
+                    processTaskRelationMapper.queryByProcessCode(processDefinitionCode);
             updateDag(loginUser, processDefinitionCode, processTaskRelations, Lists.newArrayList(taskDefinitionLog));
         }
         this.updateTaskUpstreams(loginUser, taskUpdateRequest.getWorkflowCode(), taskDefinitionUpdate.getCode(),
@@ -653,7 +647,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
      * Get resource task definition by code
      *
      * @param loginUser login user
-     * @param taskCode task code
+     * @param taskCode  task code
      * @return TaskDefinition
      */
     @Override
@@ -671,7 +665,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
     /**
      * Get resource task definition according to query parameter
      *
-     * @param loginUser login user
+     * @param loginUser         login user
      * @param taskFilterRequest taskFilterRequest object you want to filter the resource task definitions
      * @return TaskDefinitions of page
      */
@@ -738,7 +732,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
             putMsg(result, Status.DATA_IS_NOT_VALID, taskDefinitionJsonObj);
             return null;
         }
-        if (!taskPluginManager.checkTaskParameters(ParametersNode.builder()
+        if (!TaskPluginManager.checkTaskParameters(ParametersNode.builder()
                 .taskType(taskDefinitionToUpdate.getTaskType())
                 .taskParams(taskDefinitionToUpdate.getTaskParams())
                 .dependence(taskDefinitionToUpdate.getDependence())
@@ -781,20 +775,59 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
                     projectCode, taskCode, taskDefinitionToUpdate.getVersion());
         // update process task relation
         List<ProcessTaskRelation> processTaskRelations = processTaskRelationMapper
-                .queryByTaskCode(taskDefinitionToUpdate.getCode());
+                .queryProcessTaskRelationByTaskCodeAndTaskVersion(taskDefinitionToUpdate.getCode(),
+                        taskDefinition.getVersion());
         if (CollectionUtils.isNotEmpty(processTaskRelations)) {
-            for (ProcessTaskRelation processTaskRelation : processTaskRelations) {
-                if (taskCode == processTaskRelation.getPreTaskCode()) {
-                    processTaskRelation.setPreTaskVersion(version);
-                } else if (taskCode == processTaskRelation.getPostTaskCode()) {
-                    processTaskRelation.setPostTaskVersion(version);
+            Map<Long, List<ProcessTaskRelation>> processTaskRelationGroupList = processTaskRelations.stream()
+                    .collect(Collectors.groupingBy(ProcessTaskRelation::getProcessDefinitionCode));
+            for (Map.Entry<Long, List<ProcessTaskRelation>> processTaskRelationMap : processTaskRelationGroupList
+                    .entrySet()) {
+                Long processDefinitionCode = processTaskRelationMap.getKey();
+                int processDefinitionVersion =
+                        processDefinitionLogMapper.queryMaxVersionForDefinition(processDefinitionCode)
+                                + 1;
+                List<ProcessTaskRelation> processTaskRelationList = processTaskRelationMap.getValue();
+                for (ProcessTaskRelation processTaskRelation : processTaskRelationList) {
+                    if (taskCode == processTaskRelation.getPreTaskCode()) {
+                        processTaskRelation.setPreTaskVersion(version);
+                    } else if (taskCode == processTaskRelation.getPostTaskCode()) {
+                        processTaskRelation.setPostTaskVersion(version);
+                    }
+                    processTaskRelation.setProcessDefinitionVersion(processDefinitionVersion);
+                    int updateProcessDefinitionVersionCount =
+                            processTaskRelationMapper.updateProcessTaskRelationTaskVersion(processTaskRelation);
+                    if (updateProcessDefinitionVersionCount != 1) {
+                        log.error("batch update process task relation error, projectCode:{}, taskDefinitionCode:{}.",
+                                projectCode, taskCode);
+                        putMsg(result, Status.PROCESS_TASK_RELATION_BATCH_UPDATE_ERROR);
+                        throw new ServiceException(Status.PROCESS_TASK_RELATION_BATCH_UPDATE_ERROR);
+                    }
+                    ProcessTaskRelationLog processTaskRelationLog = new ProcessTaskRelationLog(processTaskRelation);
+                    processTaskRelationLog.setOperator(loginUser.getId());
+                    processTaskRelationLog.setId(null);
+                    processTaskRelationLog.setOperateTime(now);
+                    int insertProcessTaskRelationLogCount = processTaskRelationLogDao.insert(processTaskRelationLog);
+                    if (insertProcessTaskRelationLogCount != 1) {
+                        log.error("batch update process task relation error, projectCode:{}, taskDefinitionCode:{}.",
+                                projectCode, taskCode);
+                        putMsg(result, Status.CREATE_PROCESS_TASK_RELATION_LOG_ERROR);
+                        throw new ServiceException(Status.CREATE_PROCESS_TASK_RELATION_LOG_ERROR);
+                    }
                 }
-                int count = processTaskRelationMapper.updateProcessTaskRelationTaskVersion(processTaskRelation);
-                if (count != 1) {
-                    log.error("batch update process task relation error, projectCode:{}, taskDefinitionCode:{}.",
-                            projectCode, taskCode);
-                    putMsg(result, Status.PROCESS_TASK_RELATION_BATCH_UPDATE_ERROR);
-                    throw new ServiceException(Status.PROCESS_TASK_RELATION_BATCH_UPDATE_ERROR);
+                ProcessDefinition processDefinition = processDefinitionMapper.queryByCode(processDefinitionCode);
+                processDefinition.setVersion(processDefinitionVersion);
+                processDefinition.setUpdateTime(now);
+                processDefinition.setUserId(loginUser.getId());
+                // update process definition
+                int updateProcessDefinitionCount = processDefinitionMapper.updateById(processDefinition);
+                ProcessDefinitionLog processDefinitionLog = new ProcessDefinitionLog(processDefinition);
+                processDefinitionLog.setOperateTime(now);
+                processDefinitionLog.setId(null);
+                processDefinitionLog.setOperator(loginUser.getId());
+                int insertProcessDefinitionLogCount = processDefinitionLogMapper.insert(processDefinitionLog);
+                if ((updateProcessDefinitionCount & insertProcessDefinitionLogCount) != 1) {
+                    putMsg(result, Status.UPDATE_PROCESS_DEFINITION_ERROR);
+                    throw new ServiceException(Status.UPDATE_PROCESS_DEFINITION_ERROR);
                 }
             }
         }
@@ -804,11 +837,11 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
     /**
      * update task definition and upstream
      *
-     * @param loginUser login user
-     * @param projectCode project code
-     * @param taskCode task definition code
+     * @param loginUser             login user
+     * @param projectCode           project code
+     * @param taskCode              task definition code
      * @param taskDefinitionJsonObj task definition json object
-     * @param upstreamCodes upstream task codes, sep comma
+     * @param upstreamCodes         upstream task codes, sep comma
      * @return update result code
      */
     @Override
@@ -850,7 +883,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
         if (MapUtils.isNotEmpty(queryUpStreamTaskCodeMap)) {
             ProcessTaskRelation taskRelation = upstreamTaskRelations.get(0);
             List<ProcessTaskRelation> processTaskRelations =
-                    processTaskRelationMapper.queryByProcessCode(projectCode, taskRelation.getProcessDefinitionCode());
+                    processTaskRelationMapper.queryByProcessCode(taskRelation.getProcessDefinitionCode());
 
             // set upstream code list
             updateUpstreamTask(new HashSet<>(queryUpStreamTaskCodeMap.keySet()),
@@ -977,10 +1010,10 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
     /**
      * switch task definition
      *
-     * @param loginUser login user
+     * @param loginUser   login user
      * @param projectCode project code
-     * @param taskCode task code
-     * @param version the version user want to switch
+     * @param taskCode    task code
+     * @param version     the version user want to switch
      */
     @Transactional
     @Override
@@ -1020,7 +1053,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
                         taskCode);
                 long processDefinitionCode = taskRelationList.get(0).getProcessDefinitionCode();
                 List<ProcessTaskRelation> processTaskRelations =
-                        processTaskRelationMapper.queryByProcessCode(projectCode, processDefinitionCode);
+                        processTaskRelationMapper.queryByProcessCode(processDefinitionCode);
                 updateDag(loginUser, processDefinitionCode, processTaskRelations,
                         Lists.newArrayList(taskDefinitionUpdate));
             } else {
@@ -1123,7 +1156,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
                 taskRelationList = taskRelationList.stream()
                         .filter(v -> v.getPreTaskCode() != 0).collect(Collectors.toList());
             }
-            TaskDefinitionVo taskDefinitionVo = TaskDefinitionVo.fromTaskDefinition(taskDefinition);
+            TaskDefinitionVO taskDefinitionVo = TaskDefinitionVO.fromTaskDefinition(taskDefinition);
             taskDefinitionVo.setProcessTaskRelationList(taskRelationList);
             result.put(Constants.DATA_LIST, taskDefinitionVo);
             putMsg(result, Status.SUCCESS);
@@ -1220,7 +1253,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
         List<Long> taskCodes = new ArrayList<>();
         try {
             for (int i = 0; i < genNum; i++) {
-                taskCodes.add(CodeGenerateUtils.getInstance().genCode());
+                taskCodes.add(CodeGenerateUtils.genCode());
             }
         } catch (CodeGenerateException e) {
             log.error("Generate task definition code error.", e);
@@ -1235,9 +1268,9 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
     /**
      * release task definition
      *
-     * @param loginUser login user
-     * @param projectCode project code
-     * @param code task definition code
+     * @param loginUser    login user
+     * @param projectCode  project code
+     * @param code         task definition code
      * @param releaseState releaseState
      * @return update result code
      */
@@ -1253,7 +1286,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
             return result;
         }
         if (null == releaseState) {
-            putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, RELEASESTATE);
+            putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.RELEASE_STATE);
             return result;
         }
         TaskDefinition taskDefinition = taskDefinitionMapper.queryByCode(code);
@@ -1293,7 +1326,7 @@ public class TaskDefinitionServiceImpl extends BaseServiceImpl implements TaskDe
                 break;
             default:
                 log.warn("Parameter releaseState is invalid.");
-                putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, RELEASESTATE);
+                putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.RELEASE_STATE);
                 return result;
         }
         int update = taskDefinitionMapper.updateById(taskDefinition);
