@@ -26,7 +26,6 @@ import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.UdfType;
 import org.apache.dolphinscheduler.dao.entity.UdfFunc;
 import org.apache.dolphinscheduler.dao.entity.User;
-import org.apache.dolphinscheduler.dao.mapper.ResourceMapper;
 import org.apache.dolphinscheduler.dao.mapper.UDFUserMapper;
 import org.apache.dolphinscheduler.dao.mapper.UdfFuncMapper;
 import org.apache.dolphinscheduler.plugin.storage.api.StorageOperate;
@@ -56,9 +55,6 @@ import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 @Slf4j
 public class UdfFuncServiceImpl extends BaseServiceImpl implements UdfFuncService {
 
-    @Autowired
-    private ResourceMapper resourceMapper;
-
     @Autowired
     private UdfFuncMapper udfFuncMapper;
 
@@ -148,7 +144,6 @@ public class UdfFuncServiceImpl extends BaseServiceImpl implements UdfFuncServic
         udfFuncMapper.insert(udf);
         log.info("UDF function create complete, udfFuncName:{}.", udf.getFuncName());
         putMsg(result, Status.SUCCESS);
-        permissionPostHandle(AuthorizationType.UDF, loginUser.getId(), Collections.singletonList(udf.getId()), log);
         return result;
     }
 
