@@ -17,6 +17,7 @@
 
 package org.apache.dolphinscheduler.api.controller;
 
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.isA;
 import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.delete;
 import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
@@ -29,15 +30,16 @@ import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.service.SchedulerService;
 import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.api.utils.Result;
+import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.FailureStrategy;
 import org.apache.dolphinscheduler.common.enums.Priority;
-import org.apache.dolphinscheduler.common.enums.ReleaseState;
 import org.apache.dolphinscheduler.common.enums.WarningType;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
-import org.apache.dolphinscheduler.dao.entity.Resource;
+import org.apache.dolphinscheduler.dao.entity.Schedule;
 import org.apache.dolphinscheduler.dao.entity.User;
 
 import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
 import org.slf4j.Logger;
@@ -48,13 +50,25 @@ import org.springframework.test.web.servlet.MvcResult;
 import org.springframework.util.LinkedMultiValueMap;
 import org.springframework.util.MultiValueMap;
 
+import com.google.common.collect.ImmutableMap;
+
 public class SchedulerControllerTest extends AbstractControllerTest {
 
+    private static Schedule scheduleObj = new Schedule();
+
     private static final Logger logger = LoggerFactory.getLogger(SchedulerControllerTest.class);
 
+    final ImmutableMap<String, Object> result =
+            ImmutableMap.of(Constants.STATUS, Status.SUCCESS, Constants.DATA_LIST, scheduleObj);
+
     @MockBean(name = "schedulerService")
     private SchedulerService schedulerService;
 
+    @BeforeAll
+    public static void initInstance() {
+        scheduleObj.setId(1);
+    }
+
     @Test
     public void testCreateSchedule() throws Exception {
         MultiValueMap<String, String> paramsMap = new LinkedMultiValueMap<>();
@@ -72,7 +86,7 @@ public class SchedulerControllerTest extends AbstractControllerTest {
 
         Mockito.when(schedulerService.insertSchedule(isA(User.class), isA(Long.class), isA(Long.class),
                 isA(String.class), isA(WarningType.class), isA(int.class), isA(FailureStrategy.class),
-                isA(Priority.class), isA(String.class), isA(String.class), isA(Long.class))).thenReturn(success());
+                isA(Priority.class), isA(String.class), isA(String.class), isA(Long.class))).thenReturn(result);
 
         MvcResult mvcResult = mockMvc.perform(post("/projects/{projectCode}/schedules/", 123)
                 .header(SESSION_ID, sessionId)
@@ -103,7 +117,7 @@ public class SchedulerControllerTest extends AbstractControllerTest {
 
         Mockito.when(schedulerService.updateSchedule(isA(User.class), isA(Long.class), isA(Integer.class),
                 isA(String.class), isA(WarningType.class), isA(Integer.class), isA(FailureStrategy.class),
-                isA(Priority.class), isA(String.class), isA(String.class), isA(Long.class))).thenReturn(success());
+                isA(Priority.class), isA(String.class), isA(String.class), isA(Long.class))).thenReturn(result);
 
         MvcResult mvcResult = mockMvc.perform(put("/projects/{projectCode}/schedules/{id}", 123, 37)
                 .header(SESSION_ID, sessionId)
@@ -122,9 +136,7 @@ public class SchedulerControllerTest extends AbstractControllerTest {
         MultiValueMap<String, String> paramsMap = new LinkedMultiValueMap<>();
         paramsMap.add("id", "37");
 
-        Mockito.doNothing().when(schedulerService).setScheduleState(isA(User.class), isA(Long.class),
-                isA(Integer.class),
-                isA(ReleaseState.class));
+        Mockito.doNothing().when(schedulerService).onlineScheduler(any(), any(), any());
 
         MvcResult mvcResult = mockMvc.perform(post("/projects/{projectCode}/schedules/{id}/online", 123, 37)
                 .header(SESSION_ID, sessionId)
@@ -143,9 +155,7 @@ public class SchedulerControllerTest extends AbstractControllerTest {
         MultiValueMap<String, String> paramsMap = new LinkedMultiValueMap<>();
         paramsMap.add("id", "28");
 
-        Mockito.doNothing().when(schedulerService).setScheduleState(isA(User.class), isA(Long.class),
-                isA(Integer.class),
-                isA(ReleaseState.class));
+        Mockito.doNothing().when(schedulerService).offlineScheduler(any(), any(), any());
 
         MvcResult mvcResult = mockMvc.perform(post("/projects/{projectCode}/schedules/{id}/offline", 123, 28)
                 .header(SESSION_ID, sessionId)
@@ -167,7 +177,7 @@ public class SchedulerControllerTest extends AbstractControllerTest {
         paramsMap.add("pageNo", "1");
         paramsMap.add("pageSize", "30");
 
-        PageInfo<Resource> pageInfo = new PageInfo<>(1, 10);
+        PageInfo<Schedule> pageInfo = new PageInfo<>(1, 10);
         Result mockResult = Result.success(pageInfo);
 
         Mockito.when(schedulerService.querySchedule(isA(User.class), isA(Long.class), isA(Long.class),
