@@ -17,20 +17,30 @@
 
 package org.apache.dolphinscheduler.api.service;
 
+import static org.apache.dolphinscheduler.api.AssertionsHelper.assertDoesNotThrow;
+import static org.apache.dolphinscheduler.api.AssertionsHelper.assertThrowsServiceException;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyLong;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doThrow;
+import static org.mockito.Mockito.when;
 
 import org.apache.dolphinscheduler.api.dto.CommandStateCount;
 import org.apache.dolphinscheduler.api.enums.Status;
+import org.apache.dolphinscheduler.api.exceptions.ServiceException;
 import org.apache.dolphinscheduler.api.permission.ResourcePermissionCheckService;
-import org.apache.dolphinscheduler.api.service.impl.BaseServiceImpl;
 import org.apache.dolphinscheduler.api.service.impl.DataAnalysisServiceImpl;
+import org.apache.dolphinscheduler.api.utils.PageInfo;
+import org.apache.dolphinscheduler.api.vo.TaskInstanceCountVO;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.CommandType;
 import org.apache.dolphinscheduler.common.enums.UserType;
+import org.apache.dolphinscheduler.dao.entity.Command;
 import org.apache.dolphinscheduler.dao.entity.CommandCount;
+import org.apache.dolphinscheduler.dao.entity.ErrorCommand;
 import org.apache.dolphinscheduler.dao.entity.ExecuteStatusCount;
 import org.apache.dolphinscheduler.dao.entity.Project;
 import org.apache.dolphinscheduler.dao.entity.User;
@@ -52,19 +62,20 @@ import java.util.Map;
 import java.util.Set;
 
 import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.ExtendWith;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
-import org.mockito.Mockito;
 import org.mockito.junit.jupiter.MockitoExtension;
 import org.mockito.junit.jupiter.MockitoSettings;
 import org.mockito.quality.Strictness;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.baomidou.mybatisplus.core.metadata.IPage;
+import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
+
 /**
  * data analysis service test
  */
@@ -72,8 +83,6 @@ import org.slf4j.LoggerFactory;
 @MockitoSettings(strictness = Strictness.LENIENT)
 public class DataAnalysisServiceTest {
 
-    private static final Logger baseServiceLogger = LoggerFactory.getLogger(BaseServiceImpl.class);
-
     private static final Logger serviceLogger = LoggerFactory.getLogger(DataAnalysisServiceImpl.class);
 
     @InjectMocks
@@ -107,17 +116,21 @@ public class DataAnalysisServiceTest {
 
     private User user;
 
+    private Project project;
+
     @BeforeEach
     public void setUp() {
 
         user = new User();
+        user.setUserType(UserType.ADMIN_USER);
         user.setId(1);
-        Project project = new Project();
+        project = new Project();
         project.setId(1);
+        project.setCode(1);
         project.setName("test");
         resultMap = new HashMap<>();
 
-        Mockito.when(projectMapper.queryByCode(1L)).thenReturn(project);
+        when(projectMapper.queryByCode(1L)).thenReturn(project);
     }
 
     @AfterEach
@@ -132,14 +145,11 @@ public class DataAnalysisServiceTest {
         String startDate = "2020-02-11 16:02:18";
         String endDate = "2020-02-11 16:03:18";
 
-        Map<String, Object> result = new HashMap<>();
-        putMsg(result, Status.SUCCESS, null);
-        Mockito.when(projectService.checkProjectAndAuth(any(), any(), anyLong(), any())).thenReturn(result);
-        Mockito.when(projectMapper.queryByCode(1L)).thenReturn(getProject("test"));
+        doNothing().when(projectService).checkProjectAndAuthThrowException(any(), anyLong(), any());
 
         // SUCCESS
-        result = dataAnalysisServiceImpl.countTaskStateByProject(user, 1, startDate, endDate);
-        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        assertDoesNotThrow(
+                () -> dataAnalysisServiceImpl.getTaskInstanceStateCountByProject(user, 1L, startDate, endDate));
     }
 
     @Test
@@ -148,76 +158,62 @@ public class DataAnalysisServiceTest {
         String endDate = "2020-02-11 16:03:18";
 
         // checkProject false
-        Map<String, Object> failResult = new HashMap<>();
-        putMsg(failResult, Status.PROJECT_NOT_FOUND, 1);
-        Mockito.when(projectService.checkProjectAndAuth(any(), any(), anyLong(), any())).thenReturn(failResult);
-        failResult = dataAnalysisServiceImpl.countTaskStateByProject(user, 1, startDate, endDate);
-        Assertions.assertEquals(Status.PROJECT_NOT_FOUND, failResult.get(Constants.STATUS));
+        doThrow(new ServiceException(Status.PROJECT_NOT_FOUND, 1)).when(projectService)
+                .checkProjectAndAuthThrowException(any(), anyLong(), any());
+        assertThrowsServiceException(Status.PROJECT_NOT_FOUND,
+                () -> dataAnalysisServiceImpl.getTaskInstanceStateCountByProject(user, 1L, startDate, endDate));
     }
 
     @Test
     public void testCountTaskStateByProject_paramValid() {
-        Map<String, Object> result = new HashMap<>();
-        putMsg(result, Status.SUCCESS, null);
-        Mockito.when(projectService.checkProjectAndAuth(any(), any(), anyLong(), any())).thenReturn(result);
-        Mockito.when(projectMapper.queryByCode(1L)).thenReturn(getProject("test"));
+        doNothing().when(projectService).checkProjectAndAuthThrowException(any(), anyLong(), any());
 
         // when date in illegal format then return error message
         String startDate2 = "illegalDateString";
         String endDate2 = "illegalDateString";
-        result = dataAnalysisServiceImpl.countTaskStateByProject(user, 1, startDate2, endDate2);
-        Assertions.assertEquals(Status.REQUEST_PARAMS_NOT_VALID_ERROR, result.get(Constants.STATUS));
+        assertThrows(IllegalArgumentException.class,
+                () -> dataAnalysisServiceImpl.getTaskInstanceStateCountByProject(user, 1L, startDate2, endDate2));
 
         // when one of date in illegal format then return error message
         String startDate3 = "2020-08-28 14:13:40";
         String endDate3 = "illegalDateString";
-        result = dataAnalysisServiceImpl.countTaskStateByProject(user, 1, startDate3, endDate3);
-        Assertions.assertEquals(Status.REQUEST_PARAMS_NOT_VALID_ERROR, result.get(Constants.STATUS));
+        assertThrows(IllegalArgumentException.class,
+                () -> dataAnalysisServiceImpl.getTaskInstanceStateCountByProject(user, 1L, startDate3, endDate3));
 
         // when one of date in illegal format then return error message
         String startDate4 = "illegalDateString";
         String endDate4 = "2020-08-28 14:13:40";
-        result = dataAnalysisServiceImpl.countTaskStateByProject(user, 1, startDate4, endDate4);
-        Assertions.assertEquals(Status.REQUEST_PARAMS_NOT_VALID_ERROR, result.get(Constants.STATUS));
+        assertThrows(IllegalArgumentException.class,
+                () -> dataAnalysisServiceImpl.getTaskInstanceStateCountByProject(user, 1L, startDate4, endDate4));
     }
 
     @Test
     public void testCountTaskStateByProject_allCountZero() {
-        Map<String, Object> result = new HashMap<>();
-        putMsg(result, Status.SUCCESS, null);
-        Mockito.when(projectService.checkProjectAndAuth(any(), any(), anyLong(), any())).thenReturn(result);
-        Mockito.when(projectMapper.queryByCode(1L)).thenReturn(getProject("test"));
+        doNothing().when(projectService).checkProjectAndAuthThrowException(any(), anyLong(), any());
 
         // when general user doesn't have any task then return all count are 0
         user.setUserType(UserType.GENERAL_USER);
-        Mockito.when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
-                serviceLogger))
-                .thenReturn(projectIds());
-        Mockito.when(taskInstanceMapper.countTaskInstanceStateByProjectCodes(any(), any(), any())).thenReturn(
-                Collections.emptyList());
-        result = dataAnalysisServiceImpl.countTaskStateByProject(user, 1, null, null);
-        assertThat(result.get(Constants.DATA_LIST)).extracting("totalCount").isEqualTo(0);
-        assertThat(result.get(Constants.DATA_LIST)).extracting("taskCountDtos").asList().hasSameSizeAs(
-                TaskExecutionStatus.values());
-        assertThat(result.get(Constants.DATA_LIST)).extracting("taskCountDtos").asList().extracting(
-                "count").allMatch(count -> count.equals(0));
+        when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
+                serviceLogger)).thenReturn(projectIds());
+        when(taskInstanceMapper.countTaskInstanceStateByProjectCodes(any(), any(), any()))
+                .thenReturn(Collections.emptyList());
+        assertDoesNotThrow(() -> dataAnalysisServiceImpl.getTaskInstanceStateCountByProject(user, 1L, null, null));
+
     }
 
     @Test
     public void testCountTaskStateByProject_noData() {
-        Map<String, Object> result = new HashMap<>();
-        putMsg(result, Status.SUCCESS, null);
-        Mockito.when(projectService.checkProjectAndAuth(any(), any(), anyLong(), any())).thenReturn(result);
-        Mockito.when(projectMapper.queryByCode(1L)).thenReturn(getProject("test"));
-        Mockito.when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
+        doNothing().when(projectService).checkProjectAndAuthThrowException(any(), anyLong(), any());
+        when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
                 serviceLogger)).thenReturn(projectIds());
 
         // when instanceStateCounter return null, then return nothing
         user.setUserType(UserType.GENERAL_USER);
-        Mockito.when(taskInstanceMapper.countTaskInstanceStateByProjectCodes(any(), any(), any()))
-                .thenReturn(null);
-        result = dataAnalysisServiceImpl.countTaskStateByProject(user, 1, null, null);
-        Assertions.assertNull(result.get(Constants.DATA_LIST));
+        when(taskInstanceMapper.countTaskInstanceStateByProjectCodes(any(), any(), any()))
+                .thenReturn(Collections.emptyList());
+        TaskInstanceCountVO taskInstanceStateCountByProject =
+                dataAnalysisServiceImpl.getTaskInstanceStateCountByProject(user, 1L, null, null);
+        assertThat(taskInstanceStateCountByProject).isNotNull();
     }
 
     @Test
@@ -225,39 +221,30 @@ public class DataAnalysisServiceTest {
         String startDate = "2020-02-11 16:02:18";
         String endDate = "2020-02-11 16:03:18";
 
-        Mockito.when(projectMapper.queryByCode(1L)).thenReturn(getProject("test"));
-
         // checkProject false
-        Map<String, Object> failResult = new HashMap<>();
-        putMsg(failResult, Status.PROJECT_NOT_FOUND, 1);
-        Mockito.when(projectService.checkProjectAndAuth(any(), any(), anyLong(), any())).thenReturn(failResult);
-        failResult = dataAnalysisServiceImpl.countProcessInstanceStateByProject(user, 1, startDate, endDate);
-        Assertions.assertEquals(Status.PROJECT_NOT_FOUND, failResult.get(Constants.STATUS));
+        doThrow(new ServiceException(Status.PROJECT_NOT_FOUND, 1)).when(projectService)
+                .checkProjectAndAuthThrowException(any(), anyLong(), any());
+        assertThrowsServiceException(Status.PROJECT_NOT_FOUND,
+                () -> dataAnalysisServiceImpl.getWorkflowInstanceStateCountByProject(user, 1L, startDate, endDate));
 
-        Map<String, Object> result = new HashMap<>();
-        putMsg(result, Status.SUCCESS, null);
-        Mockito.when(projectService.checkProjectAndAuth(any(), any(), anyLong(), any())).thenReturn(result);
+        doNothing().when(projectService).checkProjectAndAuthThrowException(any(), anyLong(), any());
 
         // SUCCESS
-        result = dataAnalysisServiceImpl.countProcessInstanceStateByProject(user, 1, startDate, endDate);
-        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        assertDoesNotThrow(
+                () -> dataAnalysisServiceImpl.getWorkflowInstanceStateCountByProject(user, 1L, startDate, endDate));
     }
 
     @Test
     public void testCountDefinitionByUser() {
+        doNothing().when(projectService).checkProjectAndAuthThrowException(any(), anyLong(), any());
 
-        Map<String, Object> result = new HashMap<>();
-        putMsg(result, Status.SUCCESS, null);
-
-        Mockito.when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
+        when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
                 serviceLogger)).thenReturn(projectIds());
-        result = dataAnalysisServiceImpl.countDefinitionByUser(user, 0);
-        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        assertDoesNotThrow(() -> dataAnalysisServiceImpl.getWorkflowDefinitionCountByProject(user, 0L));
 
-        Mockito.when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
+        when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
                 serviceLogger)).thenReturn(Collections.emptySet());
-        result = dataAnalysisServiceImpl.countDefinitionByUser(user, 0);
-        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        assertDoesNotThrow(() -> dataAnalysisServiceImpl.getWorkflowDefinitionCountByProject(user, 0L));
     }
 
     @Test
@@ -266,21 +253,17 @@ public class DataAnalysisServiceTest {
         user.setUserType(UserType.ADMIN_USER);
         user.setId(1);
 
-        Map<String, Object> result = dataAnalysisServiceImpl.countCommandState(user);
-        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        assertDoesNotThrow(() -> dataAnalysisServiceImpl.countCommandState(user));
 
         // when no command found then return all count are 0
-        Mockito.when(commandMapper.countCommandState(any(), any(), any())).thenReturn(Collections.emptyList());
-        Mockito.when(errorCommandMapper.countCommandState(any(), any(), any())).thenReturn(Collections.emptyList());
-        Mockito.when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
+        when(commandMapper.countCommandState(any(), any(), any())).thenReturn(Collections.emptyList());
+        when(errorCommandMapper.countCommandState(any(), any(), any())).thenReturn(Collections.emptyList());
+        when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
                 serviceLogger)).thenReturn(projectIds());
 
-        Map<String, Object> result5 = dataAnalysisServiceImpl.countCommandState(user);
-        assertThat(result5).containsEntry(Constants.STATUS, Status.SUCCESS);
-        assertThat(result5.get(Constants.DATA_LIST)).asList().extracting("errorCount")
-                .allMatch(count -> count.equals(0));
-        assertThat(result5.get(Constants.DATA_LIST)).asList().extracting("normalCount")
-                .allMatch(count -> count.equals(0));
+        List<CommandStateCount> commandStateCounts = dataAnalysisServiceImpl.countCommandState(user);
+        assertThat(commandStateCounts).asList().extracting("errorCount").allMatch(count -> count.equals(0));
+        assertThat(commandStateCounts).asList().extracting("normalCount").allMatch(count -> count.equals(0));
 
         // when command found then return combination result
         CommandCount normalCommandCount = new CommandCount();
@@ -289,30 +272,89 @@ public class DataAnalysisServiceTest {
         CommandCount errorCommandCount = new CommandCount();
         errorCommandCount.setCommandType(CommandType.START_PROCESS);
         errorCommandCount.setCount(5);
-        Mockito.when(commandMapper.countCommandState(any(), any(), any()))
+        when(commandMapper.countCommandState(any(), any(), any()))
                 .thenReturn(Collections.singletonList(normalCommandCount));
-        Mockito.when(errorCommandMapper.countCommandState(any(), any(), any()))
+        when(errorCommandMapper.countCommandState(any(), any(), any()))
                 .thenReturn(Collections.singletonList(errorCommandCount));
 
-        Map<String, Object> result6 = dataAnalysisServiceImpl.countCommandState(user);
+        commandStateCounts = dataAnalysisServiceImpl.countCommandState(user);
 
-        assertThat(result6).containsEntry(Constants.STATUS, Status.SUCCESS);
         CommandStateCount commandStateCount = new CommandStateCount();
         commandStateCount.setCommandState(CommandType.START_PROCESS);
         commandStateCount.setNormalCount(10);
         commandStateCount.setErrorCount(5);
-        assertThat(result6.get(Constants.DATA_LIST)).asList().containsOnlyOnce(commandStateCount);
+        assertThat(commandStateCounts).asList().containsOnlyOnce(commandStateCount);
     }
 
     @Test
     public void testCountQueueState() {
         // when project check success when return all count are 0
-        Map<String, Object> result2 = dataAnalysisServiceImpl.countQueueState(user);
-        assertThat(result2.get(Constants.DATA_LIST)).extracting("taskQueue", "taskKill")
+        Map<String, Integer> stringIntegerMap = dataAnalysisServiceImpl.countQueueState(user);
+        assertThat(stringIntegerMap).extracting("taskQueue", "taskKill")
                 .isNotEmpty()
                 .allMatch(count -> count.equals(0));
     }
 
+    @Test
+    public void testListPendingCommands() {
+        IPage<Command> page = new Page<>(1, 10);
+        page.setTotal(2L);
+        page.setRecords(getList());
+        when(commandMapper.queryCommandPage(any())).thenReturn(page);
+        PageInfo<Command> list1 = dataAnalysisServiceImpl.listPendingCommands(user, 1L, 1, 10);
+        assertThat(list1.getTotal()).isEqualTo(2);
+        user.setUserType(UserType.GENERAL_USER);
+        when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
+                serviceLogger))
+                        .thenReturn(projectIds());
+        PageInfo<Command> list2 = dataAnalysisServiceImpl.listPendingCommands(user, 1L, 1, 10);
+        assertThat(list2.getTotal()).isEqualTo(0);
+        when(projectMapper.selectBatchIds(any())).thenReturn(Collections.singletonList(project));
+        when(processDefinitionMapper.queryDefinitionCodeListByProjectCodes(any()))
+                .thenReturn(Collections.singletonList(1L));
+        when(commandMapper.queryCommandPageByIds(any(), any())).thenReturn(page);
+        PageInfo<Command> list3 = dataAnalysisServiceImpl.listPendingCommands(user, 1L, 1, 10);
+        assertThat(list3.getTotal()).isEqualTo(2);
+    }
+
+    @Test
+    public void testListErrorCommand() {
+        IPage<ErrorCommand> page = new Page<>(1, 10);
+        page.setTotal(2L);
+        page.setRecords(getErrorList());
+        when(errorCommandMapper.queryErrorCommandPage(any())).thenReturn(page);
+        PageInfo<ErrorCommand> list1 = dataAnalysisServiceImpl.listErrorCommand(user, 1L, 1, 10);
+        assertThat(list1.getTotal()).isEqualTo(2);
+        user.setUserType(UserType.GENERAL_USER);
+        when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, 1,
+                serviceLogger))
+                        .thenReturn(projectIds());
+        PageInfo<ErrorCommand> list2 = dataAnalysisServiceImpl.listErrorCommand(user, 1L, 1, 10);
+        assertThat(list2.getTotal()).isEqualTo(0);
+        when(projectMapper.selectBatchIds(any())).thenReturn(Collections.singletonList(project));
+        when(processDefinitionMapper.queryDefinitionCodeListByProjectCodes(any()))
+                .thenReturn(Collections.singletonList(1L));
+        when(errorCommandMapper.queryErrorCommandPageByIds(any(), any())).thenReturn(page);
+        PageInfo<ErrorCommand> list3 = dataAnalysisServiceImpl.listErrorCommand(user, 1L, 1, 10);
+        assertThat(list3.getTotal()).isEqualTo(2);
+    }
+
+    private List<Command> getList() {
+        List<Command> commandList = new ArrayList<>();
+        Command command = new Command();
+        command.setId(1);
+        commandList.add(command);
+        return commandList;
+    }
+
+    private List<ErrorCommand> getErrorList() {
+        List<ErrorCommand> commandList = new ArrayList<>();
+        ErrorCommand command = new ErrorCommand();
+        command.setId(1);
+        commandList.add(command);
+        return commandList;
+    }
+
     private Set<Integer> projectIds() {
         Set<Integer> projectIds = new HashSet<>();
         projectIds.add(1);
