@@ -20,7 +20,10 @@ package org.apache.dolphinscheduler.api.service;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.INSTANCE_DELETE;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.INSTANCE_UPDATE;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.WORKFLOW_INSTANCE;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.when;
 
 import org.apache.dolphinscheduler.api.enums.Status;
@@ -81,6 +84,7 @@ import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.ExtendWith;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
+import org.mockito.MockedStatic;
 import org.mockito.Mockito;
 import org.mockito.junit.jupiter.MockitoExtension;
 import org.mockito.junit.jupiter.MockitoSettings;
@@ -139,9 +143,6 @@ public class ProcessInstanceServiceTest {
     @Mock
     TaskDefinitionMapper taskDefinitionMapper;
 
-    @Mock
-    TaskPluginManager taskPluginManager;
-
     @Mock
     ScheduleMapper scheduleMapper;
 
@@ -192,13 +193,23 @@ public class ProcessInstanceServiceTest {
         putMsg(result, Status.PROJECT_NOT_FOUND, projectCode);
 
         // project auth fail
-        when(projectMapper.queryByCode(projectCode)).thenReturn(null);
-        Mockito.doThrow(new ServiceException()).when(projectService).checkProjectAndAuthThrowException(Mockito.any(),
-                Mockito.any(), Mockito.any());
-        Assertions.assertThrows(ServiceException.class, () -> {
-            processInstanceService.queryProcessInstanceList(loginUser, projectCode, 46, "2020-01-01 00:00:00",
-                    "2020-01-02 00:00:00", "", "test_user", WorkflowExecutionStatus.SUBMITTED_SUCCESS,
-                    "192.168.xx.xx", "", 1, 10);
+        doThrow(new ServiceException())
+                .when(projectService)
+                .checkProjectAndAuthThrowException(loginUser, projectCode, WORKFLOW_INSTANCE);
+        assertThrows(ServiceException.class, () -> {
+            processInstanceService.queryProcessInstanceList(
+                    loginUser,
+                    projectCode,
+                    46,
+                    "2020-01-01 00:00:00",
+                    "2020-01-02 00:00:00",
+                    "",
+                    "test_user",
+                    WorkflowExecutionStatus.SUBMITTED_SUCCESS,
+                    "192.168.xx.xx",
+                    "",
+                    1,
+                    10);
         });
 
         Date start = DateUtils.stringToDate("2020-01-01 00:00:00");
@@ -212,13 +223,14 @@ public class ProcessInstanceServiceTest {
         // data parameter check
         putMsg(result, Status.SUCCESS, projectCode);
         when(projectMapper.queryByCode(projectCode)).thenReturn(project);
-        Mockito.doNothing().when(projectService).checkProjectAndAuthThrowException(Mockito.any(), Mockito.any(),
+        Mockito.doNothing().when(projectService).checkProjectAndAuthThrowException(Mockito.any(),
+                Mockito.any(Project.class),
                 Mockito.any());
         when(processDefineMapper.selectById(Mockito.anyInt())).thenReturn(getProcessDefinition());
         when(processInstanceMapper.queryProcessInstanceListPaging(Mockito.any(Page.class), Mockito.any(), Mockito.any(),
                 Mockito.any(), Mockito.any(), Mockito.any(),
                 eq("192.168.xx.xx"), Mockito.any(), Mockito.any())).thenReturn(pageReturn);
-        Assertions.assertThrows(ServiceException.class, () -> processInstanceService.queryProcessInstanceList(
+        assertThrows(ServiceException.class, () -> processInstanceService.queryProcessInstanceList(
                 loginUser,
                 projectCode,
                 1,
@@ -235,13 +247,20 @@ public class ProcessInstanceServiceTest {
         // project auth success
         putMsg(result, Status.SUCCESS, projectCode);
 
-        when(projectMapper.queryByCode(projectCode)).thenReturn(project);
-        when(projectService.checkProjectAndAuth(loginUser, project, projectCode, WORKFLOW_INSTANCE)).thenReturn(result);
+        doNothing().when(projectService).checkProjectAndAuthThrowException(loginUser, projectCode, WORKFLOW_INSTANCE);
         when(usersService.queryUser(loginUser.getId())).thenReturn(loginUser);
         when(usersService.getUserIdByName(loginUser.getUserName())).thenReturn(loginUser.getId());
-        when(processInstanceMapper.queryProcessInstanceListPaging(Mockito.any(Page.class), eq(project.getCode()),
-                eq(1L), eq(""), eq(""), Mockito.any(),
-                eq("192.168.xx.xx"), eq(start), eq(end))).thenReturn(pageReturn);
+        when(processInstanceMapper.queryProcessInstanceListPaging(
+                Mockito.any(Page.class),
+                eq(project.getCode()),
+                eq(1L),
+                eq(""),
+                eq(""),
+                Mockito.any(),
+                eq("192.168.xx.xx"),
+                eq(start),
+                eq(end)))
+                        .thenReturn(pageReturn);
         when(usersService.queryUser(processInstance.getExecutorId())).thenReturn(loginUser);
 
         Result successRes =
@@ -554,18 +573,22 @@ public class ProcessInstanceServiceTest {
 
         // project auth fail
         when(projectMapper.queryByCode(projectCode)).thenReturn(project);
-        when(projectService.checkProjectAndAuth(loginUser, project, projectCode, INSTANCE_UPDATE)).thenReturn(result);
-        Map<String, Object> projectAuthFailRes = processInstanceService.updateProcessInstance(loginUser, projectCode, 1,
-                shellJson, taskJson, "2020-02-21 00:00:00", true, "", "", 0);
-        Assertions.assertEquals(Status.PROJECT_NOT_FOUND, projectAuthFailRes.get(Constants.STATUS));
+        doThrow(new ServiceException(Status.PROJECT_NOT_FOUND, projectCode))
+                .when(projectService)
+                .checkProjectAndAuthThrowException(loginUser, projectCode, INSTANCE_UPDATE);
+        Assertions.assertThrows(ServiceException.class,
+                () -> processInstanceService.updateProcessInstance(loginUser, projectCode, 1,
+                        shellJson, taskJson, "2020-02-21 00:00:00", true, "", "", 0));
 
         // process instance null
         putMsg(result, Status.SUCCESS, projectCode);
         ProcessInstance processInstance = getProcessInstance();
         when(projectMapper.queryByCode(projectCode)).thenReturn(project);
-        when(projectService.checkProjectAndAuth(loginUser, project, projectCode, INSTANCE_UPDATE)).thenReturn(result);
+        doNothing()
+                .when(projectService)
+                .checkProjectAndAuthThrowException(loginUser, projectCode, INSTANCE_UPDATE);
         when(processService.findProcessInstanceDetailById(1)).thenReturn(Optional.empty());
-        Assertions.assertThrows(ServiceException.class, () -> {
+        assertThrows(ServiceException.class, () -> {
             processInstanceService.updateProcessInstance(loginUser, projectCode, 1,
                     shellJson, taskJson, "2020-02-21 00:00:00", true, "", "", 0);
         });
@@ -600,21 +623,27 @@ public class ProcessInstanceServiceTest {
         List<TaskDefinitionLog> taskDefinitionLogs = JSONUtils.toList(taskDefinitionJson, TaskDefinitionLog.class);
         when(processDefinitionService.checkProcessNodeList(taskRelationJson, taskDefinitionLogs)).thenReturn(result);
         putMsg(result, Status.SUCCESS, projectCode);
-        when(taskPluginManager.checkTaskParameters(Mockito.any())).thenReturn(true);
-        Map<String, Object> processInstanceFinishRes =
-                processInstanceService.updateProcessInstance(loginUser, projectCode, 1,
-                        taskRelationJson, taskDefinitionJson, "2020-02-21 00:00:00", true, "", "", 0);
-        Assertions.assertEquals(Status.SUCCESS, processInstanceFinishRes.get(Constants.STATUS));
 
-        // success
-        when(processDefineMapper.queryByCode(46L)).thenReturn(processDefinition);
-        putMsg(result, Status.SUCCESS, projectCode);
+        try (
+                MockedStatic<TaskPluginManager> taskPluginManagerMockedStatic =
+                        Mockito.mockStatic(TaskPluginManager.class)) {
+            taskPluginManagerMockedStatic.when(() -> TaskPluginManager.checkTaskParameters(Mockito.any()))
+                    .thenReturn(true);
+            Map<String, Object> processInstanceFinishRes =
+                    processInstanceService.updateProcessInstance(loginUser, projectCode, 1,
+                            taskRelationJson, taskDefinitionJson, "2020-02-21 00:00:00", true, "", "", 0);
+            Assertions.assertEquals(Status.SUCCESS, processInstanceFinishRes.get(Constants.STATUS));
 
-        when(processService.saveProcessDefine(loginUser, processDefinition, Boolean.FALSE, Boolean.FALSE))
-                .thenReturn(1);
-        Map<String, Object> successRes = processInstanceService.updateProcessInstance(loginUser, projectCode, 1,
-                taskRelationJson, taskDefinitionJson, "2020-02-21 00:00:00", Boolean.FALSE, "", "", 0);
-        Assertions.assertEquals(Status.SUCCESS, successRes.get(Constants.STATUS));
+            // success
+            when(processDefineMapper.queryByCode(46L)).thenReturn(processDefinition);
+            putMsg(result, Status.SUCCESS, projectCode);
+
+            when(processService.saveProcessDefine(loginUser, processDefinition, Boolean.FALSE, Boolean.FALSE))
+                    .thenReturn(1);
+            Map<String, Object> successRes = processInstanceService.updateProcessInstance(loginUser, projectCode, 1,
+                    taskRelationJson, taskDefinitionJson, "2020-02-21 00:00:00", Boolean.FALSE, "", "", 0);
+            Assertions.assertEquals(Status.SUCCESS, successRes.get(Constants.STATUS));
+        }
     }
 
     @Test
@@ -637,7 +666,7 @@ public class ProcessInstanceServiceTest {
         when(projectMapper.queryByCode(projectCode)).thenReturn(project);
         when(projectService.checkProjectAndAuth(loginUser, project, projectCode, WORKFLOW_INSTANCE)).thenReturn(result);
         when(processService.findProcessInstanceDetailById(1)).thenReturn(Optional.empty());
-        Assertions.assertThrows(ServiceException.class, () -> {
+        assertThrows(ServiceException.class, () -> {
             processInstanceService.queryParentInstanceBySubId(loginUser, projectCode, 1);
         });
 
@@ -678,7 +707,7 @@ public class ProcessInstanceServiceTest {
         when(projectMapper.queryByCode(projectCode)).thenReturn(project);
         when(projectService.checkProjectAndAuth(loginUser, project, projectCode, INSTANCE_DELETE)).thenReturn(result);
 
-        Assertions.assertThrows(ServiceException.class,
+        assertThrows(ServiceException.class,
                 () -> processInstanceService.deleteProcessInstanceById(loginUser, 1));
 
         // not sub process
@@ -689,7 +718,7 @@ public class ProcessInstanceServiceTest {
         when(processService.findProcessInstanceDetailById(1)).thenReturn(Optional.ofNullable(processInstance));
         when(processDefinitionLogMapper.queryByDefinitionCodeAndVersion(Mockito.anyLong(), Mockito.anyInt()))
                 .thenReturn(new ProcessDefinitionLog());
-        Assertions.assertThrows(ServiceException.class,
+        assertThrows(ServiceException.class,
                 () -> processInstanceService.deleteProcessInstanceById(loginUser, 1));
 
         processInstance.setState(WorkflowExecutionStatus.SUCCESS);
@@ -704,7 +733,7 @@ public class ProcessInstanceServiceTest {
         processDefinition.setProjectCode(0L);
         when(processDefineMapper.queryByCode(46L)).thenReturn(processDefinition);
         when(processService.findProcessInstanceDetailById(Mockito.anyInt())).thenReturn(Optional.empty());
-        Assertions.assertThrows(ServiceException.class,
+        assertThrows(ServiceException.class,
                 () -> processInstanceService.deleteProcessInstanceById(loginUser, 1));
 
         processDefinition.setProjectCode(projectCode);
@@ -744,7 +773,6 @@ public class ProcessInstanceServiceTest {
                 processInstance.getProcessDefinitionCode(),
                 processInstance.getProcessDefinitionVersion())).thenReturn(new ProcessDefinitionLog());
         when(processInstanceMapper.queryDetailById(1)).thenReturn(processInstance);
-        when(taskInstanceMapper.queryByInstanceIdAndName(Mockito.anyInt(), Mockito.any())).thenReturn(taskInstance);
         DAG<Long, TaskNode, TaskNodeRelation> graph = new DAG<>();
         for (long i = 1; i <= 7; ++i) {
             graph.addNode(i, new TaskNode());
