@@ -17,19 +17,19 @@
 
 package org.apache.dolphinscheduler.api.service;
 
+import static org.apache.dolphinscheduler.api.AssertionsHelper.assertDoesNotThrow;
+import static org.apache.dolphinscheduler.api.AssertionsHelper.assertThrowsServiceException;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.TENANT_CREATE;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.TENANT_DELETE;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.TENANT_UPDATE;
 import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.Mockito.when;
 
 import org.apache.dolphinscheduler.api.enums.Status;
-import org.apache.dolphinscheduler.api.exceptions.ServiceException;
 import org.apache.dolphinscheduler.api.permission.ResourcePermissionCheckService;
 import org.apache.dolphinscheduler.api.service.impl.BaseServiceImpl;
 import org.apache.dolphinscheduler.api.service.impl.TenantServiceImpl;
 import org.apache.dolphinscheduler.api.utils.PageInfo;
-import org.apache.dolphinscheduler.api.utils.Result;
-import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.UserType;
 import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
@@ -45,12 +45,10 @@ import org.apache.dolphinscheduler.plugin.storage.api.StorageOperate;
 
 import org.apache.commons.collections4.CollectionUtils;
 
-import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 
 import org.junit.jupiter.api.Assertions;
@@ -68,9 +66,6 @@ import org.slf4j.LoggerFactory;
 import com.baomidou.mybatisplus.core.metadata.IPage;
 import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 
-/**
- * tenant service test
- */
 @ExtendWith(MockitoExtension.class)
 @MockitoSettings(strictness = Strictness.LENIENT)
 public class TenantServiceTest {
@@ -108,59 +103,47 @@ public class TenantServiceTest {
     private static final String queueName = "queue_name";
 
     @Test
-    public void testCreateTenant() throws Exception {
+    public void testCreateTenant() {
 
         User loginUser = getLoginUser();
-        Mockito.when(tenantMapper.existTenant(tenantCode)).thenReturn(true);
-        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.TENANT,
-                loginUser.getId(), TENANT_CREATE, baseServiceLogger)).thenReturn(true);
-        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.TENANT, null, 0,
+        when(tenantMapper.existTenant(tenantCode)).thenReturn(true);
+        when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.TENANT, loginUser.getId(),
+                TENANT_CREATE, baseServiceLogger)).thenReturn(true);
+        when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.TENANT, null, 0,
                 baseServiceLogger)).thenReturn(true);
-        Map<String, Object> result;
-
         // check exist
         String emptyTenantCode = "";
-        Throwable exception = Assertions.assertThrows(ServiceException.class,
+        assertThrowsServiceException(Status.REQUEST_PARAMS_NOT_VALID_ERROR,
                 () -> tenantService.createTenant(loginUser, emptyTenantCode, 1, tenantDesc));
-        String formatter = MessageFormat.format(Status.REQUEST_PARAMS_NOT_VALID_ERROR.getMsg(), emptyTenantCode);
-        Assertions.assertEquals(formatter, exception.getMessage());
 
         // check tenant code too long
         String longStr =
                 "this_is_a_very_long_string_this_is_a_very_long_string_this_is_a_very_long_string_this_is_a_very_long_string";
-        exception = Assertions.assertThrows(ServiceException.class,
+        assertThrowsServiceException(Status.TENANT_FULL_NAME_TOO_LONG_ERROR,
                 () -> tenantService.createTenant(loginUser, longStr, 1, tenantDesc));
-        Assertions.assertEquals(Status.TENANT_FULL_NAME_TOO_LONG_ERROR.getMsg(), exception.getMessage());
 
         // check tenant code invalid
-        exception = Assertions.assertThrows(ServiceException.class,
+        assertThrowsServiceException(Status.CHECK_OS_TENANT_CODE_ERROR,
                 () -> tenantService.createTenant(getLoginUser(), "%!1111", 1, tenantDesc));
-        Assertions.assertEquals(Status.CHECK_OS_TENANT_CODE_ERROR.getMsg(), exception.getMessage());
 
         // check exist
-        exception = Assertions.assertThrows(ServiceException.class,
+        assertThrowsServiceException(Status.OS_TENANT_CODE_EXIST,
                 () -> tenantService.createTenant(loginUser, tenantCode, 1, tenantDesc));
-        formatter = MessageFormat.format(Status.OS_TENANT_CODE_EXIST.getMsg(), tenantCode);
-        Assertions.assertEquals(formatter, exception.getMessage());
 
         // success
-        result = tenantService.createTenant(loginUser, "test", 1, tenantDesc);
-        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        assertDoesNotThrow(() -> tenantService.createTenant(loginUser, "test", 1, tenantDesc));
     }
 
     @Test
     public void testCreateTenantError() {
-        Mockito.when(tenantMapper.existTenant(tenantCode)).thenReturn(true);
+        when(tenantMapper.existTenant(tenantCode)).thenReturn(true);
 
         // tenantCode exist
-        Throwable exception = Assertions.assertThrows(ServiceException.class,
+        assertThrowsServiceException(Status.OS_TENANT_CODE_EXIST,
                 () -> tenantService.verifyTenantCode(getTenant().getTenantCode()));
-        String expect = MessageFormat.format(Status.OS_TENANT_CODE_EXIST.getMsg(), getTenant().getTenantCode());
-        Assertions.assertEquals(expect, exception.getMessage());
 
         // success
-        Result result = tenantService.verifyTenantCode("s00000000000l887888885554444sfjdskfjslakslkdf");
-        Assertions.assertEquals(Status.SUCCESS.getMsg(), result.getMsg());
+        assertDoesNotThrow(() -> tenantService.verifyTenantCode("s00000000000l887888885554444sfjdskfjslakslkdf"));
     }
 
     @Test
@@ -171,100 +154,81 @@ public class TenantServiceTest {
         page.setTotal(1L);
         Set<Integer> ids = new HashSet<>();
         ids.add(1);
-        Mockito.when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.TENANT,
+        when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.TENANT,
                 getLoginUser().getId(), tenantServiceImplLogger)).thenReturn(ids);
-        Mockito.when(tenantMapper.queryTenantPaging(any(Page.class), Mockito.anyList(), Mockito.eq(tenantDesc)))
+        when(tenantMapper.queryTenantPaging(any(Page.class), Mockito.anyList(), Mockito.eq(tenantDesc)))
                 .thenReturn(page);
-        Result result = tenantService.queryTenantList(getLoginUser(), tenantDesc, 1, 10);
-        PageInfo<Tenant> pageInfo = (PageInfo<Tenant>) result.getData();
+        PageInfo<Tenant> pageInfo = tenantService.queryTenantList(getLoginUser(), tenantDesc, 1, 10);
         Assertions.assertTrue(CollectionUtils.isNotEmpty(pageInfo.getTotalList()));
 
     }
 
     @Test
-    public void testUpdateTenant() throws Exception {
-        Mockito.when(tenantMapper.queryById(1)).thenReturn(getTenant());
-        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.TENANT,
-                getLoginUser().getId(), TENANT_UPDATE, baseServiceLogger)).thenReturn(true);
-        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.TENANT, null, 0,
+    public void testUpdateTenant() {
+        when(tenantMapper.queryById(1)).thenReturn(getTenant());
+        when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.TENANT, getLoginUser().getId(),
+                TENANT_UPDATE, baseServiceLogger)).thenReturn(true);
+        when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.TENANT, null, 0,
                 baseServiceLogger)).thenReturn(true);
-        Mockito.when(tenantMapper.updateById(getTenant())).thenReturn(1);
+        when(tenantMapper.updateById(any())).thenReturn(1);
 
         // update not exists tenant
-        Throwable exception = Assertions.assertThrows(ServiceException.class,
+        assertThrowsServiceException(Status.TENANT_NOT_EXIST,
                 () -> tenantService.updateTenant(getLoginUser(), 912222, tenantCode, 1, tenantDesc));
-        Assertions.assertEquals(Status.TENANT_NOT_EXIST.getMsg(), exception.getMessage());
 
         // success
-        Map<String, Object> result = tenantService.updateTenant(getLoginUser(), 1, tenantCode, 1, tenantDesc);
-        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        assertDoesNotThrow(() -> tenantService.updateTenant(getLoginUser(), 1, tenantCode, 1, tenantDesc));
 
         // success update with same tenant code
-        result = tenantService.updateTenant(getLoginUser(), 1, tenantCode, 1, tenantDesc);
-        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        assertDoesNotThrow(() -> tenantService.updateTenant(getLoginUser(), 1, tenantCode, 1, tenantDesc));
     }
 
     @Test
-    public void testDeleteTenantById() throws Exception {
-        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.TENANT,
+    public void testDeleteTenantById() {
+        when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.TENANT,
                 getLoginUser().getId(), TENANT_DELETE, baseServiceLogger)).thenReturn(true);
-        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.TENANT, null, 0,
+        when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.TENANT, null, 0,
                 baseServiceLogger)).thenReturn(true);
-        Mockito.when(tenantMapper.queryById(1)).thenReturn(getTenant());
-        Mockito.when(processInstanceMapper.queryByTenantCodeAndStatus(tenantCode,
+        when(tenantMapper.queryById(1)).thenReturn(getTenant());
+        when(processInstanceMapper.queryByTenantCodeAndStatus(tenantCode,
                 org.apache.dolphinscheduler.service.utils.Constants.NOT_TERMINATED_STATES))
-                .thenReturn(getInstanceList());
-        Mockito.when(scheduleMapper.queryScheduleListByTenant(tenantCode)).thenReturn(getScheduleList());
-        Mockito.when(userMapper.queryUserListByTenant(3)).thenReturn(getUserList());
+                        .thenReturn(getInstanceList());
+        when(scheduleMapper.queryScheduleListByTenant(tenantCode)).thenReturn(getScheduleList());
+        when(userMapper.queryUserListByTenant(3)).thenReturn(getUserList());
 
         // TENANT_NOT_EXIST
-        Throwable exception = Assertions.assertThrows(ServiceException.class,
-                () -> tenantService.deleteTenantById(getLoginUser(), 12));
-        Assertions.assertEquals(Status.TENANT_NOT_EXIST.getMsg(), exception.getMessage());
+        assertThrowsServiceException(Status.TENANT_NOT_EXIST, () -> tenantService.deleteTenantById(getLoginUser(), 12));
 
         // DELETE_TENANT_BY_ID_FAIL
-        exception = Assertions.assertThrows(ServiceException.class,
+        assertThrowsServiceException(Status.DELETE_TENANT_BY_ID_FAIL,
                 () -> tenantService.deleteTenantById(getLoginUser(), 1));
-        String prefix = Status.DELETE_TENANT_BY_ID_FAIL.getMsg().substring(1, 5);
-        Assertions.assertTrue(exception.getMessage().contains(prefix));
 
         // DELETE_TENANT_BY_ID_FAIL_DEFINES
-        Mockito.when(tenantMapper.queryById(2)).thenReturn(getTenant(2));
-        exception = Assertions.assertThrows(ServiceException.class,
+        when(processInstanceMapper.queryByTenantCodeAndStatus(any(), any())).thenReturn(Collections.emptyList());
+        when(tenantMapper.queryById(2)).thenReturn(getTenant(2));
+        assertThrowsServiceException(Status.DELETE_TENANT_BY_ID_FAIL_DEFINES,
                 () -> tenantService.deleteTenantById(getLoginUser(), 2));
-        prefix = Status.DELETE_TENANT_BY_ID_FAIL_DEFINES.getMsg().substring(1, 5);
-        Assertions.assertTrue(exception.getMessage().contains(prefix));
 
         // DELETE_TENANT_BY_ID_FAIL_USERS
-        Mockito.when(tenantMapper.queryById(3)).thenReturn(getTenant(3));
-        exception = Assertions.assertThrows(ServiceException.class,
+        when(tenantMapper.queryById(3)).thenReturn(getTenant(3));
+        when(scheduleMapper.queryScheduleListByTenant(tenantCode)).thenReturn(Collections.emptyList());
+        assertThrowsServiceException(Status.DELETE_TENANT_BY_ID_FAIL_USERS,
                 () -> tenantService.deleteTenantById(getLoginUser(), 3));
-        prefix = Status.DELETE_TENANT_BY_ID_FAIL_USERS.getMsg().substring(1, 5);
-        Assertions.assertTrue(exception.getMessage().contains(prefix));
 
         // success
-        Mockito.when(processInstanceMapper.queryByTenantCodeAndStatus(tenantCode,
-                org.apache.dolphinscheduler.service.utils.Constants.NOT_TERMINATED_STATES))
-                .thenReturn(Collections.emptyList());
-        Mockito.when(scheduleMapper.queryScheduleListByTenant(tenantCode)).thenReturn(Collections.emptyList());
-        Mockito.when(tenantMapper.queryById(4)).thenReturn(getTenant(4));
-        Mockito.when(tenantMapper.deleteById(4)).thenReturn(1);
-        Map<String, Object> result = tenantService.deleteTenantById(getLoginUser(), 4);
-        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        when(tenantMapper.queryById(4)).thenReturn(getTenant(4));
+        when(tenantMapper.deleteById(4)).thenReturn(1);
+        assertDoesNotThrow(() -> tenantService.deleteTenantById(getLoginUser(), 4));
     }
 
     @Test
     public void testVerifyTenantCode() {
-        Mockito.when(tenantMapper.existTenant(tenantCode)).thenReturn(true);
+        when(tenantMapper.existTenant(tenantCode)).thenReturn(true);
         // tenantCode exist
-        Throwable exception = Assertions.assertThrows(ServiceException.class,
+        assertThrowsServiceException(Status.OS_TENANT_CODE_EXIST,
                 () -> tenantService.verifyTenantCode(getTenant().getTenantCode()));
-        String expect = MessageFormat.format(Status.OS_TENANT_CODE_EXIST.getMsg(), getTenant().getTenantCode());
-        Assertions.assertEquals(expect, exception.getMessage());
-
         // success
-        Result result = tenantService.verifyTenantCode("s00000000000l887888885554444sfjdskfjslakslkdf");
-        Assertions.assertEquals(Status.SUCCESS.getMsg(), result.getMsg());
+        assertDoesNotThrow(() -> tenantService.verifyTenantCode("s00000000000l887888885554444sfjdskfjslakslkdf"));
     }
 
     @Test
@@ -272,16 +236,18 @@ public class TenantServiceTest {
         Tenant tenant;
 
         // Tenant exists
-        Mockito.when(tenantMapper.existTenant(tenantCode)).thenReturn(true);
-        Mockito.when(tenantMapper.queryByTenantCode(tenantCode)).thenReturn(getTenant());
+        when(tenantMapper.existTenant(tenantCode)).thenReturn(true);
+        when(tenantMapper.queryByTenantCode(tenantCode)).thenReturn(getTenant());
         tenant = tenantService.createTenantIfNotExists(tenantCode, tenantDesc, queue, queueName);
         Assertions.assertEquals(getTenant(), tenant);
 
         // Tenant not exists
-        Mockito.when(tenantMapper.existTenant(tenantCode)).thenReturn(false);
-        Mockito.when(queueService.createQueueIfNotExists(queue, queueName)).thenReturn(getQueue());
+        when(tenantMapper.existTenant(tenantCode)).thenReturn(false);
+        when(queueService.createQueueIfNotExists(queue, queueName)).thenReturn(getQueue());
         tenant = tenantService.createTenantIfNotExists(tenantCode, tenantDesc, queue, queueName);
-        Assertions.assertEquals(new Tenant(tenantCode, tenantDesc, getQueue().getId()), tenant);
+        Assertions.assertEquals(tenantCode, tenant.getTenantCode());
+        Assertions.assertEquals(tenantDesc, tenant.getDescription());
+        Assertions.assertEquals(getQueue().getId(), tenant.getQueueId());
     }
 
     /**
