@@ -35,8 +35,7 @@ public final class Constants {
      */
     public static final String COMMON_PROPERTIES_PATH = "/common.properties";
 
-    public static final String REGISTRY_DOLPHINSCHEDULER_MASTERS = "/nodes/master";
-    public static final String REGISTRY_DOLPHINSCHEDULER_WORKERS = "/nodes/worker";
+    public static final String REMOTE_LOGGING_YAML_PATH = "/remote-logging.yaml";
 
     public static final String FORMAT_SS = "%s%s";
     public static final String FORMAT_S_S = "%s/%s";
@@ -48,6 +47,7 @@ public final class Constants {
     public static final String RESOURCE_TYPE_UDF = "udfs";
 
     public static final String EMPTY_STRING = "";
+    public static final int MAX_FILE_SIZE = 1024 * 1024 * 1024;
 
     /**
      * resource.hdfs.fs.defaultFS
@@ -191,11 +191,6 @@ public final class Constants {
      */
     public static final String DOUBLE_SLASH = "//";
 
-    /**
-     * EQUAL SIGN
-     */
-    public static final String EQUAL_SIGN = "=";
-
     /**
      * AT SIGN
      */
@@ -235,11 +230,6 @@ public final class Constants {
      */
     public static final int SOCKET_TIMEOUT = 60 * 1000;
 
-    /**
-     * registry session timeout
-     */
-    public static final int REGISTRY_SESSION_TIMEOUT = 10 * 1000;
-
     /**
      * http header
      */
@@ -255,11 +245,6 @@ public final class Constants {
      */
     public static final String HTTP_X_REAL_IP = "X-Real-IP";
 
-    /**
-     * UTF-8
-     */
-    public static final String UTF_8 = "UTF-8";
-
     /**
      * user name regex
      */
@@ -300,22 +285,6 @@ public final class Constants {
      */
     public static final int MAX_TASK_TIMEOUT = 24 * 3600;
 
-    /**
-     * worker host weight
-     */
-    public static final int DEFAULT_WORKER_HOST_WEIGHT = 100;
-
-    /**
-     * time unit second to minutes
-     */
-    public static final int SEC_2_MINUTES_TIME_UNIT = 60;
-
-    /***
-     *
-     * rpc port
-     */
-    public static final String RPC_PORT = "rpc.port";
-
     /**
      * forbid running task
      */
@@ -356,21 +325,6 @@ public final class Constants {
 
     public static final Duration SERVER_CLOSE_WAIT_TIME = Duration.ofSeconds(3);
 
-    /**
-     * one second mils
-     */
-    public static final long SECOND_TIME_MILLIS = 1_000L;
-
-    /**
-     * master task instance cache-database refresh interval
-     */
-    public static final long CACHE_REFRESH_TIME_MILLIS = 20 * 1_000L;
-
-    /**
-     * heartbeat for zk info length
-     */
-    public static final int HEARTBEAT_FOR_ZOOKEEPER_INFO_LENGTH = 14;
-
     /**
      * jar
      */
@@ -408,39 +362,10 @@ public final class Constants {
      */
     public static final int VERSION_FIRST = 1;
 
-    /**
-     * ACCEPTED
-     */
-    public static final String ACCEPTED = "ACCEPTED";
-
-    /**
-     * SUCCEEDED
-     */
-    public static final String SUCCEEDED = "SUCCEEDED";
-    /**
-     * ENDED
-     */
-    public static final String ENDED = "ENDED";
-    /**
-     * NEW
-     */
-    public static final String NEW = "NEW";
-    /**
-     * NEW_SAVING
-     */
-    public static final String NEW_SAVING = "NEW_SAVING";
-    /**
-     * SUBMITTED
-     */
-    public static final String SUBMITTED = "SUBMITTED";
     /**
      * FAILED
      */
     public static final String FAILED = "FAILED";
-    /**
-     * KILLED
-     */
-    public static final String KILLED = "KILLED";
     /**
      * RUNNING
      */
@@ -449,25 +374,11 @@ public final class Constants {
      * underline  "_"
      */
     public static final String UNDERLINE = "_";
-    /**
-     * application regex
-     */
-    public static final String APPLICATION_REGEX = "application_\\d+_\\d+";
+
     public static final String PID = SystemUtils.IS_OS_WINDOWS ? "handle" : "pid";
 
-    public static final char SUBTRACT_CHAR = '-';
-    public static final char ADD_CHAR = '+';
-    public static final char MULTIPLY_CHAR = '*';
-    public static final char DIVISION_CHAR = '/';
-    public static final char LEFT_BRACE_CHAR = '(';
-    public static final char RIGHT_BRACE_CHAR = ')';
-    public static final String ADD_STRING = "+";
     public static final String STAR = "*";
-    public static final String DIVISION_STRING = "/";
-    public static final String LEFT_BRACE_STRING = "(";
-    public static final char P = 'P';
     public static final char N = 'N';
-    public static final String SUBTRACT_STRING = "-";
     public static final String GLOBAL_PARAMS = "globalParams";
     public static final String LOCAL_PARAMS = "localParams";
     public static final String SUBPROCESS_INSTANCE_ID = "subProcessInstanceId";
@@ -482,13 +393,11 @@ public final class Constants {
     public static final String QUEUE_NAME = "queueName";
     public static final int LOG_QUERY_SKIP_LINE_NUMBER = 0;
     public static final int LOG_QUERY_LIMIT = 4096;
-    public static final String BLOCKING_CONDITION = "blockingCondition";
-    public static final String ALERT_WHEN_BLOCKING = "alertWhenBlocking";
-
     public static final String ALIAS = "alias";
     public static final String CONTENT = "content";
     public static final String DEPENDENT_SPLIT = ":||";
-    public static final long DEPENDENT_ALL_TASK_CODE = 0;
+    public static final long DEPENDENT_ALL_TASK_CODE = -1;
+    public static final long DEPENDENT_WORKFLOW_CODE = 0;
 
     /**
      * preview schedule execute count
@@ -526,11 +435,6 @@ public final class Constants {
     public static final String HADOOP_SECURITY_AUTHENTICATION_STARTUP_STATE =
             "hadoop.security.authentication.startup.state";
 
-    /**
-     * com.amazonaws.services.s3.enableV4
-     */
-    public static final String AWS_S3_V4 = "com.amazonaws.services.s3.enableV4";
-
     /**
      * loginUserFromKeytab user
      */
@@ -549,11 +453,6 @@ public final class Constants {
     public static final String WORKFLOW_INSTANCE_ID_MDC_KEY = "workflowInstanceId";
     public static final String TASK_INSTANCE_ID_MDC_KEY = "taskInstanceId";
 
-    /**
-     * task log info format
-     */
-    public static final String TASK_LOG_INFO_FORMAT = "TaskLogInfo-%s";
-
     /**
      * double brackets left
      */
@@ -634,22 +533,13 @@ public final class Constants {
      * session timeout
      */
     public static final int SESSION_TIME_OUT = 7200;
-    public static final int MAX_FILE_SIZE = 1024 * 1024 * 1024;
     public static final String UDF = "UDF";
     public static final String CLASS = "class";
 
-    /**
-     * default worker group
-     */
-    public static final String DEFAULT_WORKER_GROUP = "default";
     /**
      * authorize writable perm
      */
     public static final int AUTHORIZE_WRITABLE_PERM = 7;
-    /**
-     * authorize readable perm
-     */
-    public static final int AUTHORIZE_READABLE_PERM = 4;
 
     public static final String START_TIME = "start time";
     public static final String END_TIME = "end time";
@@ -681,15 +571,11 @@ public final class Constants {
      */
     public static final String DATA_QUALITY_ERROR_OUTPUT_PATH = "data-quality.error.output.path";
 
-    public static final String CACHE_KEY_VALUE_ALL = "'all'";
-
     /**
      * use for k8s
      */
     public static final String NAMESPACE = "namespace";
     public static final String CLUSTER = "cluster";
-    public static final String LIMITS_CPU = "limitsCpu";
-    public static final String LIMITS_MEMORY = "limitsMemory";
     public static final Long K8S_LOCAL_TEST_CLUSTER_CODE = 0L;
 
     /**
@@ -785,20 +671,11 @@ public final class Constants {
      */
     public static final String SUPPORT_HIVE_ONE_SESSION = "support.hive.oneSession";
 
-    public static final String PRINCIPAL = "principal";
-    public static final String ORACLE_DB_CONNECT_TYPE = "connectType";
-    public static final String KERBEROS_KRB5_CONF_PATH = "javaSecurityKrb5Conf";
-    public static final String KERBEROS_KEY_TAB_USERNAME = "loginUserKeytabUsername";
-    public static final String KERBEROS_KEY_TAB_PATH = "loginUserKeytabPath";
-
     public static final Integer QUERY_ALL_ON_SYSTEM = 0;
     public static final Integer QUERY_ALL_ON_PROJECT = 1;
     public static final Integer QUERY_ALL_ON_WORKFLOW = 2;
     public static final Integer QUERY_ALL_ON_TASK = 3;
 
-    /**
-     * remote logging
-     */
     public static final String REMOTE_LOGGING_ENABLE = "remote.logging.enable";
 
     public static final String REMOTE_LOGGING_TARGET = "remote.logging.target";
@@ -838,6 +715,13 @@ public final class Constants {
 
     public static final String REMOTE_LOGGING_GCS_BUCKET_NAME = "remote.logging.google.cloud.storage.bucket.name";
 
+    /**
+     * remote logging for ABS
+     */
+    public static final String REMOTE_LOGGING_ABS_ACCOUNT_NAME = "remote.logging.abs.account.name";
+    public static final String REMOTE_LOGGING_ABS_ACCOUNT_KEY = "remote.logging.abs.account.key";
+    public static final String REMOTE_LOGGING_ABS_CONTAINER_NAME = "remote.logging.abs.container.name";
+
     /**
      * data quality
      */
@@ -848,4 +732,8 @@ public final class Constants {
      * K8S sensitive param
      */
     public static final String K8S_CONFIG_REGEX = "(?<=((?i)configYaml(\" : \"))).*?(?=(\",\\n))";
+
+    public static final String RELEASE_STATE = "releaseState";
+    public static final String EXECUTE_TYPE = "executeType";
+
 }
