@@ -21,8 +21,8 @@ import org.apache.dolphinscheduler.common.constants.Constants;
 
 import org.apache.commons.lang3.SystemUtils;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 /**
  * Constants Test
@@ -35,9 +35,9 @@ public class ConstantsTest {
     @Test
     public void testPID() {
         if (SystemUtils.IS_OS_WINDOWS) {
-            Assert.assertEquals(Constants.PID, "handle");
+            Assertions.assertEquals(Constants.PID, "handle");
         } else {
-            Assert.assertEquals(Constants.PID, "pid");
+            Assertions.assertEquals(Constants.PID, "pid");
         }
     }
 
