@@ -17,6 +17,7 @@
 package org.apache.dolphinscheduler.dao.entity;
 
 import java.util.Date;
+import java.util.Objects;
 
 import lombok.Data;
 
@@ -82,7 +83,7 @@ public class Queue {
 
         Queue queue1 = (Queue) o;
 
-        if (id != queue1.id) {
+        if (!Objects.equals(id, queue1.id)) {
             return false;
         }
         if (!queueName.equals(queue1.queueName)) {
