@@ -17,7 +17,6 @@
 
 package org.apache.dolphinscheduler.dao.entity;
 
-import static org.apache.dolphinscheduler.common.constants.Constants.SEC_2_MINUTES_TIME_UNIT;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_BLOCKING;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_CONDITIONS;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_DEPENDENT;
@@ -32,12 +31,17 @@ import org.apache.dolphinscheduler.common.enums.TaskExecuteType;
 import org.apache.dolphinscheduler.common.utils.DateUtils;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
+import org.apache.dolphinscheduler.plugin.task.api.parameters.ConditionsParameters;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.DependentParameters;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.SwitchParameters;
 
+import org.apache.commons.lang3.StringUtils;
+
 import java.io.Serializable;
 import java.util.Date;
+import java.util.HashMap;
 import java.util.Map;
+import java.util.concurrent.TimeUnit;
 
 import lombok.Data;
 
@@ -192,6 +196,9 @@ public class TaskInstance implements Serializable {
     @TableField(exist = false)
     private DependentParameters dependency;
 
+    @TableField(exist = false)
+    private ConditionsParameters conditionsParameters;
+
     /**
      * switch dependency
      */
@@ -258,9 +265,6 @@ public class TaskInstance implements Serializable {
 
     private String executorName;
 
-    @TableField(exist = false)
-    private Map<String, String> resources;
-
     /**
      * delay execution time.
      */
@@ -321,6 +325,43 @@ public class TaskInstance implements Serializable {
         this.dependency = dependency;
     }
 
+    public ConditionsParameters getConditionsParameters() {
+        if (this.conditionsParameters == null) {
+            Map<String, Object> taskParamsMap =
+                    JSONUtils.parseObject(this.getTaskParams(), new TypeReference<Map<String, Object>>() {
+                    });
+            this.conditionsParameters =
+                    JSONUtils.parseObject((String) taskParamsMap.get(Constants.DEPENDENCE), ConditionsParameters.class);
+        }
+        return conditionsParameters;
+    }
+
+    public ConditionsParameters.ConditionResult getConditionResult() {
+        Map<String, Object> taskParamsMap =
+                JSONUtils.parseObject(this.getTaskParams(), new TypeReference<Map<String, Object>>() {
+                });
+        String conditionResult = (String) taskParamsMap.getOrDefault(Constants.CONDITION_RESULT, "");
+        if (StringUtils.isNotEmpty(conditionResult)) {
+            return JSONUtils.parseObject(conditionResult, new TypeReference<ConditionsParameters.ConditionResult>() {
+            });
+        }
+        return null;
+    }
+
+    public void setConditionResult(ConditionsParameters conditionsParameters) {
+        if (conditionsParameters == null) {
+            return;
+        }
+        Map<String, Object> taskParamsMap =
+                JSONUtils.parseObject(this.getTaskParams(), new TypeReference<Map<String, Object>>() {
+                });
+        if (taskParamsMap == null) {
+            taskParamsMap = new HashMap<>();
+        }
+        taskParamsMap.put(Constants.CONDITION_RESULT, JSONUtils.toJsonString(conditionsParameters));
+        this.setTaskParams(JSONUtils.toJsonString(taskParamsMap));
+    }
+
     public SwitchParameters getSwitchDependency() {
         // todo: We need to directly use Jackson to deserialize the taskParam, rather than parse the map and get from
         // field.
@@ -410,7 +451,7 @@ public class TaskInstance implements Serializable {
         Date now = new Date();
         long failedTimeInterval = DateUtils.differSec(now, getEndTime());
         // task retry does not over time, return false
-        return getRetryInterval() * SEC_2_MINUTES_TIME_UNIT < failedTimeInterval;
+        return TimeUnit.MINUTES.toSeconds(getRetryInterval()) < failedTimeInterval;
     }
 
 }
