@@ -26,6 +26,8 @@ import java.util.Date;
 import java.util.List;
 
 import com.baomidou.mybatisplus.core.mapper.BaseMapper;
+import com.baomidou.mybatisplus.core.metadata.IPage;
+import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 
 /**
  * error command mapper interface
@@ -36,11 +38,16 @@ public interface ErrorCommandMapper extends BaseMapper<ErrorCommand> {
      * count command state
      * @param startTime startTime
      * @param endTime endTime
-     * @param projectCodeArray projectCodeArray
+     * @param projectCodes projectCodes
      * @return CommandCount list
      */
     List<CommandCount> countCommandState(
                                          @Param("startTime") Date startTime,
                                          @Param("endTime") Date endTime,
-                                         @Param("projectCodeArray") Long[] projectCodeArray);
+                                         @Param("projectCodes") List<Long> projectCodes);
+
+    IPage<ErrorCommand> queryErrorCommandPage(Page<ErrorCommand> page);
+
+    IPage<ErrorCommand> queryErrorCommandPageByIds(Page<ErrorCommand> page,
+                                                   @Param("workflowDefinitionCodes") List<Long> workflowDefinitionCodes);
 }
