@@ -18,7 +18,7 @@
 package org.apache.dolphinscheduler.plugin.datasource.api.utils;
 
 import static org.apache.dolphinscheduler.common.constants.Constants.RESOURCE_STORAGE_TYPE;
-import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.DATA_QUALITY_JAR_NAME;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.DATA_QUALITY_JAR_DIR;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.HADOOP_SECURITY_AUTHENTICATION;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.HADOOP_SECURITY_AUTHENTICATION_STARTUP_STATE;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.JAVA_SECURITY_KRB5_CONF;
@@ -28,6 +28,7 @@ import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.LOGIN_US
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.LOGIN_USER_KEY_TAB_USERNAME;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.RESOURCE_UPLOAD_PATH;
 
+import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.ResUploadType;
 import org.apache.dolphinscheduler.common.utils.PropertyUtils;
 
@@ -35,17 +36,35 @@ import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.security.UserGroupInformation;
 
+import java.io.File;
 import java.io.IOException;
+import java.util.Optional;
+
+import lombok.extern.slf4j.Slf4j;
+
+import org.springframework.core.io.ClassPathResource;
 
 /**
  * common utils
  */
+@Slf4j
 public class CommonUtils {
 
     private CommonUtils() {
         throw new UnsupportedOperationException("Construct CommonUtils");
     }
 
+    private static String DEFAULT_DATA_QUALITY_JAR_PATH = null;
+
+    private static final boolean IS_DEVELOP_MODE = PropertyUtils.getBoolean(Constants.DEVELOPMENT_STATE, true);
+
+    /**
+     * @return is develop mode
+     */
+    public static boolean isDevelopMode() {
+        return IS_DEVELOP_MODE;
+    }
+
     /**
      * if upload resource is HDFS and kerberos startup is true , else false
      *
@@ -74,12 +93,13 @@ public class CommonUtils {
     /**
      * load kerberos configuration
      *
-     * @param javaSecurityKrb5Conf javaSecurityKrb5Conf
+     * @param javaSecurityKrb5Conf    javaSecurityKrb5Conf
      * @param loginUserKeytabUsername loginUserKeytabUsername
-     * @param loginUserKeytabPath loginUserKeytabPath
+     * @param loginUserKeytabPath     loginUserKeytabPath
      * @throws IOException errors
      */
-    public static synchronized void loadKerberosConf(String javaSecurityKrb5Conf, String loginUserKeytabUsername,
+    public static synchronized void loadKerberosConf(String javaSecurityKrb5Conf,
+                                                     String loginUserKeytabUsername,
                                                      String loginUserKeytabPath) throws IOException {
         Configuration configuration = new Configuration();
         configuration.setClassLoader(configuration.getClass().getClassLoader());
@@ -112,14 +132,71 @@ public class CommonUtils {
         return false;
     }
 
-    public static String getDataQualityJarName() {
-        String dqsJarName = PropertyUtils.getString(DATA_QUALITY_JAR_NAME);
+    public static String getDataQualityJarPath() {
+        log.info("Trying to get data quality jar in path");
+        String dqJarDir = PropertyUtils.getString(DATA_QUALITY_JAR_DIR);
 
-        if (StringUtils.isEmpty(dqsJarName)) {
-            return "dolphinscheduler-data-quality.jar";
+        if (StringUtils.isNotEmpty(dqJarDir)) {
+            log.info(
+                    "Configuration data-quality.jar.dir is not empty, will try to get data quality jar from directory {}",
+                    dqJarDir);
+            getDataQualityJarPathFromPath(dqJarDir).ifPresent(jarName -> DEFAULT_DATA_QUALITY_JAR_PATH = jarName);
         }
 
-        return dqsJarName;
+        if (StringUtils.isEmpty(DEFAULT_DATA_QUALITY_JAR_PATH)) {
+            log.info("data quality jar path is empty, will try to auto discover it from build-in rules.");
+            getDefaultDataQualityJarPath();
+        }
+
+        if (StringUtils.isEmpty(DEFAULT_DATA_QUALITY_JAR_PATH)) {
+            log.error(
+                    "Can not find data quality jar in both configuration and auto discover, please check your configuration or report a bug.");
+            throw new RuntimeException("data quality jar path is empty");
+        }
+
+        return DEFAULT_DATA_QUALITY_JAR_PATH;
+    }
+
+    private static String getDefaultDataQualityJarPath() {
+        if (StringUtils.isNotEmpty(DEFAULT_DATA_QUALITY_JAR_PATH)) {
+            return DEFAULT_DATA_QUALITY_JAR_PATH;
+        }
+        try {
+            // not standalone mode
+            String currentAbsolutePath = new ClassPathResource("./").getFile().getAbsolutePath();
+            String currentLibPath = currentAbsolutePath + "/../libs";
+            getDataQualityJarPathFromPath(currentLibPath).ifPresent(jarName -> DEFAULT_DATA_QUALITY_JAR_PATH = jarName);
+
+            // standalone mode
+            if (StringUtils.isEmpty(DEFAULT_DATA_QUALITY_JAR_PATH)) {
+                log.info(
+                        "Can not get data quality jar from path {}, maybe service running in standalone mode, will try to find another path",
+                        currentLibPath);
+                currentLibPath = currentAbsolutePath + "/../../worker-server/libs";
+                getDataQualityJarPathFromPath(currentLibPath)
+                        .ifPresent(jarName -> DEFAULT_DATA_QUALITY_JAR_PATH = jarName);
+            }
+        } catch (IOException e) {
+            throw new RuntimeException("get default data quality jar path error", e);
+        }
+        log.info("get default data quality jar name: {}", DEFAULT_DATA_QUALITY_JAR_PATH);
+        return DEFAULT_DATA_QUALITY_JAR_PATH;
+    }
+
+    private static Optional<String> getDataQualityJarPathFromPath(String path) {
+        log.info("Try to get data quality jar from path {}", path);
+        File[] jars = new File(path).listFiles();
+        if (jars == null) {
+            log.warn("No any files find given path {}", path);
+            return Optional.empty();
+        }
+        for (File jar : jars) {
+            if (jar.getName().startsWith("dolphinscheduler-data-quality")) {
+                return Optional.of(jar.getAbsolutePath());
+            }
+        }
+        log.warn("No data quality related jar found from path {}", path);
+        return Optional.empty();
     }
 
     /**
