@@ -65,6 +65,12 @@ public abstract class TaskNodeForm {
     })
     private WebElement selectPreTasks;
 
+    @FindBys({
+            @FindBy(className = "env-select"),
+            @FindBy(className = "n-base-selection"),
+    })
+    private WebElement selectEnv;
+
     @FindBys({
             @FindBy(className = "btn-custom-parameters"),
             @FindBy(tagName = "button"),
@@ -112,6 +118,25 @@ public abstract class TaskNodeForm {
         return this;
     }
 
+    public TaskNodeForm selectEnv(String envName){
+        ((JavascriptExecutor)parent().driver()).executeScript("arguments[0].click();", selectEnv);
+
+        final By optionsLocator = By.className("n-base-selection-input__content");
+
+        new WebDriverWait(parent.driver(), Duration.ofSeconds(20))
+                .until(ExpectedConditions.visibilityOfElementLocated(optionsLocator));
+
+        List<WebElement> webElements =  parent.driver().findElements(optionsLocator);
+
+        webElements.stream()
+                .filter(it -> it.getText().contains(envName))
+                .findFirst()
+                .orElseThrow(() -> new RuntimeException("No such envName: " + envName))
+                .click();
+
+        return this;
+    }
+
     public TaskNodeForm preTask(String preTaskName) {
         ((JavascriptExecutor)parent().driver()).executeScript("arguments[0].click();", selectPreTasks);
 
