@@ -25,25 +25,23 @@ import org.apache.dolphinscheduler.server.master.runner.WorkflowExecuteRunnable;
 
 import java.util.Optional;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
 
 import com.google.auto.service.AutoService;
 
 @AutoService(StateEventHandler.class)
+@Slf4j
 public class WorkflowBlockStateEventHandler implements StateEventHandler {
 
-    private static final Logger logger = LoggerFactory.getLogger(WorkflowBlockStateEventHandler.class);
-
     @Override
-    public boolean handleStateEvent(WorkflowExecuteRunnable workflowExecuteRunnable, StateEvent stateEvent)
-        throws StateEventHandleError {
-        logger.info("Handle workflow instance state block event");
+    public boolean handleStateEvent(WorkflowExecuteRunnable workflowExecuteRunnable,
+                                    StateEvent stateEvent) throws StateEventHandleError {
+        log.info("Handle workflow instance state block event");
         Optional<TaskInstance> taskInstanceOptional =
-            workflowExecuteRunnable.getTaskInstance(stateEvent.getTaskInstanceId());
+                workflowExecuteRunnable.getTaskInstance(stateEvent.getTaskInstanceId());
         if (!taskInstanceOptional.isPresent()) {
             throw new StateEventHandleError("Cannot find taskInstance from taskMap by taskInstanceId: "
-                + stateEvent.getTaskInstanceId());
+                    + stateEvent.getTaskInstanceId());
         }
         TaskInstance task = taskInstanceOptional.get();
 
