@@ -17,40 +17,36 @@
 
 package org.apache.dolphinscheduler.server.master.runner;
 
-import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
-import org.apache.dolphinscheduler.plugin.task.api.enums.TaskTimeoutStrategy;
 import org.apache.dolphinscheduler.common.enums.TimeoutFlag;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
+import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
+import org.apache.dolphinscheduler.plugin.task.api.enums.TaskTimeoutStrategy;
 import org.apache.dolphinscheduler.service.bean.SpringApplicationContext;
 import org.apache.dolphinscheduler.service.process.ProcessService;
 
 import java.util.HashSet;
 import java.util.Set;
 
-import org.junit.Before;
-import org.junit.Ignore;
-import org.junit.Test;
-import org.junit.runner.RunWith;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.mockito.Mockito;
-import org.mockito.junit.MockitoJUnitRunner;
-import org.powermock.api.mockito.PowerMockito;
+import org.mockito.junit.jupiter.MockitoExtension;
 import org.springframework.context.ApplicationContext;
 
-@RunWith(MockitoJUnitRunner.Silent.class)
-@Ignore
+@ExtendWith(MockitoExtension.class)
+@Disabled
 public class MasterTaskExecThreadTest {
 
     private SpringApplicationContext springApplicationContext;
 
-    @Before
+    @BeforeEach
     public void setUp() {
-        ApplicationContext applicationContext = PowerMockito.mock(ApplicationContext.class);
+        ApplicationContext applicationContext = Mockito.mock(ApplicationContext.class);
         this.springApplicationContext = new SpringApplicationContext();
         springApplicationContext.setApplicationContext(applicationContext);
-        // this.registryCenter = PowerMockito.mock(RegistryCenter.class);
-        // PowerMockito.when(SpringApplicationContext.getBean(RegistryCenter.class))
-        // .thenReturn(this.registryCenter);
         ProcessService processService = Mockito.mock(ProcessService.class);
         Mockito.when(SpringApplicationContext.getBean(ProcessService.class))
                 .thenReturn(processService);
@@ -58,18 +54,10 @@ public class MasterTaskExecThreadTest {
         taskDefinition.setTimeoutFlag(TimeoutFlag.OPEN);
         taskDefinition.setTimeoutNotifyStrategy(TaskTimeoutStrategy.WARN);
         taskDefinition.setTimeout(0);
-        Mockito.when(processService.findTaskDefinition(1L, 1))
-                .thenReturn(taskDefinition);
-        // this.masterTaskExecThread = new MasterTaskExecThread(getTaskInstance());
     }
 
     @Test
     public void testExistsValidWorkerGroup1() {
-
-        /*
-         * Mockito.when(registryCenter.getWorkerGroupDirectly()).thenReturn(Sets.newHashSet()); boolean b =
-         * masterTaskExecThread.existsValidWorkerGroup("default"); Assert.assertFalse(b);
-         */
     }
 
     @Test
@@ -77,22 +65,12 @@ public class MasterTaskExecThreadTest {
         Set<String> workerGroups = new HashSet<>();
         workerGroups.add("test1");
         workerGroups.add("test2");
-
-        /*
-         * Mockito.when(registryCenter.getWorkerGroupDirectly()).thenReturn(workerGroups); boolean b =
-         * masterTaskExecThread.existsValidWorkerGroup("default"); Assert.assertFalse(b);
-         */
     }
 
     @Test
     public void testExistsValidWorkerGroup3() {
         Set<String> workerGroups = new HashSet<>();
         workerGroups.add("test1");
-        /*
-         * Mockito.when(registryCenter.getWorkerGroupDirectly()).thenReturn(workerGroups);
-         * Mockito.when(registryCenter.getWorkerGroupNodesDirectly("test1")).thenReturn(workerGroups); boolean b =
-         * masterTaskExecThread.existsValidWorkerGroup("test1"); Assert.assertTrue(b);
-         */
     }
 
     @Test
@@ -100,24 +78,10 @@ public class MasterTaskExecThreadTest {
         ProcessService processService = Mockito.mock(ProcessService.class);
         Mockito.when(SpringApplicationContext.getBean(ProcessService.class))
                 .thenReturn(processService);
-
-        TaskInstance taskInstance = getTaskInstance();
-        Mockito.when(processService.findTaskInstanceById(252612))
-                .thenReturn(taskInstance);
-
-        Mockito.when(processService.updateTaskInstance(taskInstance))
-                .thenReturn(true);
-
         TaskDefinition taskDefinition = new TaskDefinition();
         taskDefinition.setTimeoutFlag(TimeoutFlag.OPEN);
         taskDefinition.setTimeoutNotifyStrategy(TaskTimeoutStrategy.WARN);
         taskDefinition.setTimeout(0);
-        Mockito.when(processService.findTaskDefinition(1L, 1))
-                .thenReturn(taskDefinition);
-
-        // MasterTaskExecThread masterTaskExecThread = new MasterTaskExecThread(taskInstance);
-        // masterTaskExecThread.pauseTask();
-        // org.junit.Assert.assertEquals(ExecutionStatus.PAUSE, taskInstance.getState());
     }
 
     private TaskInstance getTaskInstance() {
