@@ -38,9 +38,9 @@ import org.apache.dolphinscheduler.dao.repository.TaskInstanceDao;
 import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 import org.apache.dolphinscheduler.server.master.config.MasterConfig;
 import org.apache.dolphinscheduler.server.master.graph.IWorkflowGraph;
-import org.apache.dolphinscheduler.server.master.rpc.MasterRpcClient;
 import org.apache.dolphinscheduler.server.master.runner.execute.DefaultTaskExecuteRunnableFactory;
-import org.apache.dolphinscheduler.server.master.runner.execute.TaskExecuteRunnable;
+import org.apache.dolphinscheduler.server.master.runner.taskgroup.TaskGroupCoordinator;
+import org.apache.dolphinscheduler.service.alert.ListenerEventAlertManager;
 import org.apache.dolphinscheduler.service.alert.ProcessAlertManager;
 import org.apache.dolphinscheduler.service.bean.SpringApplicationContext;
 import org.apache.dolphinscheduler.service.command.CommandService;
@@ -50,7 +50,6 @@ import org.apache.dolphinscheduler.service.process.ProcessService;
 
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
-import java.text.ParseException;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Date;
@@ -72,6 +71,7 @@ import org.mockito.junit.jupiter.MockitoSettings;
 import org.mockito.quality.Strictness;
 import org.springframework.context.ApplicationContext;
 
+import com.google.common.collect.Lists;
 import com.google.common.collect.Sets;
 
 @ExtendWith(MockitoExtension.class)
@@ -103,6 +103,12 @@ public class WorkflowExecuteRunnableTest {
 
     private WorkflowExecuteContextFactory workflowExecuteContextFactory;
 
+    private ListenerEventAlertManager listenerEventAlertManager;
+
+    private TaskGroupCoordinator taskGroupCoordinator;
+
+    private WorkflowExecuteContext workflowExecuteContext;
+
     @BeforeEach
     public void init() throws Exception {
         applicationContext = Mockito.mock(ApplicationContext.class);
@@ -118,6 +124,7 @@ public class WorkflowExecuteRunnableTest {
         taskDefinitionLogDao = Mockito.mock(TaskDefinitionLogDao.class);
         defaultTaskExecuteRunnableFactory = Mockito.mock(DefaultTaskExecuteRunnableFactory.class);
         workflowExecuteContextFactory = Mockito.mock(WorkflowExecuteContextFactory.class);
+        listenerEventAlertManager = Mockito.mock(ListenerEventAlertManager.class);
 
         Map<String, String> cmdParam = new HashMap<>();
         cmdParam.put(CMD_PARAM_COMPLEMENT_DATA_START_DATE, "2020-01-01 00:00:00");
@@ -129,31 +136,33 @@ public class WorkflowExecuteRunnableTest {
 
         stateWheelExecuteThread = Mockito.mock(StateWheelExecuteThread.class);
         curingGlobalParamsService = Mockito.mock(CuringParamsService.class);
-        MasterRpcClient masterRpcClient = Mockito.mock(MasterRpcClient.class);
         ProcessAlertManager processAlertManager = Mockito.mock(ProcessAlertManager.class);
-        WorkflowExecuteContext workflowExecuteContext = Mockito.mock(WorkflowExecuteContext.class);
+        workflowExecuteContext = Mockito.mock(WorkflowExecuteContext.class);
         Mockito.when(workflowExecuteContext.getWorkflowInstance()).thenReturn(processInstance);
         IWorkflowGraph workflowGraph = Mockito.mock(IWorkflowGraph.class);
         Mockito.when(workflowExecuteContext.getWorkflowGraph()).thenReturn(workflowGraph);
         Mockito.when(workflowGraph.getDag()).thenReturn(new DAG<>());
 
+        taskGroupCoordinator = Mockito.mock(TaskGroupCoordinator.class);
+
         workflowExecuteThread = Mockito.spy(
                 new WorkflowExecuteRunnable(
                         workflowExecuteContext,
                         commandService,
                         processService,
                         processInstanceDao,
-                        masterRpcClient,
                         processAlertManager,
                         config,
                         stateWheelExecuteThread,
                         curingGlobalParamsService,
                         taskInstanceDao,
-                        defaultTaskExecuteRunnableFactory));
+                        defaultTaskExecuteRunnableFactory,
+                        listenerEventAlertManager,
+                        taskGroupCoordinator));
     }
 
     @Test
-    public void testParseStartNodeName() throws ParseException {
+    public void testParseStartNodeName() {
         try {
             Map<String, String> cmdParam = new HashMap<>();
             cmdParam.put(CMD_PARAM_START_NODES, "1,2,3");
@@ -203,11 +212,13 @@ public class WorkflowExecuteRunnableTest {
     }
 
     @Test
-    public void testGetPreVarPool() {
+    public void testInitializeTaskInstanceVarPool() {
         try {
-            Set<Long> preTaskName = new HashSet<>();
-            preTaskName.add(1L);
-            preTaskName.add(2L);
+            IWorkflowGraph workflowGraph = Mockito.mock(IWorkflowGraph.class);
+            Mockito.when(workflowExecuteContext.getWorkflowGraph()).thenReturn(workflowGraph);
+            TaskNode taskNode = Mockito.mock(TaskNode.class);
+            Mockito.when(workflowGraph.getTaskNodeByCode(Mockito.anyLong())).thenReturn(taskNode);
+            Mockito.when(taskNode.getPreTasks()).thenReturn(JSONUtils.toJsonString(Lists.newArrayList(1L, 2L)));
 
             TaskInstance taskInstance = new TaskInstance();
 
@@ -249,7 +260,7 @@ public class WorkflowExecuteRunnableTest {
             taskCodeInstanceMapField.setAccessible(true);
             taskCodeInstanceMapField.set(workflowExecuteThread, taskCodeInstanceMap);
 
-            workflowExecuteThread.getPreVarPool(taskInstance, preTaskName);
+            workflowExecuteThread.initializeTaskInstanceVarPool(taskInstance);
             Assertions.assertNotNull(taskInstance.getVarPool());
 
             taskInstance2.setVarPool("[{\"direct\":\"OUT\",\"prop\":\"test1\",\"type\":\"VARCHAR\",\"value\":\"2\"}]");
@@ -260,7 +271,7 @@ public class WorkflowExecuteRunnableTest {
             taskInstanceMapField.setAccessible(true);
             taskInstanceMapField.set(workflowExecuteThread, taskInstanceMap);
 
-            workflowExecuteThread.getPreVarPool(taskInstance, preTaskName);
+            workflowExecuteThread.initializeTaskInstanceVarPool(taskInstance);
             Assertions.assertNotNull(taskInstance.getVarPool());
         } catch (Exception e) {
             Assertions.fail();
