@@ -30,7 +30,7 @@ import org.apache.dolphinscheduler.plugin.task.api.parameters.SwitchParameters;
 import org.apache.dolphinscheduler.service.model.TaskNode;
 import org.apache.dolphinscheduler.service.process.ProcessDag;
 
-import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
 
 import java.util.ArrayList;
@@ -42,16 +42,14 @@ import java.util.Map;
 import java.util.Optional;
 import java.util.Set;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
 
 /**
  * dag tools
  */
+@Slf4j
 public class DagHelper {
 
-    private static final Logger logger = LoggerFactory.getLogger(DagHelper.class);
-
     /**
      * generate flow node relation list by task node list;
      * Edges that are not in the task Node List will not be added to the result
@@ -63,11 +61,11 @@ public class DagHelper {
         List<TaskNodeRelation> nodeRelationList = new ArrayList<>();
         for (TaskNode taskNode : taskNodeList) {
             String preTasks = taskNode.getPreTasks();
-            List<String> preTaskList = JSONUtils.toList(preTasks, String.class);
+            List<Long> preTaskList = JSONUtils.toList(preTasks, Long.class);
             if (preTaskList != null) {
-                for (String depNodeCode : preTaskList) {
+                for (Long depNodeCode : preTaskList) {
                     if (null != findNodeByCode(taskNodeList, depNodeCode)) {
-                        nodeRelationList.add(new TaskNodeRelation(depNodeCode, Long.toString(taskNode.getCode())));
+                        nodeRelationList.add(new TaskNodeRelation(depNodeCode, taskNode.getCode()));
                     }
                 }
             }
@@ -78,21 +76,21 @@ public class DagHelper {
     /**
      * generate task nodes needed by dag
      *
-     * @param taskNodeList taskNodeList
-     * @param startNodeNameList startNodeNameList
+     * @param taskNodeList         taskNodeList
+     * @param startNodeNameList    startNodeNameList
      * @param recoveryNodeCodeList recoveryNodeCodeList
-     * @param taskDependType taskDependType
+     * @param taskDependType       taskDependType
      * @return task node list
      */
     public static List<TaskNode> generateFlowNodeListByStartNode(List<TaskNode> taskNodeList,
-                                                                 List<String> startNodeNameList,
-                                                                 List<String> recoveryNodeCodeList,
+                                                                 List<Long> startNodeNameList,
+                                                                 List<Long> recoveryNodeCodeList,
                                                                  TaskDependType taskDependType) {
         List<TaskNode> destFlowNodeList = new ArrayList<>();
-        List<String> startNodeList = startNodeNameList;
+        List<Long> startNodeList = startNodeNameList;
 
         if (taskDependType != TaskDependType.TASK_POST && CollectionUtils.isEmpty(startNodeList)) {
-            logger.error("start node list is empty! cannot continue run the process ");
+            log.error("start node list is empty! cannot continue run the process ");
             return destFlowNodeList;
         }
 
@@ -108,19 +106,19 @@ public class DagHelper {
             tmpTaskNodeList = taskNodeList;
         } else {
             // specified start nodes or resume execution
-            for (String startNodeCode : startNodeList) {
+            for (Long startNodeCode : startNodeList) {
                 TaskNode startNode = findNodeByCode(taskNodeList, startNodeCode);
                 List<TaskNode> childNodeList = new ArrayList<>();
                 if (startNode == null) {
-                    logger.error("start node name [{}] is not in task node list [{}] ",
+                    log.error("start node name [{}] is not in task node list [{}] ",
                             startNodeCode,
                             taskNodeList);
                     continue;
                 } else if (TaskDependType.TASK_POST == taskDependType) {
-                    List<String> visitedNodeCodeList = new ArrayList<>();
+                    List<Long> visitedNodeCodeList = new ArrayList<>();
                     childNodeList = getFlowNodeListPost(startNode, taskNodeList, visitedNodeCodeList);
                 } else if (TaskDependType.TASK_PRE == taskDependType) {
-                    List<String> visitedNodeCodeList = new ArrayList<>();
+                    List<Long> visitedNodeCodeList = new ArrayList<>();
                     childNodeList =
                             getFlowNodeListPre(startNode, recoveryNodeCodeList, taskNodeList, visitedNodeCodeList);
                 } else {
@@ -131,7 +129,7 @@ public class DagHelper {
         }
 
         for (TaskNode taskNode : tmpTaskNodeList) {
-            if (null == findNodeByCode(destTaskNodeList, Long.toString(taskNode.getCode()))) {
+            if (null == findNodeByCode(destTaskNodeList, taskNode.getCode())) {
                 destTaskNodeList.add(taskNode);
             }
         }
@@ -141,23 +139,24 @@ public class DagHelper {
     /**
      * find all the nodes that depended on the start node
      *
-     * @param startNode startNode
+     * @param startNode    startNode
      * @param taskNodeList taskNodeList
      * @return task node list
      */
-    private static List<TaskNode> getFlowNodeListPost(TaskNode startNode, List<TaskNode> taskNodeList,
-                                                      List<String> visitedNodeCodeList) {
+    private static List<TaskNode> getFlowNodeListPost(TaskNode startNode,
+                                                      List<TaskNode> taskNodeList,
+                                                      List<Long> visitedNodeCodeList) {
         List<TaskNode> resultList = new ArrayList<>();
         for (TaskNode taskNode : taskNodeList) {
-            List<String> depList = taskNode.getDepList();
-            if (null != depList && null != startNode && depList.contains(Long.toString(startNode.getCode()))
-                    && !visitedNodeCodeList.contains(Long.toString(taskNode.getCode()))) {
+            List<Long> depList = taskNode.getDepList();
+            if (null != depList && null != startNode && depList.contains(startNode.getCode())
+                    && !visitedNodeCodeList.contains(taskNode.getCode())) {
                 resultList.addAll(getFlowNodeListPost(taskNode, taskNodeList, visitedNodeCodeList));
             }
         }
         // why add (startNode != null) condition? for SonarCloud Quality Gate passed
         if (null != startNode) {
-            visitedNodeCodeList.add(Long.toString(startNode.getCode()));
+            visitedNodeCodeList.add(startNode.getCode());
         }
 
         resultList.add(startNode);
@@ -167,17 +166,19 @@ public class DagHelper {
     /**
      * find all nodes that start nodes depend on.
      *
-     * @param startNode startNode
+     * @param startNode            startNode
      * @param recoveryNodeCodeList recoveryNodeCodeList
-     * @param taskNodeList taskNodeList
+     * @param taskNodeList         taskNodeList
      * @return task node list
      */
-    private static List<TaskNode> getFlowNodeListPre(TaskNode startNode, List<String> recoveryNodeCodeList,
-                                                     List<TaskNode> taskNodeList, List<String> visitedNodeCodeList) {
+    private static List<TaskNode> getFlowNodeListPre(TaskNode startNode,
+                                                     List<Long> recoveryNodeCodeList,
+                                                     List<TaskNode> taskNodeList,
+                                                     List<Long> visitedNodeCodeList) {
 
         List<TaskNode> resultList = new ArrayList<>();
 
-        List<String> depList = new ArrayList<>();
+        List<Long> depList = new ArrayList<>();
         if (null != startNode) {
             depList = startNode.getDepList();
             resultList.add(startNode);
@@ -185,7 +186,7 @@ public class DagHelper {
         if (CollectionUtils.isEmpty(depList)) {
             return resultList;
         }
-        for (String depNodeCode : depList) {
+        for (Long depNodeCode : depList) {
             TaskNode start = findNodeByCode(taskNodeList, depNodeCode);
             if (recoveryNodeCodeList.contains(depNodeCode)) {
                 resultList.add(start);
@@ -195,7 +196,7 @@ public class DagHelper {
         }
         // why add (startNode != null) condition? for SonarCloud Quality Gate passed
         if (null != startNode) {
-            visitedNodeCodeList.add(Long.toString(startNode.getCode()));
+            visitedNodeCodeList.add(startNode.getCode());
         }
         return resultList;
     }
@@ -203,16 +204,16 @@ public class DagHelper {
     /**
      * generate dag by start nodes and recovery nodes
      *
-     * @param totalTaskNodeList totalTaskNodeList
-     * @param startNodeNameList startNodeNameList
+     * @param totalTaskNodeList    totalTaskNodeList
+     * @param startNodeNameList    startNodeNameList
      * @param recoveryNodeCodeList recoveryNodeCodeList
-     * @param depNodeType depNodeType
+     * @param depNodeType          depNodeType
      * @return process dag
      * @throws Exception if error throws Exception
      */
     public static ProcessDag generateFlowDag(List<TaskNode> totalTaskNodeList,
-                                             List<String> startNodeNameList,
-                                             List<String> recoveryNodeCodeList,
+                                             List<Long> startNodeNameList,
+                                             List<Long> recoveryNodeCodeList,
                                              TaskDependType depNodeType) throws Exception {
 
         List<TaskNode> destTaskNodeList = generateFlowNodeListByStartNode(totalTaskNodeList, startNodeNameList,
@@ -231,7 +232,7 @@ public class DagHelper {
      * find node by node name
      *
      * @param nodeDetails nodeDetails
-     * @param nodeName nodeName
+     * @param nodeName    nodeName
      * @return task node
      */
     public static TaskNode findNodeByName(List<TaskNode> nodeDetails, String nodeName) {
@@ -247,12 +248,12 @@ public class DagHelper {
      * find node by node code
      *
      * @param nodeDetails nodeDetails
-     * @param nodeCode nodeCode
+     * @param nodeCode    nodeCode
      * @return task node
      */
-    public static TaskNode findNodeByCode(List<TaskNode> nodeDetails, String nodeCode) {
+    public static TaskNode findNodeByCode(List<TaskNode> nodeDetails, Long nodeCode) {
         for (TaskNode taskNode : nodeDetails) {
-            if (Long.toString(taskNode.getCode()).equals(nodeCode)) {
+            if (taskNode.getCode() == nodeCode) {
                 return taskNode;
             }
         }
@@ -262,20 +263,20 @@ public class DagHelper {
     /**
      * the task can be submit when  all the depends nodes are forbidden or complete
      *
-     * @param taskNode taskNode
-     * @param dag dag
+     * @param taskNode         taskNode
+     * @param dag              dag
      * @param completeTaskList completeTaskList
      * @return can submit
      */
     public static boolean allDependsForbiddenOrEnd(TaskNode taskNode,
-                                                   DAG<String, TaskNode, TaskNodeRelation> dag,
-                                                   Map<String, TaskNode> skipTaskNodeList,
-                                                   Map<String, TaskInstance> completeTaskList) {
-        List<String> dependList = taskNode.getDepList();
+                                                   DAG<Long, TaskNode, TaskNodeRelation> dag,
+                                                   Map<Long, TaskNode> skipTaskNodeList,
+                                                   Map<Long, TaskInstance> completeTaskList) {
+        List<Long> dependList = taskNode.getDepList();
         if (dependList == null) {
             return true;
         }
-        for (String dependNodeCode : dependList) {
+        for (Long dependNodeCode : dependList) {
             TaskNode dependNode = dag.getNode(dependNodeCode);
             if (dependNode == null || completeTaskList.containsKey(dependNodeCode)
                     || dependNode.isForbidden()
@@ -295,28 +296,28 @@ public class DagHelper {
      *
      * @return successor nodes
      */
-    public static Set<String> parsePostNodes(String preNodeCode,
-                                             Map<String, TaskNode> skipTaskNodeList,
-                                             DAG<String, TaskNode, TaskNodeRelation> dag,
-                                             Map<String, TaskInstance> completeTaskList) {
-        Set<String> postNodeList = new HashSet<>();
-        Collection<String> startVertexes = new ArrayList<>();
+    public static Set<Long> parsePostNodes(Long preNodeCode,
+                                           Map<Long, TaskNode> skipTaskNodeList,
+                                           DAG<Long, TaskNode, TaskNodeRelation> dag,
+                                           Map<Long, TaskInstance> completeTaskList) {
+        Set<Long> postNodeList = new HashSet<>();
+        Collection<Long> startVertexes = new ArrayList<>();
 
         if (preNodeCode == null) {
             startVertexes = dag.getBeginNode();
         } else if (dag.getNode(preNodeCode).isConditionsTask()) {
-            List<String> conditionTaskList = parseConditionTask(preNodeCode, skipTaskNodeList, dag, completeTaskList);
+            List<Long> conditionTaskList = parseConditionTask(preNodeCode, skipTaskNodeList, dag, completeTaskList);
             startVertexes.addAll(conditionTaskList);
         } else if (dag.getNode(preNodeCode).isSwitchTask()) {
-            List<String> conditionTaskList = parseSwitchTask(preNodeCode, skipTaskNodeList, dag, completeTaskList);
+            List<Long> conditionTaskList = parseSwitchTask(preNodeCode, skipTaskNodeList, dag, completeTaskList);
             startVertexes.addAll(conditionTaskList);
         } else {
             startVertexes = dag.getSubsequentNodes(preNodeCode);
         }
-        for (String subsequent : startVertexes) {
+        for (Long subsequent : startVertexes) {
             TaskNode taskNode = dag.getNode(subsequent);
             if (taskNode == null) {
-                logger.error("taskNode {} is null, please check dag", subsequent);
+                log.error("taskNode {} is null, please check dag", subsequent);
                 continue;
             }
             if (isTaskNodeNeedSkip(taskNode, skipTaskNodeList)) {
@@ -339,11 +340,11 @@ public class DagHelper {
      * if all of the task dependence are skipped, skip it too.
      */
     private static boolean isTaskNodeNeedSkip(TaskNode taskNode,
-                                              Map<String, TaskNode> skipTaskNodeList) {
+                                              Map<Long, TaskNode> skipTaskNodeList) {
         if (CollectionUtils.isEmpty(taskNode.getDepList())) {
             return false;
         }
-        for (String depNode : taskNode.getDepList()) {
+        for (Long depNode : taskNode.getDepList()) {
             if (!skipTaskNodeList.containsKey(depNode)) {
                 return false;
             }
@@ -355,11 +356,11 @@ public class DagHelper {
      * parse condition task find the branch process
      * set skip flag for another one.
      */
-    public static List<String> parseConditionTask(String nodeCode,
-                                                  Map<String, TaskNode> skipTaskNodeList,
-                                                  DAG<String, TaskNode, TaskNodeRelation> dag,
-                                                  Map<String, TaskInstance> completeTaskList) {
-        List<String> conditionTaskList = new ArrayList<>();
+    public static List<Long> parseConditionTask(Long nodeCode,
+                                                Map<Long, TaskNode> skipTaskNodeList,
+                                                DAG<Long, TaskNode, TaskNodeRelation> dag,
+                                                Map<Long, TaskInstance> completeTaskList) {
+        List<Long> conditionTaskList = new ArrayList<>();
         TaskNode taskNode = dag.getNode(nodeCode);
         if (!taskNode.isConditionsTask()) {
             return conditionTaskList;
@@ -368,22 +369,20 @@ public class DagHelper {
             return conditionTaskList;
         }
         TaskInstance taskInstance = completeTaskList.get(nodeCode);
-        ConditionsParameters conditionsParameters =
-                JSONUtils.parseObject(taskNode.getConditionResult(), ConditionsParameters.class);
-        List<String> skipNodeList = new ArrayList<>();
-        if (taskInstance.getState().isSuccess()) {
-            conditionTaskList = conditionsParameters.getSuccessNode();
-            skipNodeList = conditionsParameters.getFailedNode();
-        } else if (taskInstance.getState().isFailure()) {
-            conditionTaskList = conditionsParameters.getFailedNode();
-            skipNodeList = conditionsParameters.getSuccessNode();
+        ConditionsParameters conditionsParameters = taskInstance.getConditionsParameters();
+        ConditionsParameters.ConditionResult conditionResult = taskInstance.getConditionResult();
+
+        List<Long> skipNodeList = new ArrayList<>();
+        if (conditionsParameters.isConditionSuccess()) {
+            conditionTaskList = conditionResult.getSuccessNode();
+            skipNodeList = conditionResult.getFailedNode();
         } else {
-            conditionTaskList.add(nodeCode);
+            conditionTaskList = conditionResult.getFailedNode();
+            skipNodeList = conditionResult.getSuccessNode();
         }
-        // the skipNodeList maybe null if no next task
-        skipNodeList = Optional.ofNullable(skipNodeList).orElse(new ArrayList<>());
-        for (String failedNode : skipNodeList) {
-            setTaskNodeSkip(failedNode, dag, completeTaskList, skipTaskNodeList);
+
+        if (CollectionUtils.isNotEmpty(skipNodeList)) {
+            skipNodeList.forEach(skipNode -> setTaskNodeSkip(skipNode, dag, completeTaskList, skipTaskNodeList));
         }
         // the conditionTaskList maybe null if no next task
         conditionTaskList = Optional.ofNullable(conditionTaskList).orElse(new ArrayList<>());
@@ -397,11 +396,11 @@ public class DagHelper {
      * @param nodeCode
      * @return
      */
-    public static List<String> parseSwitchTask(String nodeCode,
-                                               Map<String, TaskNode> skipTaskNodeList,
-                                               DAG<String, TaskNode, TaskNodeRelation> dag,
-                                               Map<String, TaskInstance> completeTaskList) {
-        List<String> conditionTaskList = new ArrayList<>();
+    public static List<Long> parseSwitchTask(Long nodeCode,
+                                             Map<Long, TaskNode> skipTaskNodeList,
+                                             DAG<Long, TaskNode, TaskNodeRelation> dag,
+                                             Map<Long, TaskInstance> completeTaskList) {
+        List<Long> conditionTaskList = new ArrayList<>();
         TaskNode taskNode = dag.getNode(nodeCode);
         if (!taskNode.isSwitchTask()) {
             return conditionTaskList;
@@ -413,32 +412,30 @@ public class DagHelper {
         return conditionTaskList;
     }
 
-
-    public static List<String> skipTaskNode4Switch(TaskNode taskNode,
-                                                 Map<String, TaskNode> skipTaskNodeList,
-                                                 Map<String, TaskInstance> completeTaskList,
-                                                 DAG<String, TaskNode, TaskNodeRelation> dag) {
+    public static List<Long> skipTaskNode4Switch(TaskNode taskNode,
+                                                 Map<Long, TaskNode> skipTaskNodeList,
+                                                 Map<Long, TaskInstance> completeTaskList,
+                                                 DAG<Long, TaskNode, TaskNodeRelation> dag) {
 
         SwitchParameters switchParameters =
-                completeTaskList.get(Long.toString(taskNode.getCode())).getSwitchDependency();
+                completeTaskList.get(taskNode.getCode()).getSwitchDependency();
         int resultConditionLocation = switchParameters.getResultConditionLocation();
         List<SwitchResultVo> conditionResultVoList = switchParameters.getDependTaskList();
-
-        List<String> switchTaskList = conditionResultVoList.get(resultConditionLocation).getNextNode();
-        Set<String> switchNeedWorkCodes = new HashSet<>();
+        List<Long> switchTaskList = conditionResultVoList.get(resultConditionLocation).getNextNode();
+        Set<Long> switchNeedWorkCodes = new HashSet<>();
         if (CollectionUtils.isEmpty(switchTaskList)) {
             return new ArrayList<>();
         }
         // get all downstream nodes of the branch that the switch node needs to execute
-        for (String switchTaskCode : switchTaskList) {
+        for (Long switchTaskCode : switchTaskList) {
             getSwitchNeedWorkCodes(switchTaskCode, dag, switchNeedWorkCodes);
         }
-        conditionResultVoList.remove(resultConditionLocation);
+        // conditionResultVoList.remove(resultConditionLocation);
         for (SwitchResultVo info : conditionResultVoList) {
             if (CollectionUtils.isEmpty(info.getNextNode())) {
                 continue;
             }
-            for (String nextNode : info.getNextNode()) {
+            for (Long nextNode : info.getNextNode()) {
                 setSwitchTaskNodeSkip(nextNode, dag, completeTaskList, skipTaskNodeList,
                         switchNeedWorkCodes);
             }
@@ -448,52 +445,54 @@ public class DagHelper {
 
     /**
      * get all downstream nodes of the branch that the switch node needs to execute
+     *
      * @param taskCode
      * @param dag
      * @param switchNeedWorkCodes
      */
-    public static void getSwitchNeedWorkCodes(String taskCode, DAG<String, TaskNode, TaskNodeRelation> dag,
-                                              Set<String> switchNeedWorkCodes) {
+    public static void getSwitchNeedWorkCodes(Long taskCode, DAG<Long, TaskNode, TaskNodeRelation> dag,
+                                              Set<Long> switchNeedWorkCodes) {
         switchNeedWorkCodes.add(taskCode);
-        Set<String> subsequentNodes = dag.getSubsequentNodes(taskCode);
+        Set<Long> subsequentNodes = dag.getSubsequentNodes(taskCode);
         if (org.apache.commons.collections.CollectionUtils.isNotEmpty(subsequentNodes)) {
-            for (String subCode : subsequentNodes) {
+            for (Long subCode : subsequentNodes) {
                 getSwitchNeedWorkCodes(subCode, dag, switchNeedWorkCodes);
             }
         }
     }
 
-    private static void setSwitchTaskNodeSkip(String skipNodeCode,
-                                              DAG<String, TaskNode, TaskNodeRelation> dag,
-                                              Map<String, TaskInstance> completeTaskList,
-                                              Map<String, TaskNode> skipTaskNodeList,
-                                              Set<String> switchNeedWorkCodes) {
+    private static void setSwitchTaskNodeSkip(Long skipNodeCode,
+                                              DAG<Long, TaskNode, TaskNodeRelation> dag,
+                                              Map<Long, TaskInstance> completeTaskList,
+                                              Map<Long, TaskNode> skipTaskNodeList,
+                                              Set<Long> switchNeedWorkCodes) {
         // ignore when the node that needs to be skipped exists on the branch that the switch type node needs to execute
         if (!dag.containsNode(skipNodeCode) || switchNeedWorkCodes.contains(skipNodeCode)) {
             return;
         }
         skipTaskNodeList.putIfAbsent(skipNodeCode, dag.getNode(skipNodeCode));
-        Collection<String> postNodeList = dag.getSubsequentNodes(skipNodeCode);
-        for (String post : postNodeList) {
+        Collection<Long> postNodeList = dag.getSubsequentNodes(skipNodeCode);
+        for (Long post : postNodeList) {
             TaskNode postNode = dag.getNode(post);
             if (isTaskNodeNeedSkip(postNode, skipTaskNodeList)) {
                 setTaskNodeSkip(post, dag, completeTaskList, skipTaskNodeList);
             }
         }
     }
+
     /**
      * set task node and the post nodes skip flag
      */
-    private static void setTaskNodeSkip(String skipNodeCode,
-                                        DAG<String, TaskNode, TaskNodeRelation> dag,
-                                        Map<String, TaskInstance> completeTaskList,
-                                        Map<String, TaskNode> skipTaskNodeList) {
+    private static void setTaskNodeSkip(Long skipNodeCode,
+                                        DAG<Long, TaskNode, TaskNodeRelation> dag,
+                                        Map<Long, TaskInstance> completeTaskList,
+                                        Map<Long, TaskNode> skipTaskNodeList) {
         if (!dag.containsNode(skipNodeCode)) {
             return;
         }
         skipTaskNodeList.putIfAbsent(skipNodeCode, dag.getNode(skipNodeCode));
-        Collection<String> postNodeList = dag.getSubsequentNodes(skipNodeCode);
-        for (String post : postNodeList) {
+        Collection<Long> postNodeList = dag.getSubsequentNodes(skipNodeCode);
+        for (Long post : postNodeList) {
             TaskNode postNode = dag.getNode(post);
             if (isTaskNodeNeedSkip(postNode, skipTaskNodeList)) {
                 setTaskNodeSkip(post, dag, completeTaskList, skipTaskNodeList);
@@ -506,14 +505,14 @@ public class DagHelper {
      * @param processDag processDag
      * @return dag
      */
-    public static DAG<String, TaskNode, TaskNodeRelation> buildDagGraph(ProcessDag processDag) {
+    public static DAG<Long, TaskNode, TaskNodeRelation> buildDagGraph(ProcessDag processDag) {
 
-        DAG<String, TaskNode, TaskNodeRelation> dag = new DAG<>();
+        DAG<Long, TaskNode, TaskNodeRelation> dag = new DAG<>();
 
         // add vertex
         if (CollectionUtils.isNotEmpty(processDag.getNodes())) {
             for (TaskNode node : processDag.getNodes()) {
-                dag.addNode(Long.toString(node.getCode()), node);
+                dag.addNode(node.getCode(), node);
             }
         }
 
@@ -538,12 +537,12 @@ public class DagHelper {
         // Traverse node information and build relationships
         for (TaskNode taskNode : taskNodeList) {
             String preTasks = taskNode.getPreTasks();
-            List<String> preTasksList = JSONUtils.toList(preTasks, String.class);
+            List<Long> preTasksList = JSONUtils.toList(preTasks, Long.class);
 
             // If the dependency is not empty
             if (preTasksList != null) {
-                for (String depNode : preTasksList) {
-                    taskNodeRelations.add(new TaskNodeRelation(depNode, Long.toString(taskNode.getCode())));
+                for (Long depNode : preTasksList) {
+                    taskNodeRelations.add(new TaskNodeRelation(depNode, taskNode.getCode()));
                 }
             }
         }
@@ -578,7 +577,7 @@ public class DagHelper {
                 TaskNode preNode = taskNodeMap.get(preTaskCode);
                 TaskNode postNode = taskNodeMap.get(postTaskCode);
                 taskNodeRelations
-                        .add(new TaskNodeRelation(Long.toString(preNode.getCode()), Long.toString(postNode.getCode())));
+                        .add(new TaskNodeRelation(preNode.getCode(), postNode.getCode()));
             }
         }
         ProcessDag processDag = new ProcessDag();
@@ -590,20 +589,20 @@ public class DagHelper {
     /**
      * is there have conditions after the parent node
      */
-    public static boolean haveConditionsAfterNode(String parentNodeCode,
-                                                  DAG<String, TaskNode, TaskNodeRelation> dag) {
+    public static boolean haveConditionsAfterNode(Long parentNodeCode,
+                                                  DAG<Long, TaskNode, TaskNodeRelation> dag) {
         return haveSubAfterNode(parentNodeCode, dag, TaskConstants.TASK_TYPE_CONDITIONS);
     }
 
     /**
      * is there have conditions after the parent node
      */
-    public static boolean haveConditionsAfterNode(String parentNodeCode, List<TaskNode> taskNodes) {
+    public static boolean haveConditionsAfterNode(Long parentNodeCode, List<TaskNode> taskNodes) {
         if (CollectionUtils.isEmpty(taskNodes)) {
             return false;
         }
         for (TaskNode taskNode : taskNodes) {
-            List<String> preTasksList = JSONUtils.toList(taskNode.getPreTasks(), String.class);
+            List<Long> preTasksList = JSONUtils.toList(taskNode.getPreTasks(), Long.class);
             if (preTasksList.contains(parentNodeCode) && taskNode.isConditionsTask()) {
                 return true;
             }
@@ -614,32 +613,32 @@ public class DagHelper {
     /**
      * is there have blocking node after the parent node
      */
-    public static boolean haveBlockingAfterNode(String parentNodeCode,
-                                                DAG<String, TaskNode, TaskNodeRelation> dag) {
+    public static boolean haveBlockingAfterNode(Long parentNodeCode,
+                                                DAG<Long, TaskNode, TaskNodeRelation> dag) {
         return haveSubAfterNode(parentNodeCode, dag, TaskConstants.TASK_TYPE_BLOCKING);
     }
 
     /**
      * is there have all node after the parent node
      */
-    public static boolean haveAllNodeAfterNode(String parentNodeCode,
-                                               DAG<String, TaskNode, TaskNodeRelation> dag) {
+    public static boolean haveAllNodeAfterNode(Long parentNodeCode,
+                                               DAG<Long, TaskNode, TaskNodeRelation> dag) {
         return haveSubAfterNode(parentNodeCode, dag, null);
     }
 
     /**
      * Whether there is a specified type of child node after the parent node
      */
-    public static boolean haveSubAfterNode(String parentNodeCode,
-                                           DAG<String, TaskNode, TaskNodeRelation> dag, String filterNodeType) {
-        Set<String> subsequentNodes = dag.getSubsequentNodes(parentNodeCode);
+    public static boolean haveSubAfterNode(Long parentNodeCode,
+                                           DAG<Long, TaskNode, TaskNodeRelation> dag, String filterNodeType) {
+        Set<Long> subsequentNodes = dag.getSubsequentNodes(parentNodeCode);
         if (CollectionUtils.isEmpty(subsequentNodes)) {
             return false;
         }
         if (StringUtils.isBlank(filterNodeType)) {
             return true;
         }
-        for (String nodeName : subsequentNodes) {
+        for (Long nodeName : subsequentNodes) {
             TaskNode taskNode = dag.getNode(nodeName);
             if (taskNode.getType().equalsIgnoreCase(filterNodeType)) {
                 return true;
