@@ -22,7 +22,19 @@ DOLPHINSCHEDULER_HOME=${DOLPHINSCHEDULER_HOME:-$(cd $BIN_DIR/..; pwd)}
 export DATABASE=${DATABASE:-h2}
 source "$DOLPHINSCHEDULER_HOME/conf/dolphinscheduler_env.sh"
 
-JAVA_OPTS=${JAVA_OPTS:-"-server -Duser.timezone=${SPRING_JACKSON_TIME_ZONE} -Xms1g -Xmx1g -Xmn512m -XX:+PrintGCDetails -Xloggc:gc.log -XX:+HeapDumpOnOutOfMemoryError -XX:HeapDumpPath=dump.hprof"}
+JVM_ARGS_ENV_FILE=${BIN_DIR}/jvm_args_env.sh
+JVM_ARGS="-server"
+
+if [ -f $JVM_ARGS_ENV_FILE ]; then
+  while read line
+  do
+      if [[ "$line" == -* ]]; then
+            JVM_ARGS="${JVM_ARGS} $line"
+      fi
+  done < $JVM_ARGS_ENV_FILE
+fi
+
+JAVA_OPTS=${JAVA_OPTS:-"${JVM_ARGS}"}
 
 if [[ "$DOCKER" == "true" ]]; then
   JAVA_OPTS="${JAVA_OPTS} -XX:-UseContainerSupport"
@@ -30,11 +42,9 @@ fi
 
 CP=""
 for d in $DOLPHINSCHEDULER_HOME/libs/*; do
-  for f in $d/*.jar; do
-    CP=$CP:$f
-  done
+  CP=$CP:"$d/*"
 done
 
 $JAVA_HOME/bin/java $JAVA_OPTS \
-  -cp "$DOLPHINSCHEDULER_HOME/conf":"$CP" \
+  -cp "$DOLPHINSCHEDULER_HOME/conf""$CP" \
   org.apache.dolphinscheduler.StandaloneServer
