@@ -25,6 +25,7 @@ import static org.apache.dolphinscheduler.common.constants.Constants.RESOURCE_TY
 
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.ResUploadType;
+import org.apache.dolphinscheduler.common.utils.FileUtils;
 import org.apache.dolphinscheduler.common.utils.PropertyUtils;
 import org.apache.dolphinscheduler.plugin.storage.api.StorageEntity;
 import org.apache.dolphinscheduler.plugin.storage.api.StorageOperate;
@@ -148,12 +149,6 @@ public class AbsStorageOperator implements Closeable, StorageOperate {
         return getAbsUdfDir(tenantCode) + FOLDER_SEPARATOR;
     }
 
-    @Override
-    public String getResourceFileName(String tenantCode, String fullName) {
-        String resDir = getResDir(tenantCode);
-        return fullName.replaceFirst(resDir, "");
-    }
-
     @Override
     public String getResourceFullName(String tenantCode, String fileName) {
         if (fileName.startsWith(FOLDER_SEPARATOR)) {
@@ -171,13 +166,12 @@ public class AbsStorageOperator implements Closeable, StorageOperate {
     }
 
     @Override
-    public void download(String tenantCode, String srcFilePath, String dstFilePath,
-                         boolean overwrite) throws IOException {
+    public void download(String srcFilePath, String dstFilePath, boolean overwrite) throws IOException {
         File dstFile = new File(dstFilePath);
         if (dstFile.isDirectory()) {
             Files.delete(dstFile.toPath());
         } else {
-            Files.createDirectories(dstFile.getParentFile().toPath());
+            FileUtils.createDirectoryWith755(dstFile.getParentFile().toPath());
         }
 
         BlobClient blobClient = blobContainerClient.getBlobClient(srcFilePath);
