@@ -71,7 +71,7 @@ import com.fasterxml.jackson.databind.node.ObjectNode;
 @Slf4j
 public class HdfsStorageOperator implements Closeable, StorageOperate {
 
-    private static HdfsStorageProperties hdfsProperties = new HdfsStorageProperties();
+    protected static HdfsStorageProperties hdfsProperties = new HdfsStorageProperties();
     private static final String HADOOP_UTILS_KEY = "HADOOP_UTILS_KEY";
 
     private volatile boolean yarnEnabled = false;
@@ -281,20 +281,13 @@ public class HdfsStorageOperator implements Closeable, StorageOperate {
         return getHdfsResourceFileName(tenantCode, fullName);
     }
 
-    @Override
-    public String getResourceFileName(String tenantCode, String fullName) {
-        String resDir = getResDir(tenantCode);
-        return fullName.replaceFirst(resDir, "");
-    }
-
     @Override
     public String getFileName(ResourceType resourceType, String tenantCode, String fileName) {
         return getHdfsFileName(resourceType, tenantCode, fileName);
     }
 
     @Override
-    public void download(String tenantCode, String srcHdfsFilePath, String dstFile,
-                         boolean overwrite) throws IOException {
+    public void download(String srcHdfsFilePath, String dstFile, boolean overwrite) throws IOException {
         copyHdfsToLocal(srcHdfsFilePath, dstFile, false, overwrite);
     }
 
