@@ -17,30 +17,35 @@
 
 package org.apache.dolphinscheduler.plugin.task.api.k8s;
 
+import org.apache.dolphinscheduler.common.utils.ClassFilterConstructor;
 import org.apache.dolphinscheduler.plugin.task.api.TaskException;
 import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
 import org.apache.dolphinscheduler.plugin.task.api.model.TaskResponse;
 import org.apache.dolphinscheduler.plugin.task.api.utils.K8sUtils;
 
-import org.slf4j.Logger;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+
 import org.yaml.snakeyaml.Yaml;
 
 public abstract class AbstractK8sTaskExecutor {
 
-    protected Logger log;
     protected TaskExecutionContext taskRequest;
     protected K8sUtils k8sUtils;
     protected Yaml yaml;
-    protected StringBuilder varPool;
-    protected AbstractK8sTaskExecutor(Logger log, TaskExecutionContext taskRequest) {
-        this.log = log;
+    protected volatile Map<String, String> taskOutputParams;
+    protected AbstractK8sTaskExecutor(TaskExecutionContext taskRequest) {
         this.taskRequest = taskRequest;
         this.k8sUtils = new K8sUtils();
-        this.yaml = new Yaml();
-        this.varPool = new StringBuilder();
+        this.yaml = new Yaml(new ClassFilterConstructor(new Class[]{
+                List.class,
+                String.class
+        }));
+        this.taskOutputParams = new HashMap<>();
     }
-    public String getVarPool() {
-        return varPool.toString();
+    public Map<String, String> getTaskOutputParams() {
+        return taskOutputParams;
     }
 
     public abstract TaskResponse run(String k8sParameterStr) throws Exception;
