@@ -17,6 +17,7 @@
 
 package org.apache.dolphinscheduler.plugin.task.api.loop.template.http.parser;
 
+import org.apache.dolphinscheduler.common.utils.ClassFilterConstructor;
 import org.apache.dolphinscheduler.plugin.task.api.loop.template.LoopTaskYamlDefinition;
 import org.apache.dolphinscheduler.plugin.task.api.loop.template.TaskDefinitionParser;
 import org.apache.dolphinscheduler.plugin.task.api.loop.template.http.HttpLoopTaskDefinition;
@@ -28,11 +29,11 @@ import org.apache.commons.lang3.StringUtils;
 
 import java.io.FileReader;
 import java.io.IOException;
+import java.util.Map;
 
 import lombok.NonNull;
 
 import org.yaml.snakeyaml.Yaml;
-import org.yaml.snakeyaml.constructor.Constructor;
 
 import com.google.common.base.Preconditions;
 
@@ -60,9 +61,20 @@ public class HttpTaskDefinitionParser implements TaskDefinitionParser<HttpLoopTa
     }
 
     protected @NonNull LoopTaskYamlDefinition parseYamlConfigFile(@NonNull String yamlConfigFile) throws IOException {
-        Yaml yaml = new Yaml(new Constructor(LoopTaskYamlDefinition.class));
         try (FileReader fileReader = new FileReader(yamlConfigFile)) {
-            return yaml.load(fileReader);
+            return new Yaml(new ClassFilterConstructor(new Class[]{
+                    LoopTaskYamlDefinition.class,
+                    LoopTaskYamlDefinition.LoopTaskServiceYamlDefinition.class,
+                    LoopTaskYamlDefinition.LoopTaskAPIYamlDefinition.class,
+                    LoopTaskYamlDefinition.LoopTaskSubmitMethodYamlDefinition.class,
+                    LoopTaskYamlDefinition.LoopTaskQueryStateYamlDefinition.class,
+                    LoopTaskYamlDefinition.LoopTaskCancelYamlDefinition.class,
+                    LoopTaskYamlDefinition.LoopTaskMethodYamlDefinition.class,
+                    LoopTaskYamlDefinition.LoopTaskQueryStateYamlDefinition.class,
+                    Map.class,
+                    String.class
+            }))
+                    .loadAs(fileReader, LoopTaskYamlDefinition.class);
         }
     }
 
