@@ -22,25 +22,36 @@ import org.apache.dolphinscheduler.plugin.task.api.enums.Direct;
 import org.apache.dolphinscheduler.plugin.task.api.model.Property;
 import org.apache.dolphinscheduler.plugin.task.api.model.ResourceInfo;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.resource.ResourceParametersHelper;
+import org.apache.dolphinscheduler.plugin.task.api.utils.VarPoolUtils;
 
 import org.apache.commons.collections4.CollectionUtils;
+import org.apache.commons.collections4.MapUtils;
 import org.apache.commons.lang3.StringUtils;
 
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
+import java.util.stream.Collectors;
+
+import lombok.Getter;
+import lombok.Setter;
+import lombok.extern.slf4j.Slf4j;
 
 import com.fasterxml.jackson.databind.JsonNode;
 import com.fasterxml.jackson.databind.node.ArrayNode;
+import com.google.common.collect.Lists;
 
-/**
- * job params related class
- */
+@Getter
+@Slf4j
 public abstract class AbstractParameters implements IParameters {
 
+    @Setter
+    public List<Property> localParams;
+
+    public List<Property> varPool = new ArrayList<>();
+
     @Override
     public abstract boolean checkParameters();
 
@@ -49,33 +60,6 @@ public abstract class AbstractParameters implements IParameters {
         return new ArrayList<>();
     }
 
-    /**
-     * local parameters
-     */
-    public List<Property> localParams;
-
-    /**
-     * var pool
-     */
-    public List<Property> varPool;
-
-    /**
-     * get local parameters list
-     *
-     * @return Property list
-     */
-    public List<Property> getLocalParams() {
-        return localParams;
-    }
-
-    public void setLocalParams(List<Property> localParams) {
-        this.localParams = localParams;
-    }
-
-    /**
-     * get local parameters map
-     * @return parameters map
-     */
     public Map<String, Property> getLocalParametersMap() {
         Map<String, Property> localParametersMaps = new LinkedHashMap<>();
         if (localParams != null) {
@@ -88,6 +72,7 @@ public abstract class AbstractParameters implements IParameters {
 
     /**
      * get input local parameters map if the param direct is IN
+     *
      * @return parameters map
      */
     public Map<String, Property> getInputLocalParametersMap() {
@@ -118,10 +103,6 @@ public abstract class AbstractParameters implements IParameters {
         return varPoolMap;
     }
 
-    public List<Property> getVarPool() {
-        return varPool;
-    }
-
     public void setVarPool(String varPool) {
         if (StringUtils.isEmpty(varPool)) {
             this.varPool = new ArrayList<>();
@@ -130,42 +111,31 @@ public abstract class AbstractParameters implements IParameters {
         }
     }
 
-    public void dealOutParam(String result) {
-        if (CollectionUtils.isEmpty(localParams)) {
-            return;
-        }
+    public void dealOutParam(Map<String, String> taskOutputParams) {
         List<Property> outProperty = getOutProperty(localParams);
         if (CollectionUtils.isEmpty(outProperty)) {
             return;
         }
-        if (StringUtils.isEmpty(result)) {
-            outProperty.forEach(this::addPropertyToValPool);
-            return;
-        }
-        Map<String, String> taskResult = getMapByString(result);
-        if (taskResult.size() == 0) {
-            return;
-        }
-        for (Property info : outProperty) {
-            String propValue = taskResult.get(info.getProp());
-            if (StringUtils.isNotEmpty(propValue)) {
-                info.setValue(propValue);
-                addPropertyToValPool(info);
+        if (CollectionUtils.isNotEmpty(outProperty) && MapUtils.isNotEmpty(taskOutputParams)) {
+            // Inject the value
+            for (Property info : outProperty) {
+                String value = taskOutputParams.get(info.getProp());
+                if (value != null) {
+                    info.setValue(value);
+                }
             }
         }
+
+        varPool = VarPoolUtils.mergeVarPool(Lists.newArrayList(varPool, outProperty));
     }
 
-    public List<Property> getOutProperty(List<Property> params) {
+    protected List<Property> getOutProperty(List<Property> params) {
         if (CollectionUtils.isEmpty(params)) {
             return new ArrayList<>();
         }
-        List<Property> result = new ArrayList<>();
-        for (Property info : params) {
-            if (info.getDirect() == Direct.OUT) {
-                result.add(info);
-            }
-        }
-        return result;
+        return params.stream()
+                .filter(info -> info.getDirect() == Direct.OUT)
+                .collect(Collectors.toList());
     }
 
     public List<Map<String, String>> getListMapByString(String json) {
@@ -178,23 +148,6 @@ public abstract class AbstractParameters implements IParameters {
         return allParams;
     }
 
-    /**
-     * shell's result format is key=value$VarPool$key=value$VarPool$
-     * @param result
-     * @return
-     */
-    public static Map<String, String> getMapByString(String result) {
-        String[] formatResult = result.split("\\$VarPool\\$");
-        Map<String, String> format = new HashMap<>();
-        for (String info : formatResult) {
-            if (StringUtils.isNotEmpty(info) && info.contains("=")) {
-                String[] keyValue = info.split("=");
-                format.put(keyValue[0], keyValue[1]);
-            }
-        }
-        return format;
-    }
-
     public ResourceParametersHelper getResources() {
         return new ResourceParametersHelper();
     }
