@@ -27,11 +27,15 @@ import java.util.ArrayList;
 import java.util.List;
 
 import lombok.Data;
+import lombok.EqualsAndHashCode;
+import lombok.extern.slf4j.Slf4j;
 
 /**
  * k8s task parameters
  */
+@EqualsAndHashCode(callSuper = true)
 @Data
+@Slf4j
 public class K8sTaskParameters extends AbstractParameters {
 
     private String image;
@@ -47,7 +51,7 @@ public class K8sTaskParameters extends AbstractParameters {
 
     @Override
     public boolean checkParameters() {
-        return StringUtils.isNotEmpty(image) && StringUtils.isNotEmpty(namespace);
+        return StringUtils.isNotEmpty(image);
     }
 
     @Override
