@@ -19,8 +19,8 @@ package org.apache.dolphinscheduler.plugin.task.flink;
 
 import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
 import org.apache.dolphinscheduler.plugin.task.api.model.ResourceInfo;
+import org.apache.dolphinscheduler.plugin.task.api.resource.ResourceContext;
 
-import java.util.HashMap;
 import java.util.List;
 
 import org.junit.jupiter.api.Assertions;
@@ -38,9 +38,7 @@ public class FlinkArgsUtilsTest {
         flinkParameters.setDeployMode(flinkDeployMode);
         flinkParameters.setParallelism(4);
         ResourceInfo resourceInfo = new ResourceInfo();
-        resourceInfo.setId(1);
         resourceInfo.setResourceName("/opt/job.jar");
-        resourceInfo.setRes("/opt/job.jar");
         flinkParameters.setMainJar(resourceInfo);
         flinkParameters.setMainClass("org.example.Main");
         flinkParameters.setSlot(4);
@@ -54,9 +52,14 @@ public class FlinkArgsUtilsTest {
         TaskExecutionContext taskExecutionContext = new TaskExecutionContext();
         taskExecutionContext.setTaskAppId("app-id");
         taskExecutionContext.setExecutePath("/tmp/execution");
-        HashMap<String, String> map = new HashMap<>();
-        map.put("/opt/job.jar", "/opt/job.jar");
-        taskExecutionContext.setResources(map);
+
+        ResourceContext.ResourceItem resourceItem = new ResourceContext.ResourceItem();
+        resourceItem.setResourceAbsolutePathInLocal("/opt/job.jar");
+        resourceItem.setResourceAbsolutePathInStorage("/opt/job.jar");
+
+        ResourceContext resourceContext = new ResourceContext();
+        resourceContext.addResourceItem(resourceItem);
+        taskExecutionContext.setResourceContext(resourceContext);
         return taskExecutionContext;
     }
 
@@ -71,7 +74,7 @@ public class FlinkArgsUtilsTest {
     }
 
     @Test
-    public void testRunJarInClusterMode() throws Exception {
+    public void testRunJarInClusterMode() {
         FlinkParameters flinkParameters = buildTestFlinkParametersWithDeployMode(FlinkDeployMode.CLUSTER);
         flinkParameters.setFlinkVersion("1.11");
         List<String> commandLine1 =
@@ -99,7 +102,7 @@ public class FlinkArgsUtilsTest {
     }
 
     @Test
-    public void testRunJarInLocalMode() throws Exception {
+    public void testRunJarInLocalMode() {
         FlinkParameters flinkParameters = buildTestFlinkParametersWithDeployMode(FlinkDeployMode.LOCAL);
         List<String> commandLine = FlinkArgsUtils.buildRunCommandLine(buildTestTaskExecutionContext(), flinkParameters);
 
@@ -109,7 +112,7 @@ public class FlinkArgsUtilsTest {
     }
 
     @Test
-    public void testRunSql() throws Exception {
+    public void testRunSql() {
         FlinkParameters flinkParameters = buildTestFlinkParametersWithDeployMode(FlinkDeployMode.CLUSTER);
         flinkParameters.setProgramType(ProgramType.SQL);
         List<String> commandLine = FlinkArgsUtils.buildRunCommandLine(buildTestTaskExecutionContext(), flinkParameters);
@@ -119,7 +122,7 @@ public class FlinkArgsUtilsTest {
     }
 
     @Test
-    public void testInitOptionsInLocalMode() throws Exception {
+    public void testInitOptionsInLocalMode() {
         List<String> initOptions =
                 FlinkArgsUtils.buildInitOptionsForSql(buildTestFlinkParametersWithDeployMode(FlinkDeployMode.LOCAL));
         Assertions.assertEquals(2, initOptions.size());
