@@ -42,31 +42,30 @@ import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
 
+import lombok.extern.slf4j.Slf4j;
 import io.fabric8.kubernetes.api.model.NodeSelectorRequirement;
 
+@Slf4j
 public class K8sTask extends AbstractK8sTask {
 
-    /**
-     * taskExecutionContext
-     */
     private final TaskExecutionContext taskExecutionContext;
 
-    /**
-     * task parameters
-     */
-    private final K8sTaskParameters k8sTaskParameters;
+    private K8sTaskParameters k8sTaskParameters;
 
-    /**
-     * @param taskRequest taskRequest
-     */
     public K8sTask(TaskExecutionContext taskRequest) {
         super(taskRequest);
         this.taskExecutionContext = taskRequest;
         this.k8sTaskParameters = JSONUtils.parseObject(taskExecutionContext.getTaskParams(), K8sTaskParameters.class);
         log.info("Initialize k8s task parameters {}", JSONUtils.toPrettyJsonString(k8sTaskParameters));
+    }
+
+    @Override
+    public void init() {
         if (k8sTaskParameters == null || !k8sTaskParameters.checkParameters()) {
             throw new TaskException("K8S task params is not valid");
         }
+
+        log.info("Initialize k8s task params:{}", JSONUtils.toPrettyJsonString(k8sTaskParameters));
     }
 
     @Override
@@ -103,8 +102,8 @@ public class K8sTask extends AbstractK8sTask {
     }
 
     @Override
-    protected void dealOutParam(String result) {
-        this.k8sTaskParameters.dealOutParam(result);
+    protected void dealOutParam(Map<String, String> taskOutputParams) {
+        this.k8sTaskParameters.dealOutParam(taskOutputParams);
     }
 
     public List<NodeSelectorRequirement> convertToNodeSelectorRequirements(List<NodeSelectorExpression> expressions) {
