@@ -17,8 +17,6 @@
 
 package org.apache.dolphinscheduler.plugin.task.k8s;
 
-import static org.apache.dolphinscheduler.plugin.task.api.utils.VarPoolUtils.VAR_DELIMITER;
-
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
 import org.apache.dolphinscheduler.plugin.task.api.enums.DataType;
@@ -38,6 +36,7 @@ import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
+import com.google.common.collect.ImmutableMap;
 import io.fabric8.kubernetes.api.model.NodeSelectorRequirement;
 
 public class K8sTaskTest {
@@ -50,7 +49,7 @@ public class K8sTaskTest {
 
     private final String pullSecret = "ds-secret";
 
-    private final String namespace = "{\"name\":\"default\",\"cluster\":\"lab\"}";
+    private final String namespace = "namespace";
 
     private final double minCpuCores = 2;
 
@@ -62,6 +61,7 @@ public class K8sTaskTest {
     private final String date = "20220507";
     private final String command = "[\"/bin/bash\", \"-c\"]";
     private final String args = "[\"echo hello world\"]";
+
     private final List<Label> labels = Arrays.asList(new Label("test", "1234"));
     private final List<NodeSelectorExpression> nodeSelectorExpressions =
             Arrays.asList(new NodeSelectorExpression("node-label", "In", "1234,12345"));
@@ -135,7 +135,7 @@ public class K8sTaskTest {
 
     @Test
     public void testDealOutParam() {
-        String result = "key=123" + VAR_DELIMITER;
+        Map<String, String> result = ImmutableMap.of("key", "123");
         k8sTask.getParameters().localParams.add(new Property("key", Direct.OUT, DataType.VARCHAR, "value"));
         k8sTask.dealOutParam(result);
         k8sTask.getParameters().getVarPool().forEach(property -> {
