@@ -40,7 +40,8 @@ export default {
     authorize_level: '权限等级',
     no_permission: '无权限',
     read_permission: '读权限',
-    all_permission: '所有权限'
+    all_permission: '所有权限',
+    assign_worker_group: '分配WorkerGroup'
   },
   workflow: {
     on_line: '线上',
@@ -82,6 +83,8 @@ export default {
     timezone: '时区',
     up_line: '上线',
     down_line: '下线',
+    time_up_line: '定时上线',
+    time_down_line: '定时下线',
     copy_workflow: '复制工作流',
     copy_workflow_name: '复制工作流名称',
     visit_workflow_instances: '查看工作流实例',
@@ -129,6 +132,7 @@ export default {
     success_send: '成功发',
     failure_send: '失败发',
     all_send: '成功或失败都发',
+    warning_group_tip: '请选择告警组',
     whether_complement_data: '是否是补数',
     schedule_date: '调度日期',
     select_date: '日期选择',
@@ -230,6 +234,20 @@ export default {
     want_to_set_timing: '现在想去配置该工作流定时?',
     confirm_to_online: '是否确定上线该工作流?',
     confirm_to_offline: '是否确定下线该工作流?',
+    time_to_online: '是否确定上线该定时?',
+    time_to_offline: '是否确定下线该定时?',
+    warning_dependent_tasks_title: '警告',
+    warning_dependent_tasks_desc:
+      '下游存在依赖, 下线操作可能会对下游任务产生影响. 你确定要下线该工作流嘛?',
+    warning_dependencies: '依赖如下:',
+    delete_validate_dependent_tasks_desc: '下游存在依赖，你不能删除该工作流',
+    warning_offline_scheduler_dependent_tasks_desc:
+      '下游存在依赖, 下线操作可能会对下游任务产生影响. 你确定要下线该定时嘛?',
+    delete_task_validate_dependent_tasks_desc:
+      '下游存在依赖，你不能删除该任务.',
+    warning_delete_scheduler_dependent_tasks_desc:
+      '下游存在依赖, 删除定时可能会对下游任务产生影响. 你确定要删除该定时嘛?',
+    warning_too_large_parallelism_number: '并行度设置太大了, 最好不要超过10.',
   },
   task: {
     on_line: '线上',
@@ -298,7 +316,8 @@ export default {
     startup_parameter: '启动参数',
     whether_dry_run: '是否空跑',
     please_choose: '请选择',
-    remove_task_cache: '清除缓存'
+    remove_task_cache: '清除缓存',
+    delete_validate_dependent_tasks_desc: '下游存在依赖，你不能删除该任务定义'
   },
   dag: {
     create: '创建工作流',
@@ -419,6 +438,8 @@ export default {
     timeout_period_tips: '超时时长必须为正整数',
     script: '脚本',
     script_tips: '请输入脚本（必填）',
+    master: 'Master',
+    master_tips: '请输入master url（必填）',
     init_script: '初始化脚本',
     init_script_tips: '请输入初始化脚本',
     resources: '资源',
@@ -483,6 +504,8 @@ export default {
     http_url_validator: '请求地址需包含http或者https',
     http_method: '请求类型',
     http_parameters: '请求参数',
+    http_body: '请求Body',
+    http_body_tips: '请填写http body,如若填写将忽略请求参数中的body类型参数',
     http_check_condition: '校验条件',
     http_condition: '校验内容',
     http_condition_tips: '请填写校验内容',
@@ -529,7 +552,7 @@ export default {
     model_type: '模式',
     form: '表单',
     table: '表名',
-    table_tips: '请输入Mysql表名(必填)',
+    table_tips: '请输入表名(必填)',
     column_type: '列类型',
     all_columns: '全表导入',
     some_columns: '选择列',
@@ -633,6 +656,7 @@ export default {
     hour: '时',
     add_dependency: '添加依赖',
     waiting_dependent_start: '等待依赖启动',
+    dependent_task_parameter_passing: '参数传递',
     check_interval: '检查间隔',
     check_interval_tips: '检查间隔必须为正整数',
     waiting_dependent_complete: '等待依赖完成',
@@ -805,8 +829,10 @@ export default {
     please_select_target_database: '请选择目标数据库',
     please_enter_target_table: '请选择目标数据表',
     please_enter_target_filter_expression: '请输入目标表过滤条件',
-    please_enter_comparison_name_the_alias_in_comparison_execute_sql: '请输入期望值名',
-    please_enter_statistics_name_the_alias_in_statistics_execute_sql: '请输入实际值名',
+    please_enter_comparison_name_the_alias_in_comparison_execute_sql:
+      '请输入期望值名',
+    please_enter_statistics_name_the_alias_in_statistics_execute_sql:
+      '请输入实际值名',
     please_enter_comparison_execute_sql: '请输入期望值计算SQL',
     please_enter_statistics_execute_sql: '请输入实际值计算SQL',
     custom_config: '自定义配置',
@@ -853,6 +879,9 @@ export default {
     child_node_instance: '子节点实例',
     yarn_queue: 'Yarn队列',
     yarn_queue_tips: '请输入Yarn队列(选填)',
+    dependent_type: '依赖类型',
+    dependent_on_workflow: '依赖于工作流',
+    dependent_on_task: '依赖于任务'
   },
   menu: {
     fav: '收藏组件',
@@ -871,6 +900,8 @@ export default {
     code: '参数编码',
     name: '参数名称',
     value: '参数值',
+    create_user: '创建用户',
+    modify_user: '修改用户',
     create_time: '创建时间',
     update_time: '更新时间',
     name_tips: '请输入参数名称',
@@ -879,15 +910,16 @@ export default {
     edit: '编辑',
     delete: '删除',
     delete_confirm: '确定删除吗?',
-    success: '成功',
+    success: '成功'
   },
   preference: {
     edit_preference: '修改项目偏好设置',
     preference_manage: '项目偏好管理',
-    instruction_tips: '下面这些项目偏好配置将影响这个项目下的所有工作流和任务。当创建工作流和任务时，这些配置将影响组件中的默认选项',
+    instruction_tips:
+      '下面这些项目偏好配置将影响这个项目下的所有工作流和任务。当创建工作流和任务时，这些配置将影响组件中的默认选项',
     success: '成功',
     submit: '提交',
     enabled: '启用',
     disabled: '未启用'
-  },
+  }
 }
