@@ -25,7 +25,9 @@ interface DatabaseRes {
   date: string
 }
 
-interface MasterNode {
+type ServerNodeType = 'MASTER' | 'WORKER' | 'ALERT_SERVER'
+
+interface ServerNode {
   id: number
   host: string
   port: number
@@ -35,14 +37,23 @@ interface MasterNode {
   lastHeartbeatTime: string
 }
 
-interface WorkerNode {
-  id: number
-  host: string
-  port: number
-  zkDirectories: Array<string>
-  resInfo: string
-  createTime: string
-  lastHeartbeatTime: string
+interface MasterNode extends ServerNode {
+  serverStatus?: 'NORMAL' | 'BUZY'
 }
 
-export { DatabaseRes, MasterNode, WorkerNode }
+interface WorkerNode extends ServerNode {
+  serverStatus?: 'NORMAL' | 'BUZY'
+  workerHostWeight?: number
+  threadPoolUsage?: number
+}
+
+interface AlertNode extends MasterNode {}
+
+export {
+  DatabaseRes,
+  MasterNode,
+  WorkerNode,
+  ServerNodeType,
+  ServerNode,
+  AlertNode
+}
