@@ -23,6 +23,7 @@ type TaskExecuteType = 'STREAM' | 'BATCH'
 type TaskType =
   | 'SHELL'
   | 'SUB_PROCESS'
+  | 'DYNAMIC'
   | 'PROCEDURE'
   | 'SQL'
   | 'SPARK'
@@ -56,6 +57,8 @@ type TaskType =
   | 'DATASYNC'
   | 'KUBEFLOW'
   | 'LINKIS'
+  | 'DATA_FACTORY'
+  | 'REMOTESHELL'
 
 type ProgramType = 'JAVA' | 'SCALA' | 'PYTHON'
 
@@ -86,6 +89,20 @@ interface TaskNodeState {
   name: string
   dependentResult: DependentResultType
 }
+
+interface ITaskType {
+  alias: string
+  helperLinkDisable?: boolean
+  taskDefinitionDisable?: boolean
+  taskExecuteType?: TaskExecuteType
+}
+interface ITaskTypeItem extends ITaskType {
+  type: TaskType
+}
+interface TaskTypeState {
+  types: ITaskTypeItem[]
+}
+
 export {
   TaskNodeState,
   EditWorkflowDefinition,
@@ -94,5 +111,10 @@ export {
   ProgramType,
   DependentResultType,
   BDependentResultType,
-  IMainJar
+  IMainJar,
+  TaskType,
+  ITaskType,
+  ITaskTypeItem,
+  TaskTypeState,
+  TaskExecuteType
 }
