@@ -154,6 +154,7 @@ const DetailModal = defineComponent({
       requiredDataBase,
       showHost,
       showPort,
+      showRestEndpoint,
       showAwsRegion,
       showCompatibleMode,
       showConnectType,
@@ -164,6 +165,7 @@ const DetailModal = defineComponent({
       showPublicKey,
       modeOptions,
       redShiftModeOptions,
+      sagemakerModeOption,
       loading,
       saving,
       testing,
@@ -251,6 +253,21 @@ const DetailModal = defineComponent({
                     placeholder={t('datasource.ip_tips')}
                   />
                 </NFormItem>
+                <NFormItem
+                  v-show={showRestEndpoint}
+                  label={t('datasource.zeppelin_rest_endpoint')}
+                  path='restEndPoint'
+                  show-require-mark
+                >
+                  <NInput
+                    allowInput={this.trim}
+                    class='input-zeppelin_rest_endpoint'
+                    v-model={[detailForm.restEndpoint, 'value']}
+                    type='text'
+                    maxlength={255}
+                    placeholder={t('datasource.zeppelin_rest_endpoint_tips')}
+                  />
+                </NFormItem>
                 <NFormItem
                   v-show={showPort}
                   label={t('datasource.port')}
@@ -305,6 +322,8 @@ const DetailModal = defineComponent({
                     options={
                       detailForm.type === 'REDSHIFT'
                         ? redShiftModeOptions
+                        : detailForm.type === 'SAGEMAKER'
+                        ? sagemakerModeOption
                         : modeOptions
                     }
                   ></NSelect>
@@ -481,7 +500,11 @@ const DetailModal = defineComponent({
                   />
                 </NFormItem>
                 <NFormItem
-                  v-show={showMode && detailForm.mode === 'IAM-accessKey'}
+                  v-show={
+                    showMode &&
+                    detailForm.mode === 'IAM-accessKey' &&
+                    detailForm.type != 'SAGEMAKER'
+                  }
                   label={t('datasource.dbUser')}
                   path='dbUser'
                   show-require-mark
@@ -519,7 +542,6 @@ const DetailModal = defineComponent({
                   />
                 </NFormItem>
                 <NFormItem
-                  v-show={!showMode || detailForm.mode === 'password'}
                   label={t('datasource.user_name')}
                   path='userName'
                   show-require-mark
@@ -534,7 +556,6 @@ const DetailModal = defineComponent({
                   />
                 </NFormItem>
                 <NFormItem
-                  v-show={!showMode || detailForm.mode === 'password'}
                   label={t('datasource.user_password')}
                   path='password'
                 >
