@@ -16,7 +16,7 @@
  */
 
 import { defineComponent, onMounted, ref, toRefs } from 'vue'
-import { NGrid, NGi, NCard, NNumberAnimation, NSpace } from 'naive-ui'
+import { NGrid, NGi, NCard, NNumberAnimation, NSpace, NTag } from 'naive-ui'
 import { useI18n } from 'vue-i18n'
 import { useWorker } from './use-worker'
 import styles from './index.module.scss'
@@ -27,6 +27,7 @@ import WorkerModal from './worker-modal'
 import type { Ref } from 'vue'
 import type { RowData } from 'naive-ui/es/data-table/src/interface'
 import type { WorkerNode } from '@/service/modules/monitor/types'
+import { capitalize } from 'lodash'
 
 const worker = defineComponent({
   name: 'worker',
@@ -36,12 +37,8 @@ const worker = defineComponent({
     const { variables, getTableWorker } = useWorker()
     const zkDirectoryRef: Ref<Array<RowData>> = ref([])
 
-    const clickDetails = (zkDirectories: Array<string>) => {
-      zkDirectoryRef.value = zkDirectories.map((zkItem) => {
-        return {
-          directory: zkItem
-        }
-      })
+    const clickDetails = (zkDirectories: string) => {
+      zkDirectoryRef.value = [{ directory: zkDirectories, index: 1 }]
       showModalRef.value = true
     }
 
@@ -66,6 +63,18 @@ const worker = defineComponent({
     const { t, clickDetails, onConfirmModal, showModalRef, zkDirectoryRef } =
       this
 
+    const renderNodeServerStatusTag = (item: WorkerNode) => {
+      const serverStatus = JSON.parse(item.resInfo)?.serverStatus
+
+      if (!serverStatus) return ''
+
+      return (
+        <NTag type={serverStatus === 'NORMAL' ? 'info' : 'warning'}>
+          {capitalize(serverStatus)}
+        </NTag>
+      )
+    }
+
     return this.data.length < 1 ? (
       <Result
         title={t('monitor.worker.worker_no_data_result_title')}
@@ -80,14 +89,21 @@ const worker = defineComponent({
             return (
               <NSpace vertical>
                 <NCard>
-                  <NSpace justify='space-between'>
+                  <NSpace
+                    justify='space-between'
+                    style={{
+                      'line-height': '28px'
+                    }}
+                  >
                     <NSpace>
+                      {renderNodeServerStatusTag(item)}
+
                       <span>{`${t('monitor.worker.host')}: ${
                         item ? item.host : ' - '
                       }`}</span>
                       <span
                         class={styles['link-btn']}
-                        onClick={() => clickDetails(item.zkDirectories)}
+                        onClick={() => clickDetails(item.zkDirectory)}
                       >
                         {t('monitor.worker.directory_detail')}
                       </span>
@@ -102,7 +118,7 @@ const worker = defineComponent({
                     </NSpace>
                   </NSpace>
                 </NCard>
-                <NGrid x-gap='12' cols='4'>
+                <NGrid x-gap='12' cols='5'>
                   <NGi>
                     <Card title={t('monitor.worker.cpu_usage')}>
                       <div class={styles.card}>
@@ -155,6 +171,33 @@ const worker = defineComponent({
                       </div>
                     </Card>
                   </NGi>
+
+                  <NGi>
+                    <Card title={t('monitor.worker.thread_pool_usage')}>
+                      <div
+                        class={[styles.card, styles['load-average']]}
+                        style={{
+                          'font-size': '90px'
+                        }}
+                      >
+                        {item && (
+                          <>
+                            <NNumberAnimation
+                              precision={0}
+                              from={0}
+                              to={JSON.parse(item.resInfo).threadPoolUsage}
+                            />
+                            /
+                            <NNumberAnimation
+                              precision={0}
+                              from={0}
+                              to={JSON.parse(item.resInfo).workerHostWeight}
+                            />
+                          </>
+                        )}
+                      </div>
+                    </Card>
+                  </NGi>
                 </NGrid>
               </NSpace>
             )
