@@ -17,6 +17,7 @@
 
 export { useName } from './use-name'
 export { useRunFlag } from './use-run-flag'
+export { useCache } from './use-cache'
 export { useDescription } from './use-description'
 export { useTaskPriority } from './use-task-priority'
 export { useWorkerGroup } from './use-worker-group'
@@ -35,6 +36,8 @@ export { useDatasource } from './use-datasource'
 export { useSqlType } from './use-sql-type'
 export { useProcedure } from './use-procedure'
 export { useCustomParams } from './use-custom-params'
+export { useCustomLabels } from './use-custom-labels'
+export { useNodeSelectors } from './use-node-selectors'
 export { useSourceType } from './use-sqoop-source-type'
 export { useTargetType } from './use-sqoop-target-type'
 export { useRelationCustomParams } from './use-relation-custom-params'
@@ -49,6 +52,7 @@ export { useExecutorCores } from './use-executor-cores'
 export { useMainJar } from './use-main-jar'
 export { useResources } from './use-resources'
 export { useTaskDefinition } from './use-task-definition'
+export { useJavaTaskMainJar } from './use-java-task-main-jar'
 
 export { useShell } from './use-shell'
 export { useSpark } from './use-spark'
@@ -74,7 +78,16 @@ export { useOpenmldb } from './use-openmldb'
 export { useDvc } from './use-dvc'
 export { useDinky } from './use-dinky'
 export { useSagemaker } from './use-sagemaker'
+export { useJava } from './use-java'
 export { useChunjun } from './use-chunjun'
 export { useChunjunDeployMode } from './use-chunjun-deploy-mode'
 export { usePytorch } from './use-pytorch'
 export { useHiveCli } from './use-hive-cli'
+export { useDms } from './use-dms'
+export { useDatasync } from './use-datasync'
+export { useKubeflow } from './use-kubeflow'
+export { useLinkis } from './use-linkis'
+export { useDataFactory } from './use-data-factory'
+export { useRemoteShell } from './use-remote-shell'
+export { useDynamic } from './use-dynamic'
+export { useYarnQueue } from './use-queue'
