@@ -15,11 +15,12 @@
  * limitations under the License.
  */
 
-import { onMounted, ref, Ref } from 'vue'
+import { onMounted, ref, Ref, watch } from 'vue'
 import { queryDataSourceList } from '@/service/modules/data-source'
 import { useI18n } from 'vue-i18n'
 import type { IJsonItem, IDataBase } from '../types'
 import type { TypeReq } from '@/service/modules/data-source/types'
+
 export function useDatasource(
   model: { [field: string]: any },
   span: Ref,
@@ -29,10 +30,24 @@ export function useDatasource(
   const { t } = useI18n()
   const dataSourceList = ref([])
   const loading = ref(false)
-
+  const hadoopSourceTypes = ref(['HIVE', 'HDFS'])
   const getDataSource = async (type: IDataBase) => {
-    if (loading.value) return
+    if (hadoopSourceTypes.value.some((source) => source === type)) {
+      loading.value = false
+      return
+    }
     loading.value = true
+    if (model.modelType === 'import') {
+      model.sourceMysqlDatasource = model.sourceMysqlDatasource
+        ? model.sourceMysqlDatasource
+        : ''
+      model.sourceMysqlType = type
+    } else {
+      model.sourceMysqlDatasource = model.targetMysqlDatasource
+        ? model.targetMysqlDatasource
+        : ''
+      model.targetMysqlType = type
+    }
     const params = { type, testFlag: 0 } as TypeReq
     const result = await queryDataSourceList(params)
     dataSourceList.value = result.map((item: { name: string; id: number }) => ({
@@ -42,16 +57,28 @@ export function useDatasource(
     loading.value = false
   }
   onMounted(() => {
-    getDataSource('MYSQL')
+    getDataSource(model.sourceType)
   })
 
+  watch(
+    () => [model.sourceType],
+    () => {
+      getDataSource(model.sourceType)
+    }
+  )
+
+  watch(
+    () => [model.targetType],
+    () => {
+      getDataSource(model.targetType)
+    }
+  )
   return [
     {
-      type: 'select',
+      type: 'input',
       field: fieldType,
       name: t('project.node.datasource'),
-      span: span,
-      options: [{ label: 'MYSQL', value: 'MYSQL' }],
+      span: 0,
       validate: {
         required: true
       }
@@ -59,7 +86,7 @@ export function useDatasource(
     {
       type: 'select',
       field: fieldDatasource,
-      name: ' ',
+      name: t('project.node.datasource'),
       span: span,
       props: {
         placeholder: t('project.node.datasource_tips'),
