@@ -25,13 +25,14 @@ import type {
   ILocalParam,
   IDependentParameters
 } from './types'
+import { ref } from 'vue'
 
 export function formatParams(data: INodeData): {
   processDefinitionCode: string
   upstreamCodes: string
   taskDefinitionJsonObj: object
 } {
-
+  const rdbmsSourceTypes = ref(['MYSQL', 'ORACLE', 'SQLSERVER', 'HANA'])
   const taskParams: ITaskParams = {}
   if (data.taskType === 'SUB_PROCESS' || data.taskType === 'DYNAMIC') {
     taskParams.processDefinitionCode = data.processDefinitionCode
@@ -67,6 +68,7 @@ export function formatParams(data: INodeData): {
   }
 
   if (data.taskType === 'SPARK') {
+    taskParams.master = data.master
     taskParams.driverCores = data.driverCores
     taskParams.driverMemory = data.driverMemory
     taskParams.numExecutors = data.numExecutors
@@ -85,6 +87,7 @@ export function formatParams(data: INodeData): {
   }
   if (data.taskType === 'HTTP') {
     taskParams.httpMethod = data.httpMethod
+    taskParams.httpBody = data.httpBody
     taskParams.httpCheckCondition = data.httpCheckCondition
     taskParams.httpParams = data.httpParams
     taskParams.url = data.url
@@ -109,79 +112,69 @@ export function formatParams(data: INodeData): {
       taskParams.targetType = data.targetType
       let targetParams: ISqoopTargetParams = {}
       let sourceParams: ISqoopSourceParams = {}
-      switch (data.targetType) {
-        case 'HIVE':
-          targetParams = {
-            hiveDatabase: data.targetHiveDatabase,
-            hiveTable: data.targetHiveTable,
-            createHiveTable: data.targetHiveCreateTable,
-            dropDelimiter: data.targetHiveDropDelimiter,
-            hiveOverWrite: data.targetHiveOverWrite,
-            hiveTargetDir: data.targetHiveTargetDir,
-            replaceDelimiter: data.targetHiveReplaceDelimiter,
-            hivePartitionKey: data.targetHivePartitionKey,
-            hivePartitionValue: data.targetHivePartitionValue
-          }
-          break
-        case 'HDFS':
-          targetParams = {
-            targetPath: data.targetHdfsTargetPath,
-            deleteTargetDir: data.targetHdfsDeleteTargetDir,
-            compressionCodec: data.targetHdfsCompressionCodec,
-            fileType: data.targetHdfsFileType,
-            fieldsTerminated: data.targetHdfsFieldsTerminated,
-            linesTerminated: data.targetHdfsLinesTerminated
-          }
-          break
-        case 'MYSQL':
-          targetParams = {
-            targetType: data.targetMysqlType,
-            targetDatasource: data.targetMysqlDatasource,
-            targetTable: data.targetMysqlTable,
-            targetColumns: data.targetMysqlColumns,
-            fieldsTerminated: data.targetMysqlFieldsTerminated,
-            linesTerminated: data.targetMysqlLinesTerminated,
-            isUpdate: data.targetMysqlIsUpdate,
-            targetUpdateKey: data.targetMysqlTargetUpdateKey,
-            targetUpdateMode: data.targetMysqlUpdateMode
-          }
-          break
-        default:
-          break
+      if (data.targetType === 'HIVE') {
+        targetParams = {
+          hiveDatabase: data.targetHiveDatabase,
+          hiveTable: data.targetHiveTable,
+          createHiveTable: data.targetHiveCreateTable,
+          dropDelimiter: data.targetHiveDropDelimiter,
+          hiveOverWrite: data.targetHiveOverWrite,
+          hiveTargetDir: data.targetHiveTargetDir,
+          replaceDelimiter: data.targetHiveReplaceDelimiter,
+          hivePartitionKey: data.targetHivePartitionKey,
+          hivePartitionValue: data.targetHivePartitionValue
+        }
+      } else if (data.targetType === 'HDFS') {
+        targetParams = {
+          targetPath: data.targetHdfsTargetPath,
+          deleteTargetDir: data.targetHdfsDeleteTargetDir,
+          compressionCodec: data.targetHdfsCompressionCodec,
+          fileType: data.targetHdfsFileType,
+          fieldsTerminated: data.targetHdfsFieldsTerminated,
+          linesTerminated: data.targetHdfsLinesTerminated
+        }
+      } else if (
+        rdbmsSourceTypes.value.some((target) => target === data.targetType)
+      ) {
+        targetParams = {
+          targetType: data.targetMysqlType,
+          targetDatasource: data.targetMysqlDatasource,
+          targetTable: data.targetMysqlTable,
+          targetColumns: data.targetMysqlColumns,
+          fieldsTerminated: data.targetMysqlFieldsTerminated,
+          linesTerminated: data.targetMysqlLinesTerminated,
+          isUpdate: data.targetMysqlIsUpdate,
+          targetUpdateKey: data.targetMysqlTargetUpdateKey,
+          targetUpdateMode: data.targetMysqlUpdateMode
+        }
       }
-      switch (data.sourceType) {
-        case 'MYSQL':
-          sourceParams = {
-            srcTable: data.srcQueryType === '1' ? '' : data.srcTable,
-            srcColumnType: data.srcQueryType === '1' ? '0' : data.srcColumnType,
-            srcColumns:
-              data.srcQueryType === '1' || data.srcColumnType === '0'
-                ? ''
-                : data.srcColumns,
-            srcQuerySql:
-              data.srcQueryType === '0' ? '' : data.sourceMysqlSrcQuerySql,
-            srcQueryType: data.srcQueryType,
-            srcType: data.sourceMysqlType,
-            srcDatasource: data.sourceMysqlDatasource,
-            mapColumnHive: data.mapColumnHive,
-            mapColumnJava: data.mapColumnJava
-          }
-          break
-        case 'HDFS':
-          sourceParams = {
-            exportDir: data.sourceHdfsExportDir
-          }
-          break
-        case 'HIVE':
-          sourceParams = {
-            hiveDatabase: data.sourceHiveDatabase,
-            hiveTable: data.sourceHiveTable,
-            hivePartitionKey: data.sourceHivePartitionKey,
-            hivePartitionValue: data.sourceHivePartitionValue
-          }
-          break
-        default:
-          break
+      if (rdbmsSourceTypes.value.some((target) => target === data.sourceType)) {
+        sourceParams = {
+          srcTable: data.srcQueryType === '1' ? '' : data.srcTable,
+          srcColumnType: data.srcQueryType === '1' ? '0' : data.srcColumnType,
+          srcColumns:
+            data.srcQueryType === '1' || data.srcColumnType === '0'
+              ? ''
+              : data.srcColumns,
+          srcQuerySql:
+            data.srcQueryType === '0' ? '' : data.sourceMysqlSrcQuerySql,
+          srcQueryType: data.srcQueryType,
+          srcType: data.sourceMysqlType,
+          srcDatasource: data.sourceMysqlDatasource,
+          mapColumnHive: data.mapColumnHive,
+          mapColumnJava: data.mapColumnJava
+        }
+      } else if (data.sourceType === 'HDFS') {
+        sourceParams = {
+          exportDir: data.sourceHdfsExportDir
+        }
+      } else if (data.sourceType === 'HIVE') {
+        sourceParams = {
+          hiveDatabase: data.sourceHiveDatabase,
+          hiveTable: data.sourceHiveTable,
+          hivePartitionKey: data.sourceHivePartitionKey,
+          hivePartitionValue: data.sourceHivePartitionValue
+        }
       }
       taskParams.targetParams = JSON.stringify(targetParams)
       taskParams.sourceParams = JSON.stringify(sourceParams)
@@ -347,6 +340,8 @@ export function formatParams(data: INodeData): {
     taskParams.password = data.password
     taskParams.productionNoteDirectory = data.productionNoteDirectory
     taskParams.parameters = data.parameters
+    taskParams.datasource = data.datasource
+    taskParams.type = data.type
   }
 
   if (data.taskType === 'K8S') {
@@ -405,6 +400,11 @@ export function formatParams(data: INodeData): {
 
   if (data.taskType === 'SAGEMAKER') {
     taskParams.sagemakerRequestJson = data.sagemakerRequestJson
+    taskParams.username = data.username
+    taskParams.password = data.password
+    taskParams.datasource = data.datasource
+    taskParams.type = data.type
+    taskParams.awsRegion = data.awsRegion
   }
   if (data.taskType === 'PYTORCH') {
     taskParams.script = data.script
@@ -598,6 +598,7 @@ export function formatModel(data: ITaskData) {
     const targetParams: ISqoopTargetParams = JSON.parse(
       data.taskParams.targetParams
     )
+    params.targetType = data.taskParams.targetType
     params.targetHiveDatabase = targetParams.hiveDatabase
     params.targetHiveTable = targetParams.hiveTable
     params.targetHiveCreateTable = targetParams.createHiveTable
