@@ -45,7 +45,8 @@ export function useSpark({
     timeout: 30,
     programType: 'SCALA',
     rawScript: '',
-    deployMode: 'local',
+    master: '',
+    deployMode: '',
     driverCores: 1,
     driverMemory: '512M',
     numExecutors: 2,
@@ -64,7 +65,7 @@ export function useSpark({
       Fields.useCache(),
       Fields.useDescription(),
       Fields.useTaskPriority(),
-      Fields.useWorkerGroup(),
+      Fields.useWorkerGroup(projectCode),
       Fields.useEnvironmentName(model, !data?.id),
       ...Fields.useTaskGroup(model, projectCode),
       ...Fields.useFailed(),
