@@ -83,6 +83,7 @@ interface IResponseJsonItem extends Omit<IJsonItemParams, 'type'> {
 }
 
 interface IDependentItemOptions {
+  dependentTypeOptions?: IOption[]
   definitionCodeOptions?: IOption[]
   depTaskCodeOptions?: IOption[]
   dateOptions?: IOption[]
@@ -99,6 +100,8 @@ interface IDependentItem {
   definitionCode?: number
   cycle?: 'month' | 'week' | 'day' | 'hour'
   dateValue?: string
+  dependentType?: 'DEPENDENT_ON_WORKFLOW' | 'DEPENDENT_ON_TASK'
+  parameterPassing?: boolean
 }
 
 interface IDependTask {
@@ -284,6 +287,7 @@ interface ITaskParams {
   mainArgs?: string
   others?: string
   httpMethod?: string
+  httpBody?: string
   httpCheckCondition?: string
   httpParams?: []
   url?: string
@@ -448,6 +452,8 @@ interface ITaskParams {
   filterCondition?: string
   listParameters?: Array<any>
   yarnQueue?: string
+  awsRegion?: string
+  kubeConfig?: string
 }
 
 interface INodeData
