@@ -39,15 +39,18 @@ import {
 import { format } from 'date-fns-tz'
 import { ISearchParam } from './types'
 import type { Router } from 'vue-router'
+import { useDependencies } from '@/views/projects/components/dependencies/use-dependencies'
 
 export function useTable() {
   const { t } = useI18n()
   const router: Router = useRouter()
 
+  const { getDependentTaskLinks } = useDependencies()
+
   const variables = reactive({
     columns: [],
     tableWidth: DefaultTableWidth,
-    row: {},
+    row: {} as any,
     tableData: [],
     projectCode: ref(Number(router.currentRoute.value.params.projectCode)),
     page: ref(1),
@@ -58,7 +61,14 @@ export function useTable() {
     loadingRef: ref(false),
     processDefinitionCode: router.currentRoute.value.params.definitionCode
       ? ref(Number(router.currentRoute.value.params.definitionCode))
-      : ref()
+      : ref(),
+    dependenciesData: ref({
+      showRef: false,
+      taskLinks: ref([]),
+      required: ref(false),
+      tip: ref(''),
+      action: () => {}
+    })
   })
 
   const renderTime = (time: string, timeZone: string) => {
@@ -107,19 +117,19 @@ export function useTable() {
         render: (row: any) => {
           if (row.releaseState === 'ONLINE') {
             return h(
-                NTag,
-                { type: 'success', size: 'small' },
-                {
-                  default: () => t('project.workflow.up_line')
-                }
+              NTag,
+              { type: 'success', size: 'small' },
+              {
+                default: () => t('project.workflow.up_line')
+              }
             )
           } else {
             return h(
-                NTag,
-                { type: 'warning', size: 'small' },
-                {
-                  default: () => t('project.workflow.down_line')
-                }
+              NTag,
+              { type: 'warning', size: 'small' },
+              {
+                default: () => t('project.workflow.down_line')
+              }
             )
           }
         }
@@ -132,36 +142,36 @@ export function useTable() {
           return h(NSpace, null, {
             default: () => [
               h(
-                  NTooltip,
-                  {},
-                  {
-                    trigger: () =>
-                        h(
-                            NButton,
-                            {
-                              circle: true,
-                              type:
-                                  row.releaseState === 'ONLINE' ? 'error' : 'warning',
-                              size: 'small',
-                              onClick: () => {
-                                handleReleaseState(row)
-                              }
-                            },
-                            {
-                              icon: () =>
-                                  h(
-                                      row.releaseState === 'ONLINE'
-                                          ? ArrowDownOutlined
-                                          : ArrowUpOutlined
-                                  )
-                            }
-                        ),
-                    default: () =>
-                        row.releaseState === 'ONLINE'
-                            ? t('project.workflow.down_line')
-                            : t('project.workflow.up_line')
-                  }
-              ),
+                NTooltip,
+                {},
+                {
+                  trigger: () =>
+                    h(
+                      NButton,
+                      {
+                        circle: true,
+                        type:
+                          row.releaseState === 'ONLINE' ? 'error' : 'warning',
+                        size: 'small',
+                        onClick: () => {
+                          handleReleaseState(row)
+                        }
+                      },
+                      {
+                        icon: () =>
+                          h(
+                            row.releaseState === 'ONLINE'
+                              ? ArrowDownOutlined
+                              : ArrowUpOutlined
+                          )
+                      }
+                    ),
+                  default: () =>
+                    row.releaseState === 'ONLINE'
+                      ? t('project.workflow.down_line')
+                      : t('project.workflow.up_line')
+                }
+              )
             ]
           })
         }
@@ -172,7 +182,6 @@ export function useTable() {
     }
   }
 
-
   const createColumns = (variables: any) => {
     variables.columns = [
       {
@@ -329,7 +338,7 @@ export function useTable() {
                 NPopconfirm,
                 {
                   onPositiveClick: () => {
-                    handleDelete(row.id)
+                    handleDelete(row)
                   }
                 },
                 {
@@ -344,7 +353,8 @@ export function useTable() {
                             {
                               circle: true,
                               type: 'error',
-                              size: 'small'
+                              size: 'small',
+                              disabled: row.releaseState === 'ONLINE'
                             },
                             {
                               icon: () => h(DeleteOutlined)
@@ -387,12 +397,49 @@ export function useTable() {
   }
 
   const handleReleaseState = (row: any) => {
-    let handle = online
     if (row.releaseState === 'ONLINE') {
-      handle = offline
+      variables.row = row
+      getDependentTaskLinks(
+        variables.projectCode,
+        row.processDefinitionCode
+      ).then((res: any) => {
+        if (res && res.length > 0) {
+          variables.dependenciesData.showRef = true
+          variables.dependenciesData.taskLinks = res
+          variables.dependenciesData.tip = t(
+            'project.workflow.warning_delete_scheduler_dependent_tasks_desc'
+          )
+          variables.dependenciesData.required = false
+          variables.dependenciesData.action = confirmToOfflineSchedule
+        } else {
+          offline(variables.projectCode, row.id).then(() => {
+            window.$message.success(t('project.workflow.success'))
+            getTableData({
+              pageSize: variables.pageSize,
+              pageNo: variables.page,
+              searchVal: variables.searchVal,
+              projectCode: variables.projectCode,
+              processDefinitionCode: variables.processDefinitionCode
+            })
+          })
+        }
+      })
+    } else {
+      online(variables.projectCode, row.id).then(() => {
+        window.$message.success(t('project.workflow.success'))
+        getTableData({
+          pageSize: variables.pageSize,
+          pageNo: variables.page,
+          searchVal: variables.searchVal,
+          projectCode: variables.projectCode,
+          processDefinitionCode: variables.processDefinitionCode
+        })
+      })
     }
+  }
 
-    handle(variables.projectCode, row.id).then(() => {
+  const confirmToOfflineSchedule = () => {
+    offline(variables.projectCode, variables.row.id).then(() => {
       window.$message.success(t('project.workflow.success'))
       getTableData({
         pageSize: variables.pageSize,
@@ -402,14 +449,11 @@ export function useTable() {
         processDefinitionCode: variables.processDefinitionCode
       })
     })
+    variables.dependenciesData.showRef = false
   }
 
-  const handleDelete = (id: number) => {
-    /* after deleting data from the current page, you need to jump forward when the page is empty. */
-    if (variables.tableData.length === 1 && variables.page > 1) {
-      variables.page -= 1
-    }
-    deleteScheduleById(id, variables.projectCode).then(() => {
+  const confirmToDeleteSchedule = () => {
+    deleteScheduleById(variables.row.id, variables.projectCode).then(() => {
       window.$message.success(t('project.workflow.success'))
       getTableData({
         pageSize: variables.pageSize,
@@ -419,6 +463,40 @@ export function useTable() {
         processDefinitionCode: variables.processDefinitionCode
       })
     })
+    variables.dependenciesData.showRef = false
+  }
+
+  const handleDelete = (row: any) => {
+    /* after deleting data from the current page, you need to jump forward when the page is empty. */
+    if (variables.tableData.length === 1 && variables.page > 1) {
+      variables.page -= 1
+    }
+    variables.row = row
+    getDependentTaskLinks(
+      variables.projectCode,
+      row.processDefinitionCode
+    ).then((res: any) => {
+      if (res && res.length > 0) {
+        variables.dependenciesData.showRef = true
+        variables.dependenciesData.taskLinks = res
+        variables.dependenciesData.tip = t(
+          'project.workflow.warning_delete_scheduler_dependent_tasks_desc'
+        )
+        variables.dependenciesData.required = false
+        variables.dependenciesData.action = confirmToDeleteSchedule
+      } else {
+        deleteScheduleById(row.id, variables.projectCode).then(() => {
+          window.$message.success(t('project.workflow.success'))
+          getTableData({
+            pageSize: variables.pageSize,
+            pageNo: variables.page,
+            searchVal: variables.searchVal,
+            projectCode: variables.projectCode,
+            processDefinitionCode: variables.processDefinitionCode
+          })
+        })
+      }
+    })
   }
 
   return {
