@@ -16,21 +16,59 @@
  */
 
 import { SearchOutlined } from '@vicons/antd'
-import { NInput, NButton, NDatePicker, NSelect, NIcon, NSpace } from 'naive-ui'
-import { defineComponent, getCurrentInstance, ref } from 'vue'
+import {
+  NInput,
+  NButton,
+  NDatePicker,
+  NSelect,
+  NIcon,
+  NSpace,
+  NEllipsis
+} from 'naive-ui'
+import { defineComponent, getCurrentInstance, h, ref, unref } from 'vue'
 import { useI18n } from 'vue-i18n'
 import { format } from 'date-fns'
 import { workflowExecutionStateType } from '@/common/common'
+import { queryProcessDefinitionList } from '@/service/modules/process-definition'
+import { SelectMixedOption } from 'naive-ui/lib/select/src/interface'
+import { Router, useRouter } from 'vue-router'
+import { SelectOption } from 'naive-ui/es/select/src/interface'
 
 export default defineComponent({
   name: 'ProcessInstanceCondition',
   emits: ['handleSearch'],
   setup(props, ctx) {
+    const router: Router = useRouter()
+
     const searchValRef = ref('')
     const executorNameRef = ref('')
     const hostRef = ref('')
     const stateTypeRef = ref('')
     const startEndTimeRef = ref()
+    const projectCode = ref(
+      Number(router.currentRoute.value.params.projectCode)
+    )
+    const processDefineCodeRef = router.currentRoute.value.query
+      .processDefineCode
+      ? ref(Number(router.currentRoute.value.query.processDefineCode))
+      : ref()
+
+    const processDefinitionOptions = ref<Array<SelectMixedOption>>([])
+
+    const initProcessList = (code: number) => {
+      queryProcessDefinitionList(code).then((result: any) => {
+        result.map((item: { code: number; name: string }) => {
+          const option: SelectMixedOption = {
+            value: item.code,
+            label: () => h(NEllipsis, null, item.name),
+            filterLabel: item.name
+          }
+          processDefinitionOptions.value.push(option)
+        })
+      })
+    }
+
+    initProcessList(projectCode.value)
 
     const handleSearch = () => {
       let startDate = ''
@@ -52,7 +90,8 @@ export default defineComponent({
         host: hostRef.value,
         stateType: stateTypeRef.value,
         startDate,
-        endDate
+        endDate,
+        processDefineCode: processDefineCodeRef.value
       })
     }
 
@@ -73,6 +112,19 @@ export default defineComponent({
 
     const trim = getCurrentInstance()?.appContext.config.globalProperties.trim
 
+    const selectFilter = (query: string, option: SelectOption) => {
+      return option.filterLabel
+        ? option.filterLabel
+            .toString()
+            .toLowerCase()
+            .includes(query.toLowerCase())
+        : false
+    }
+
+    const updateValue = (value: number) => {
+      processDefineCodeRef.value = value
+    }
+
     return {
       searchValRef,
       executorNameRef,
@@ -83,15 +135,39 @@ export default defineComponent({
       onClearSearchVal,
       onClearSearchExecutor,
       onClearSearchHost,
-      trim
+      trim,
+      processDefinitionOptions,
+      processDefineCodeRef,
+      selectFilter,
+      updateValue
     }
   },
   render() {
     const { t } = useI18n()
     const options = workflowExecutionStateType(t)
+    const {
+      processDefinitionOptions,
+      processDefineCodeRef,
+      selectFilter,
+      updateValue
+    } = this
 
     return (
       <NSpace justify='end'>
+        {h(NSelect, {
+          style: {
+            width: '210px'
+          },
+          size: 'small',
+          clearable: true,
+          filterable: true,
+          options: unref(processDefinitionOptions),
+          value: processDefineCodeRef,
+          filter: selectFilter,
+          onUpdateValue: (value: any) => {
+            updateValue(value)
+          }
+        })}
         <NInput
           allowInput={this.trim}
           size='small'
