@@ -16,7 +16,7 @@
  */
 
 import { defineComponent, onMounted, ref } from 'vue'
-import { useRoute, useRouter } from 'vue-router'
+import { useRoute } from 'vue-router'
 import { useThemeStore } from '@/store/theme/theme'
 import { useI18n } from 'vue-i18n'
 import Dag from '../../components/dag'
@@ -47,7 +47,6 @@ export default defineComponent({
   setup() {
     const theme = useThemeStore()
     const route = useRoute()
-    const router = useRouter()
     const { t } = useI18n()
     const projectCode = Number(route.params.projectCode)
     const id = Number(route.params.id)
@@ -82,7 +81,7 @@ export default defineComponent({
         return {
           prop: p.key,
           value: p.value,
-          direct: 'IN',
+          direct: p.direct,
           type: 'VARCHAR'
         }
       })
@@ -94,14 +93,13 @@ export default defineComponent({
           locations: JSON.stringify(locations),
           taskDefinitionJson: JSON.stringify(taskDefinitions),
           taskRelationJson: JSON.stringify(connects),
-          tenantCode: saveForm.tenantCode,
           timeout: saveForm.timeoutFlag ? saveForm.timeout : 0
         },
         id,
         projectCode
       ).then((ignored: any) => {
         window.$message.success(t('project.dag.success'))
-        router.push({ path: `/projects/${projectCode}/workflow/instances` })
+        window.location.reload()
       })
     }
 
