@@ -23,7 +23,15 @@ import {
   ref,
   getCurrentInstance
 } from 'vue'
-import { NSelect, NInput } from 'naive-ui'
+import {
+  NSelect,
+  NInput,
+  NSwitch,
+  NRadioGroup,
+  NSpace,
+  NRadio,
+  NButton
+} from 'naive-ui'
 import { isFunction } from 'lodash'
 import { useI18n } from 'vue-i18n'
 import { useForm } from './use-form'
@@ -57,6 +65,7 @@ const DetailModal = defineComponent({
 
     const rules = ref<IFormRules>({})
     const elements = ref<IFormItem[]>([]) as IElements
+    const warningTypeSpan = ref(24)
 
     const {
       meta,
@@ -68,7 +77,7 @@ const DetailModal = defineComponent({
       changePlugin
     } = useForm()
 
-    const { status, createOrUpdate } = useDetail(getFormValues)
+    const { status, createOrUpdate, testSend } = useDetail(getFormValues)
 
     const onCancel = () => {
       resetForm()
@@ -85,6 +94,11 @@ const DetailModal = defineComponent({
         ctx.emit('update')
       }
     }
+    const onTest = async () => {
+      await state.detailFormRef.validate()
+      testSend(state.json)
+    }
+
     const onChangePlugin = changePlugin
 
     const trim = getCurrentInstance()?.appContext.config.globalProperties.trim
@@ -95,6 +109,12 @@ const DetailModal = defineComponent({
         props.show && props.currentRecord && setDetail(props.currentRecord)
       }
     )
+    watch(
+      () => state.detailForm.instanceType,
+      () =>
+        (warningTypeSpan.value =
+          state.detailForm.instanceType === 'GLOBAL' ? 0 : 24)
+    )
     watch(
       () => state.json,
       () => {
@@ -121,10 +141,12 @@ const DetailModal = defineComponent({
       ...toRefs(state),
       ...toRefs(status),
       meta,
+      warningTypeSpan,
       rules,
       elements,
       onChangePlugin,
       onSubmit,
+      onTest,
       onCancel,
       trim
     }
@@ -134,6 +156,7 @@ const DetailModal = defineComponent({
       show,
       t,
       meta,
+      warningTypeSpan,
       rules,
       elements,
       detailForm,
@@ -143,7 +166,9 @@ const DetailModal = defineComponent({
       saving,
       onChangePlugin,
       onCancel,
-      onSubmit
+      onSubmit,
+      onTest,
+      testing
     } = this
     const { currentRecord } = props
     return (
@@ -183,6 +208,32 @@ const DetailModal = defineComponent({
                       />
                     )
                   },
+                  {
+                    path: 'instanceType',
+                    label: t('security.alarm_instance.is_global_instance'),
+                    widget: (
+                      <NSwitch
+                        checkedValue={'GLOBAL'}
+                        uncheckedValue={'NORMAL'}
+                        disabled={!!currentRecord?.id}
+                        v-model:value={detailForm.instanceType}
+                      />
+                    )
+                  },
+                  {
+                    path: 'warningType',
+                    label: t('security.alarm_instance.WarningType'),
+                    span: warningTypeSpan,
+                    widget: (
+                      <NRadioGroup v-model:value={detailForm.warningType}>
+                        <NSpace>
+                          <NRadio value={'SUCCESS'}>{'success'}</NRadio>
+                          <NRadio value={'FAILURE'}>{'failure'}</NRadio>
+                          <NRadio value={'ALL'}>{'all'}</NRadio>
+                        </NSpace>
+                      </NRadioGroup>
+                    )
+                  },
                   {
                     path: 'pluginDefineId',
                     label: t('security.alarm_instance.select_plugin'),
@@ -205,6 +256,18 @@ const DetailModal = defineComponent({
                 cols: 24
               }}
             />
+          ),
+
+          'btn-middle': () => (
+            <NButton
+              class='btn-test-send'
+              type='primary'
+              size='small'
+              onClick={onTest}
+              loading={testing || loading}
+            >
+              {t('security.alarm_instance.test_send')}
+            </NButton>
           )
         }}
       </Modal>
